<?php
	/**
	 * Catalan language file.
	 */

	// Basic strings
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'La base de dades dels reports no està creada. Llegeixi el fitxer INSTALL per fer-ho.';

	// Reports
	$plugin_lang['strreport'] = 'Report';
	$plugin_lang['strreports'] = 'Reports';
	$plugin_lang['strshowallreports'] = 'Mostra tots els reports';
	$plugin_lang['strnoreports'] = 'No s\'han trobat reports';
	$plugin_lang['strcreatereport'] = 'Crea un report';
	$plugin_lang['strreportdropped'] = 'Report eliminat.';
	$plugin_lang['strreportdroppedbad'] = 'No s\'ha pogut eliminar el report.';
	$plugin_lang['strconfdropreport'] = 'Està segur de voler eliminar el report "%s"?';
	$plugin_lang['strreportneedsname'] = 'Ha de donar un nom al report.';
	$plugin_lang['strreportneedsdef'] = 'Ha de donar un SQL al report.';
	$plugin_lang['strreportcreated'] = 'Report desat.';
	$plugin_lang['strreportcreatedbad'] = 'No s\'ha pogut desar el report.';
?>
