<?php
	/**
	 * Galician language file.
	 */

	//Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'Non creou a base de datos de informes. Lea o ficheiro »INSTALL» (en inglés) para máis información.';

	// Reports
	$plugin_lang['strreport'] = 'Informe';
	$plugin_lang['strreports'] = 'Informes';
	$plugin_lang['strshowallreports'] = 'Listar todos os informes';
	$plugin_lang['strnoreports'] = 'Non se atopou informe algún.';
	$plugin_lang['strcreatereport'] = 'Crear un informe';
	$plugin_lang['strreportdropped'] = 'Eliminouse o informe.';
	$plugin_lang['strreportdroppedbad'] = 'Non se conseguiu eliminar o informe.';
	$plugin_lang['strconfdropreport'] = 'Está seguro de que quere eliminar o informe «%s»?';
	$plugin_lang['strreportneedsname'] = 'Debe fornecer un nome para o informe.';
	$plugin_lang['strreportneedsdef'] = 'Debe fornecer un código SQL para o informe.';
	$plugin_lang['strreportcreated'] = 'Gardouse o informe.';
	$plugin_lang['strreportcreatedbad'] = 'Non se conseguiu gardar o informe.';
?>
