<?php
	/**
	 * Czech language file.
	 */

	//Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'Nemáte vytvořenou databázi výstupních sestav. Přečtěte si soubor INSTALL s instrukcemi.';

	// Reports
	$plugin_lang['strreport'] = 'Výstupní sestava';
	$plugin_lang['strreports'] = 'Výstupní sestavy';
	$plugin_lang['strshowallreports'] = 'Zobrazit všechny výstupní sestavy';
	$plugin_lang['strnoreports'] = 'Nebyly nalezeny žádné výstupní sestava.';
	$plugin_lang['strcreatereport'] = 'Vytvořit výstupní sestavu';
	$plugin_lang['strreportdropped'] = 'Výstupní sestava byla odstraněna.';
	$plugin_lang['strreportdroppedbad'] = 'Nezdařilo se odstranit výstupní sestavu.';
	$plugin_lang['strconfdropreport'] = 'Opravdu chcete odstranit výstupní sestavu „%s“?';
	$plugin_lang['strreportneedsname'] = 'Musíte zadat název pro výstupní sestavu.';
	$plugin_lang['strreportneedsdef'] = 'Musíte zadat dotaz SQL pro výstupní sestavu.';
	$plugin_lang['strreportcreated'] = 'Výstupní sestava byla uložena.';
	$plugin_lang['strreportcreatedbad'] = 'Nezdařilo se uložit výstupní sestavu.';
?>
