<?php

	/*
	 *		Slovenska lokalizacia phpPgAdmin-u.
	 *                             ado (at) imladris.sk
	 */

	// Language and character set
	$lang['applang'] = 'Slovensky';
	$lang['applocale'] = 'sk-SK';
	$lang['applangdir'] = 'ltr';

	// Basic strings
	$lang['strintro'] = 'Vitaje vo phpPgAdmin-e.';
	$lang['strppahome'] = 'phpPgAdmin Homepage';
	$lang['strpgsqlhome'] = 'PostgreSQL Homepage';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQL Dokumentácia';
	$lang['strreportbug'] = 'Oznámiť Chybu';
	$lang['strviewfaq'] = 'Zobraziť FAQ';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';
	
	// Basic strings
	$lang['strlogin'] = 'Prihlásenie';
	$lang['strloginfailed'] = 'Prihlásenie zlyhalo';
	$lang['strlogindisallowed']  =  'Prihlásenie je vypnuté kôli bezpečnosti';
	$lang['strserver'] = 'Server';
	$lang['strservers']  =  'Servery';
	$lang['strintroduction']  =  'Úvod';
	$lang['strhost']  =  'Hostiteľ';
	$lang['strport']  =  'Port';
	$lang['strlogout'] = 'Odhlásiť';
	$lang['strowner'] = 'Vlastník';
	$lang['straction'] = 'Akcia';
	$lang['stractions'] = 'Akcie';
	$lang['strname'] = 'Meno';
	$lang['strdefinition'] = 'Definícia';
	$lang['strproperties'] = 'Vlastnosti';
	$lang['strbrowse'] = 'Prehliadať';
	$lang['strdrop'] = 'Odstrániť';
	$lang['strdropped'] = 'Odstránený';
	$lang['strnull'] = 'Nulový';
	$lang['strnotnull'] = 'Ne-nulový';
	$lang['strprev'] = 'Predchádzajúci';
	$lang['strnext'] = 'Ďaľší';
	$lang['strfirst'] = '<< Prvý';
	$lang['strlast'] = 'Posledný >>';
	$lang['strfailed']  =  'Chyba.';
	$lang['strcreate'] = 'Vytvoriť';
	$lang['strcreated'] = 'Vytvorené';
	$lang['strcomment'] = 'Komentár';
	$lang['strlength'] = 'Dĺžka';
	$lang['strdefault'] = 'Predvolené';
	$lang['stralter'] = 'Zmeniť';
	$lang['strok'] = 'OK';
	$lang['strcancel'] = 'Zrušiť';
	$lang['strsave'] = 'Uložiť';
	$lang['strreset'] = 'Reset';
	$lang['strinsert'] = 'Vložiť';
	$lang['strselect'] = 'Vybrať';
	$lang['strdelete'] = 'Zmazať';
	$lang['strupdate'] = 'Aktualizovať';
	$lang['strreferences'] = 'Referencie';
	$lang['stryes'] = 'Áno';
	$lang['strno'] = 'Nie';
	$lang['strtrue'] = 'True';
	$lang['strfalse'] = 'False';
	$lang['stredit']  =  'Upraviť';
	$lang['strcolumn']  =  'Stĺpec';
	$lang['strcolumns']  =  'Stĺpce';
	$lang['strrows'] = 'riadky';
	$lang['strrowsaff']  =  'riadkov ovplyvnených.';
	$lang['strobjects']  =  'objekt(y)';
	$lang['strback'] = 'Späť';
	$lang['strqueryresults'] = 'Výsledky Dotazu';
	$lang['strshow'] = 'Ukázať';
	$lang['strempty'] = 'Vyprázdniť';
	$lang['strlanguage'] = 'Jazyk';
	$lang['strencoding'] = 'Kódovanie';
	$lang['strvalue'] = 'Hodnota';
	$lang['strunique'] = 'Unikátny';
	$lang['strprimary'] = 'Primárny';
	$lang['strexport'] = 'Exportovať';
	$lang['strimport']  =  'Import'; 
	$lang['strallowednulls']  =  'Povolený NULL znak';
	$lang['strbackslashn']  =  '\N';
	$lang['strnull']  =  'Null';
	$lang['strnull']  =  'NULL (slovo)';
	$lang['stremptystring']  =  'Prázdny reťazec/pole';
	$lang['strsql'] = 'SQL';
	$lang['stradmin'] = 'Admin';
	$lang['strvacuum'] = 'Vyčistiť';
	$lang['stranalyze'] = 'Analyzovať';
	$lang['strclusterindex'] = 'Cluster';
	$lang['strclustered']  =  'Clustered?';
	$lang['strreindex'] = 'Reindex';
	$lang['strrun'] = 'Spustiť';
	$lang['stradd'] = 'Pridať';
	$lang['strremove']  =  'Zmazať';
	$lang['strevent'] = 'Prípadne';
	$lang['strwhere'] = 'Kde';
	$lang['strinstead'] = 'Urobiť Namiesto';
	$lang['strwhen'] = 'Kedy';
	$lang['strformat'] = 'Formát';
	$lang['strdata'] = 'Dáta';
	$lang['strconfirm'] = 'Potvrdiť';
	$lang['strexpression'] = 'Výraz';
	$lang['strellipsis'] = '...';
	$lang['strseparator']  =  ': ';
	$lang['strexpand'] = 'Rozšíriť';
	$lang['strcollapse']  =  'Zbaliť';
	$lang['strexplain'] = 'Vysvetliť';
	$lang['strexplainanalyze']  =  'Vysvetliť Analyze';
	$lang['strfind'] = 'Nájsť';
	$lang['stroptions'] = 'Nastavenia';
	$lang['strrefresh'] = 'Obnoviť';
	$lang['strdownload'] = 'Download';
	$lang['strdownloadgzipped'] = 'Stiahnuť skomprimované pomocou gzip';
	$lang['strinfo'] = 'Info';
	$lang['stroids'] = 'OIDs';
	$lang['stradvanced'] = 'Viac';
	$lang['strvariables'] = 'Premenné';
	$lang['strprocess'] = 'Proces';
	$lang['strprocesses'] = 'Procesy';
	$lang['strsetting'] = 'Nastavenie';
	$lang['streditsql'] = 'Upraviť SQL';
	$lang['strruntime']  =  'Celkový beh: %s ms';
	$lang['strpaginate'] = 'Výsledky stránkovania';
	$lang['struploadscript']  =  'alebo uploadni SQL skript:';
	$lang['strstarttime'] = 'Čas štartu';
	$lang['strfile']  =  'Súbor';
	$lang['strfileimported']  =  'Súbor importovaný.';
	$lang['strtrycred']  =  'Použiť tieto hodnoty pre všetky hodnoty';
$lang['strexecute']  =  'Execute';

	// Error handling
	$lang['strnoframes']  =  'Táto aplikácia funguje najlapšie s prehliadačom, ktorý podporuje technológiu frame-ov, no môže byť použitý aj takým, ktorý to nepodporuje nasledovaním tohto odkazu:';
	$lang['strnoframeslink']  =  'Nepoužívať frame-y';
	$lang['strbadconfig'] = 'Tvoj config.inc.php je zastaralý. Musíš vygenerovať nový zo súboru config.inc.php-dist.';
	$lang['strnotloaded'] = 'Tvoje PHP nie je skompilované s potrebnou podporou databáz.';
	$lang['strpostgresqlversionnotsupported']  =  'Tvoja verzia PostgreSQL nie je podporovaná. Prosím aktualizuj ju na verziu %s alebo vyššiu.';
	$lang['strbadschema'] = 'Špecifikovaná chybná schéma.';
	$lang['strbadencoding'] = 'Nastavenie kódovania v databáze zlyhalo.';
	$lang['strsqlerror'] = 'SQL chyba:';
	$lang['strinstatement'] = 'Vo výraze:';
	$lang['strinvalidparam'] = 'Chybné parametre skriptu.';
	$lang['strnodata'] = 'Nenájdené žiadne záznamy.';
	$lang['strnoobjects'] = 'Nenájdené žiadne objekty.';
	$lang['strrownotunique'] = 'Žiadny unikátny identifikárot pre tento riadok.';
	$lang['strnouploads']  =  'Upload súborov je vypnutý.';
	$lang['strimporterror']  =  'Chyba Import-u.';
	$lang['strimporterror-fileformat']  =  'Chyba importu: Automatické určenie formátu súboru zlyhalo.';
	$lang['strimporterrorline']  =  'Chyba Import-u na riadku %s.';
	$lang['strimporterrorline-badcolumnnum']  =  'Chyba importu na riadku %s: Riadok nemá správny počet stĺpcov.';
	$lang['strimporterror-uploadedfile']  =  'Chyba importu: Súbor nemôže byť upload-nutý k serveru';
	$lang['strcannotdumponwindows']  =  'Dump komplexných tabuliek a schém nie je na platforme Windows podporovaný.';

	// Tables
	$lang['strtable']  =  'Tabuľka';
	$lang['strtables'] = 'Tabuľky';
	$lang['strshowalltables'] = 'Zobraziť Všetky Tabuľky';
	$lang['strnotables'] = 'Nenájdené žiadne tabuľky.';
	$lang['strnotable'] = 'Nenájdená žiadna tabuľka.';
	$lang['strcreatetable'] = 'Vytvoriť tabuľku';
	$lang['strtablename'] = 'Názov tabuľky';
	$lang['strtableneedsname'] = 'Musíš zadať názov pre tvoju tabuľku.';
	$lang['strtableneedsfield'] = 'Musíš špecifikovať aspoň jedno pole.';
	$lang['strtableneedscols'] = 'Tabuľky vyžadujú vyhovujúci počet stĺpcov.';
	$lang['strtablecreated'] = 'Tabuľka vytvorená.';
	$lang['strtablecreatedbad'] = 'Tabuľka nebola vytvorená.';
	$lang['strconfdroptable'] = 'Naozaj chceš odstrániť tabuľku "%s"?';
	$lang['strtabledropped'] = 'Tabuľka odstránená.';
	$lang['strtabledroppedbad'] = 'Tabuľka nebola odstránená.';
	$lang['strconfemptytable'] = 'Si si istý, že chceš vyprázdniť tabuľku "%s"?';
	$lang['strtableemptied'] = 'Tabuľka vyprázdnená.';
	$lang['strtableemptiedbad'] = 'Tabuľka nebola vyprázdnená.';
	$lang['strinsertrow'] = 'Vložiť Riadok';
	$lang['strrowinserted'] = 'Riadok vložený.';
	$lang['strrowinsertedbad'] = 'Riadok nebol vložený.';
	$lang['strrowduplicate']  =  'Vloženie riadku zlyhalo, pokus o duplikátny insert.';
	$lang['streditrow'] = 'Upraviť Riadok';
	$lang['strrowupdated'] = 'Riadok upravený.';
	$lang['strrowupdatedbad'] = 'Riadok nebol upravený.';
	$lang['strdeleterow'] = 'Zmazať Riadok';
	$lang['strconfdeleterow'] = 'Si si istý, že chceš zmazať tento riadok?';
	$lang['strrowdeleted'] = 'Riadok zmazaný.';
	$lang['strrowdeletedbad'] = 'Riadok nebol zmazaný.';
	$lang['strinsertandrepeat']  =  'Vložiť & Zopakovať';
	$lang['strnumcols']  =  'Počet stĺpcov';
	$lang['strcolneedsname']  =  'Musíš zadať názov pre tvoj stĺpec';
	$lang['strselectallfields'] = 'Vybrať všetky polia';
	$lang['strselectneedscol']  =  'Musíš označiť aspoň jeden stĺpec.';
	$lang['strselectunary']  =  'Unárne operátory nemôžu mať hodnoty.';
	$lang['straltercolumn'] = 'Zmeniť Stĺpec';
	$lang['strcolumnaltered']  =  'Stĺpec zmenený.';
	$lang['strcolumnalteredbad'] = 'Stĺpec nebol zmenený.';
	$lang['strconfdropcolumn'] = 'Naozaj chceš zmazať stĺpec "%s" z tabuľky "%s"?';
	$lang['strcolumndropped']  =  'Stĺpec zmenený.';
	$lang['strcolumndroppedbad'] = 'Stĺpec nebol zmazaný.';
	$lang['straddcolumn'] = 'Pridať Stĺpec';
	$lang['strcolumnadded'] = 'Stĺpec pridaný.';
	$lang['strcolumnaddedbad'] = 'Stĺpec nebol pridaný.';
	$lang['strcascade']  =  'CASCADE';
	$lang['strtablealtered']  =  'Tabuľka zmenená.';
	$lang['strtablealteredbad']  =  'Tabuľka nebola zmenená.';
	$lang['strdataonly'] = 'Iba Dáta';
	$lang['strstructureonly'] = 'Iba Štruktúra';
	$lang['strstructureanddata'] = 'Štruktúra a Dáta';
	$lang['strtabbed']  =  'Tabbed';
	$lang['strauto']  =  'Auto';
	$lang['strconfvacuumtable']  =  'Naozaj chceš vyčistiť "%s"?';
	$lang['strestimatedrowcount']  =  'Odhadovaný počet riadkov';

	// Users
	$lang['struser'] = 'Používateľ';
	$lang['strusers'] = 'Používatelia';
	$lang['strusername'] = 'Meno používateľa';
	$lang['strpassword'] = 'Heslo';
	$lang['strsuper'] = 'Superuser?';
	$lang['strcreatedb'] = 'Vytváranie DB?';
	$lang['strexpires'] = 'Expiruje';
	$lang['strsessiondefaults']  =  'Sessions defaults'; //s cim to tak suvis??:)
	$lang['strnousers'] = 'Nenájdení žiadni používatelia.';
	$lang['struserupdated'] = 'Požívatelia zmenení.';
	$lang['struserupdatedbad'] = 'Použivatelia neboli zmenení.';
	$lang['strshowallusers'] = 'Zobraziť Všetkých Používateľov';
	$lang['strcreateuser'] = 'Vytvoriť používateľa';
	$lang['struserneedsname'] = 'Musíš zadať meno pre svojho používateľa.';
	$lang['strusercreated'] = 'Používateľ vytvorený.';
	$lang['strusercreatedbad']  =  'Používateľ nebol vytvorený.';
	$lang['strconfdropuser']  =  'Naozaj chceš zmazať používateľa "%s"?';
	$lang['struserdropped'] = 'Používateľ zmazaný.';
	$lang['struserdroppedbad'] = 'Používateľ nebol zmazaný.';

	// Groups
	$lang['straccount'] = 'Konto';
	$lang['strchangepassword'] = 'Zmeniť Heslo';
	$lang['strpasswordchanged'] = 'Heslo zmenené.';
	$lang['strpasswordchangedbad'] = 'Heslo NEBOLO zmenené.';
	$lang['strpasswordshort'] = 'Heslo je príliš krátke.';
	$lang['strpasswordconfirm']  =  'Heslo sa nezhoduje so zadaným overovacím heslom.';
	
	// Groups
	$lang['strgroup'] = 'Skupina';
	$lang['strgroups'] = 'Skupiny';
	$lang['strnogroup'] = 'Skupina nenájdená.';
	$lang['strnogroups'] = 'Žiadne skupiny nenájdené.';
	$lang['strcreategroup'] = 'Vytvoriť Skupinu';
	$lang['strshowallgroups'] = 'Zobraziť Všetky Skupiny';
	$lang['strgroupneedsname'] = 'Musíš zadať názov pre tvoju skupinu.';
	$lang['strgroupcreated'] = 'Skupina Vytvorená.';
	$lang['strgroupcreatedbad'] = 'Skupina nebola vytvorená.';
	$lang['strconfdropgroup'] = 'Naozaj chceš zmazať skupinu "%s"?';
	$lang['strgroupdropped'] = 'Skupina zmazaná.';
	$lang['strgroupdroppedbad'] = 'Skupina nebola zmazaná.';
	$lang['strmembers']  =  'Členovia';
	$lang['straddmember'] = 'Pridať člena';
	$lang['strmemberadded'] = 'Člen pridaný.';
	$lang['strmemberaddedbad'] = 'Člen nebol pridaný.';
	$lang['strdropmember'] = 'Zmazať člena';
	$lang['strconfdropmember'] = 'Naozaj chceš zmazať cľena "%s" zo skupiny "%s"?';
	$lang['strmemberdropped'] = 'Člen zmazaný.';
	$lang['strmemberdroppedbad'] = 'Člen nebol zmazaný.';

	// Privilges
	$lang['strprivilege'] = 'Privilégiá';
	$lang['strprivileges'] = 'Privilégiá';
	$lang['strnoprivileges'] = 'Tento objekt nemá privilégiá.';
	$lang['strgrant'] = 'Povoliť';
	$lang['strrevoke'] = 'Odobrať';
	$lang['strgranted'] = 'Privilégiá pridané.';
	$lang['strgrantfailed'] = 'Privilégiá neboli pridané.';
	$lang['strgrantbad'] = 'Musíš špecifikovat aspoň jedného užívateľa/skupinu a aspoň jedno privilégium.';
	$lang['strgrantor'] = 'Prideľovateľ';
	$lang['strasterisk'] = '*';

	// Databases
	$lang['strdatabase'] = 'Databáza';
	$lang['strdatabases'] = 'Databázy';
	$lang['strshowalldatabases'] = 'Zobraziť všetky databázy';
	$lang['strnodatabase'] = 'Nenájdená žiadna Databáza.';
	$lang['strnodatabases'] = 'Nenájdené žiadne Databázy.';
	$lang['strcreatedatabase'] = 'Vytvoriť databázu';
	$lang['strdatabasename'] = 'Názov databázy';
	$lang['strdatabaseneedsname'] = 'Musíš zadať názov pre tvoju databázu.';
	$lang['strdatabasecreated'] = 'Databáza vytvorená.';
	$lang['strdatabasecreatedbad'] = 'Databáza nebola vytvorená.';
	$lang['strconfdropdatabase'] = 'Naozaj chceš zmazať databázu "%s"?';
	$lang['strdatabasedropped'] = 'Databáze zmazaná.';
	$lang['strdatabasedroppedbad'] = 'Databáza nebola zmazaná.';
	$lang['strentersql'] = 'Vložiť SQL dotaz:';
	$lang['strsqlexecuted'] = 'SQL dotaz vykonaný.';
	$lang['strvacuumgood'] = 'Vyčistenie kompletné.';
	$lang['strvacuumbad'] = 'Vyčistnie zlyhalo.';
	$lang['stranalyzegood'] = 'Analyzovanie kompletné.';
	$lang['stranalyzebad'] = 'Analyzovanie zlyhalo.';
	$lang['strreindexgood']  =  'Reindex hotový.';
	$lang['strreindexbad']  =  'Reindex zlyhal.';
	$lang['strfull']  =  'Full'; //todo - konzultovat!!
	$lang['strfreeze']  =  'Freeze'; //deto
	$lang['strforce']  =  'Force'; // -||-
	$lang['strsignalsent']  =  'Signál odoslaný.';
	$lang['strsignalsentbad']  =  'Odoslanie signálu zlyhalo.';
	$lang['strallobjects']  =  'Všetky objekty';
	$lang['strdatabasealtered']  =  'Databáza zmenená.';
	$lang['strdatabasealteredbad']  =  'Databáza nebola zmenená.';

	// Views
	$lang['strview'] = 'Náhľad';
	$lang['strviews'] = 'Náhľady';
	$lang['strshowallviews'] = 'Zobraziť Všetky Náhľady';
	$lang['strnoview'] = 'Nenájdený žiadny náhľad.';
	$lang['strnoviews'] = 'Nenájdené žiadne náhľady.';
	$lang['strcreateview'] = 'Vytvoriť Náhľad';
	$lang['strviewname'] = 'Názov náhľadu';
	$lang['strviewneedsname'] = 'Musíš zadať názov pre tvoj náhľad.';
	$lang['strviewneedsdef'] = 'Musíš zadať definíciu pre tvoj náhľad.';
	$lang['strviewneedsfields']  =  'Mušíš zvoliť stĺpce, ktoré chceš mať vo svojom náhľade.';
	$lang['strviewcreated'] = 'Náhľad vytvorený.';
	$lang['strviewcreatedbad'] = 'Náhľad nebol vytvorený.';
	$lang['strconfdropview'] = 'Naozaj chceš zmazať náhľad "%s"?';
	$lang['strviewdropped'] = 'Náhľad zmazaný.';
	$lang['strviewdroppedbad'] = 'Náhľad nebol zmazaný.';
	$lang['strviewupdated'] = 'Náhľad upravený.';
	$lang['strviewupdatedbad'] = 'Náhľad nebol upravený.';
	$lang['strviewlink']  =  'Linkujúce Kľúče';
	$lang['strviewconditions']  =  'Doplňujúce Podmienky';
	$lang['strcreateviewwiz']  =  'Vytvoriť náhľad cez \"pomocníka\"';

	// Sequences
	$lang['strsequence'] = 'Sekvencia';
	$lang['strsequences'] = 'Sekvencie';
	$lang['strshowallsequences'] = 'Zobraziť Všetky Sekvencie';
	$lang['strnosequence'] = 'Nenájdená žiadna sekvencia.';
	$lang['strnosequences'] = 'nenájdené žiadne sekvencie.';
	$lang['strcreatesequence'] = 'Vytvoriť Sekvenciu';
	$lang['strlastvalue'] = 'Posledná Hodnota';
	$lang['strincrementby'] = 'Inkrementovať od';
	$lang['strstartvalue'] = 'Start Hodnota';
	$lang['strmaxvalue'] = 'Max Hodnota';
	$lang['strminvalue'] = 'Min Hodnota';
	$lang['strcachevalue'] = 'Cache Hodnota';
	$lang['strlogcount'] = 'Log Súčet';
	$lang['striscycled'] = 'Je Cycled?';
	$lang['strsequenceneedsname'] = 'Musíš zadať názov pre tvoju sekvenciu.';
	$lang['strsequencecreated'] = 'Sekvencia vytvorená.';
	$lang['strsequencecreatedbad'] = 'Sekvencia nebola vytvorená.';
	$lang['strconfdropsequence'] = 'Naozaj chceš zmazať sekvenciu "%s"?';
	$lang['strsequencedropped'] = 'Sekvencia zmazaná.';
	$lang['strsequencedroppedbad'] = 'Sekvencia nebola zmazaná.';
	$lang['strsequencereset'] = 'Sekvencia resetovaná.';
	$lang['strsequenceresetbad'] = 'Sekvencia nebola resetovaná.';

	// Indexes
	$lang['strindex']  =  'Index';
	$lang['strindexes'] = 'Indexy';
	$lang['strindexname'] = 'Názov Indexu';
	$lang['strshowallindexes'] = 'Zobraziť Všetky Indexy';
	$lang['strnoindex'] = 'Nenájdený žiadny index.';
	$lang['strnoindexes'] = 'Nenájdené žiadne indexy.';
	$lang['strcreateindex'] = 'Vytvoriť Index';
	$lang['strtabname'] = 'Tab Meno';
	$lang['strcolumnname'] = 'Názov ståpca';
	$lang['strindexneedsname'] = 'Musíš zadať názov pre tvoj index';
	$lang['strindexneedscols'] = 'Index vyžaduje vyhovujúci počet stĺpcov.';
	$lang['strindexcreated'] = 'Index vytvorený';
	$lang['strindexcreatedbad'] = 'Index nebol vytvorený.';
	$lang['strconfdropindex'] = 'Naozaj chceš zmazať index "%s"?';
	$lang['strindexdropped'] = 'Index zmazaný.';
	$lang['strindexdroppedbad'] = 'Index nebol zmazaný.';
	$lang['strkeyname'] = 'Názov Kľúču';
	$lang['struniquekey'] = 'Unikátny Kľúč';
	$lang['strprimarykey'] = 'Primárny Kľúč';
	$lang['strindextype'] = 'Typ indexu';
	$lang['strtablecolumnlist'] = 'Stĺpce v Tabuľke';
	$lang['strindexcolumnlist'] = 'Stľpce v Indexe';
	$lang['strconfcluster'] = 'Naozaj chceš vytvoriť cluster "%s"?';
	$lang['strclusteredgood'] = 'Cluster hotový.';
	$lang['strclusteredbad'] = 'Cluster nebol vytvorený.';
$lang['strcluster']  =  'Cluster';

	// Rules
	$lang['strrules'] = 'Pravidlá';
	$lang['strrule'] = 'Pravidlo';
	$lang['strshowallrules'] = 'Zobraziť Všetky Pravidlá';
	$lang['strnorule'] = 'Nenájdené žiadne pravidlo.';
	$lang['strnorules'] = 'Nenájdené žiadne pravidlá.';
	$lang['strcreaterule'] = 'Vytvoriť pravidlo';
	$lang['strrulename'] = 'Názov pravidla';
	$lang['strruleneedsname'] = 'Musíš zadať názov pre tvoje pravidlo.';
	$lang['strrulecreated'] = 'Pravidlo vytvorené.';
	$lang['strrulecreatedbad'] = 'Pravidlo nebolo vytvorené.';
	$lang['strconfdroprule'] = 'Naozaj chceš zmazať pravidlo "%s" na "%s"?';
	$lang['strruledropped'] = 'Pravidlo zmazané.';
	$lang['strruledroppedbad'] = 'Pravidlo nebolo zmazané.';

	// Constraints
	$lang['strconstraint']  =  'Obmedzenie';
	$lang['strconstraints'] = 'Obmedzenia';
	$lang['strshowallconstraints'] = 'Zobraziť Všetky Obmedzenia';
	$lang['strnoconstraints'] = 'Nenájdené žiadne obmedzenie.';
	$lang['strcreateconstraint'] = 'Vytvoriť Obmedzenie';
	$lang['strconstraintcreated'] = 'Obmedzenie vytvorené.';
	$lang['strconstraintcreatedbad'] = 'Obmedzenie nebolo vytvorené.';
	$lang['strconfdropconstraint'] = 'Naozaj chceš zmazať obmedzenie "%s" na "%s"?';
	$lang['strconstraintdropped'] = 'Obmedzenie zmazané.';
	$lang['strconstraintdroppedbad'] = 'Obmedzenie nebolo zmazané.';
	$lang['straddcheck'] = 'Pridať Overovanie';
	$lang['strcheckneedsdefinition'] = 'Overovanie Obmedzenia vyžaduje jeho definovanie.';
	$lang['strcheckadded'] = 'Overovanie obmedzenia pridané.';
	$lang['strcheckaddedbad'] = 'Overovanie obmedzenia nebolo pridané.';
	$lang['straddpk'] = 'Pridať Primárny Kľúč';
	$lang['strpkneedscols'] = 'Primárny kľúč vyžaduje aspoň jeden stĺpec.';
	$lang['strpkadded'] = 'Primárny kľúč pridaný.';
	$lang['strpkaddedbad'] = 'Primárny kľúč nebol pridaný.';
	$lang['stradduniq'] = 'Pridať Unikátny Kľúč';
	$lang['struniqneedscols'] = 'Unikátny kľúč vyžaduje aspoň jeden stĺpec.';
	$lang['struniqadded'] = 'Unikátny kľúč pridaný.';
	$lang['struniqaddedbad'] = 'Unikátny kľúč nebol pridaný.';
	$lang['straddfk'] = 'Pridať Cudzí Kľúč';
	$lang['strfkneedscols'] = 'Cudzí kľúč vyžaduje aspoň jeden stĺpec.';
	$lang['strfkneedstarget'] = 'Cudzí kľúč vyžaduje cieľovú tabuľku.';
	$lang['strfkadded'] = 'Cudzí kľúč pridaný.';
	$lang['strfkaddedbad'] = 'Cudzí kľúč nebol pridaný.';
	$lang['strfktarget'] = 'Cieľová tabuľka';
	$lang['strfkcolumnlist'] = 'Stľpce v kľúči';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';

	// Functions
	$lang['strfunction'] = 'Funkcia';
	$lang['strfunctions'] = 'Funkcie';
	$lang['strshowallfunctions'] = 'Zobraziť vŠetky funkcie';
	$lang['strnofunction'] = 'Nenájdená žiadna funkcia.';
	$lang['strnofunctions'] = 'Nenájdené žiadne funkcie.';
	$lang['strcreateplfunction']  =  'Vytvoriť SQL/PL funkciu';
	$lang['strcreateinternalfunction']  =  'Vytvoriť internú funkciu';
	$lang['strcreatecfunction']  =  'Vytvoriť C funkciu';
	$lang['strfunctionname'] = 'Názov funkcie';
	$lang['strreturns'] = 'Vracia';
	$lang['strarguments'] = 'Argumenty';
	$lang['strproglanguage'] = 'Jazyk';
	$lang['strfunctionneedsname'] = 'Musíš zadať názov pre tvoju funkciu.';
	$lang['strfunctionneedsdef'] = 'Musíš zadať definíciu pre tvoju funkciu.';
	$lang['strfunctioncreated'] = 'Funkcia vytvorená.';
	$lang['strfunctioncreatedbad'] = 'Funkcia nebola vytvorená.';
	$lang['strconfdropfunction'] = 'Si si istý, že chceš zmazať funkciu "%s"?';
	$lang['strfunctiondropped'] = 'Funkcia zmazaná.';
	$lang['strfunctiondroppedbad'] = 'Funkcia nebola zmazaná.';
	$lang['strfunctionupdated'] = 'Funkcia upravená.';
	$lang['strfunctionupdatedbad'] = 'Funkcia nebola upravená.';
	$lang['strobjectfile']  =  'Objektový súbor';
	$lang['strlinksymbol']  =  'Link symbol';

	// Triggers
	$lang['strtrigger'] = 'Trigger'; //su to medzipravidla ?? po cesky spouste..
	$lang['strtriggers'] = 'Trigger-y';
	$lang['strshowalltriggers'] = 'Zobraziť Všetky Trigger-y';
	$lang['strnotrigger'] = 'Nenájdený žiadny Trigger.';
	$lang['strnotriggers'] = 'Nenájdené žiadne Trigger-y.';
	$lang['strcreatetrigger'] = 'Vytvoriť Trigger';
	$lang['strtriggerneedsname'] = 'Musíš zadať názov pre tvoj Trigger.';
	$lang['strtriggerneedsfunc'] = 'Musíš zadať funkciu pre tvoj Trigger.';
	$lang['strtriggercreated'] = 'Trigger vytvorený.';
	$lang['strtriggercreatedbad'] = 'Trigger nebol vytvorený.';
	$lang['strconfdroptrigger'] = 'Naozaj chceš zmazať Trigger "%s" na "%s"?';
	$lang['strtriggerdropped'] = 'Trigger zmazaný.';
	$lang['strtriggerdroppedbad'] = 'Trigger nebol zmazaný.';
	$lang['strtriggeraltered']  =  'Trigger zmenený.';
	$lang['strtriggeralteredbad']  =  'Trigger nebol zmenený.';
	$lang['strforeach']  =  'Pre každých';

	// Types
	$lang['strtype'] = 'Typ';
	$lang['strtypes'] = 'Typy';
	$lang['strshowalltypes'] = 'Zobraziť Všetky typy';
	$lang['strnotype'] = 'Nenájdený žiadny typ.';
	$lang['strnotypes'] = 'Nenájdené žiadne typy.';
	$lang['strcreatetype'] = 'Vytvoriť Typ';
	$lang['strcreatecomptype']  =  'Vytvoriť kompozitný typ';
	$lang['strtypeneedsfield']  =  'Musíš vybrať aspoň jedno pole.';
	$lang['strtypeneedscols']  =  'Musíš zadať správny počet polí.';	
	$lang['strtypename'] = 'Názov typu';
	$lang['strinputfn'] = 'Vstupná funkcia';
	$lang['stroutputfn'] = 'Výstupná funkcia';
	$lang['strpassbyval'] = 'Passed by val?';
	$lang['stralignment'] = 'Alignment';
	$lang['strelement'] = 'Element';
	$lang['strdelimiter'] = 'Delimiter';
	$lang['strstorage'] = 'Storage';
	$lang['strfield']  =  'Pole';
	$lang['strnumfields']  =  'Počet polí';
	$lang['strtypeneedsname'] = 'Musíš zadať názov pre tvoj typ.';
	$lang['strtypeneedslen'] = 'Musíš zadať dĺžku pre tvoj typ.';
	$lang['strtypecreated'] = 'Typ Vytvorený';
	$lang['strtypecreatedbad'] = 'Typ nebol vytvorený.';
	$lang['strconfdroptype'] = 'Naozaj chceš zmazať typ "%s"?';
	$lang['strtypedropped'] = 'Typ zmazaný.';
	$lang['strtypedroppedbad'] = 'Typ nebol zmazaný.';
	$lang['strflavor']  =  'Flavor'; //todo
	$lang['strbasetype']  =  'Základný';
	$lang['strcompositetype']  =  'Kompozitný';
	$lang['strpseudotype']  =  'Pseudo';

	// Schemas
	$lang['strschema'] = 'Schéma';
	$lang['strschemas'] = 'Schémy';
	$lang['strshowallschemas'] = 'Zobraziť Všetky Schémy';
	$lang['strnoschema'] = 'Nenájdená žiadna schéma.';
	$lang['strnoschemas'] = 'Nenájdené žiadne schémy.';
	$lang['strcreateschema'] = 'Vytvoriť Schému';
	$lang['strschemaname'] = 'Názov Schémy';
	$lang['strschemaneedsname'] = 'Musíš zadať názov pre tvoju schému.';
	$lang['strschemacreated'] = 'Schéma vytvorená';
	$lang['strschemacreatedbad'] = 'Schéma nebola vytvorená.';
	$lang['strconfdropschema'] = 'Naozaj chceš zmazať schému "%s"?';
	$lang['strschemadropped'] = 'Schéma zmazaná.';
	$lang['strschemadroppedbad'] = 'Schéma nebola zmazaná.';
	$lang['strschemaaltered']  =  'Schéma zmenená.';
	$lang['strschemaalteredbad']  =  'Schéma nebola zmenená.';
	$lang['strsearchpath']  =  'Cesta k nájdeniu Schémy';

	// Reports

	//Domains
	$lang['strdomain'] = 'Doména';
	$lang['strdomains'] = 'Domény';
	$lang['strshowalldomains'] = 'Zobraziť Všetky Domény';
	$lang['strnodomains'] = 'Nenájdené žiadne domény.';
	$lang['strcreatedomain']  =  'Vytvoriť doménu';
	$lang['strdomaindropped'] = 'Doména zmazaná.';
	$lang['strdomaindroppedbad'] = 'Doména nebola zmazaná.';
	$lang['strconfdropdomain'] = 'Naozaj chceš zmazať doménu "%s"?';
	$lang['strdomainneedsname'] = 'Musíš zadať názov pre tvoju doménu.';
	$lang['strdomaincreated'] = 'Doména vytvorená.';
	$lang['strdomaincreatedbad'] = 'Doména nebola vytvorená.';
	$lang['strdomainaltered'] = 'Doména zmenená.';
	$lang['strdomainalteredbad'] = 'Doména nebola zmenená.';

	//Operators
	$lang['stroperator'] = 'Operátor';
	$lang['stroperators']  =  'Operátory';
	$lang['strshowalloperators'] = 'Zobraziť Všetky Operátory';
	$lang['strnooperator'] = 'Nenájdený žiadny operátor.';
	$lang['strnooperators'] = 'Nenájdené žiadne operátory.';
	$lang['strcreateoperator'] = 'Vytvoriť Operátor';
	$lang['strleftarg'] = 'Ľavý Arg Typ';
	$lang['strrightarg']  =  'Pravý Arg Typ';
	$lang['strcommutator'] = 'Komutátor';
	$lang['strnegator'] = 'Negátor';
	$lang['strrestrict'] = 'Obmedziť';
	$lang['strjoin'] = 'Join';
	$lang['strhashes'] = 'Hashes';
	$lang['strmerges'] = 'Merges';
	$lang['strleftsort'] = 'Ľavý sort';
	$lang['strrightsort'] = 'Pravý sort';
	$lang['strlessthan'] = 'Menej ako';
	$lang['strgreaterthan'] = 'Viac ako';
	$lang['stroperatorneedsname'] = 'Musíš zadať názov pre tvoj operátor.';
	$lang['stroperatorcreated'] = 'Operátor vytvorený';
	$lang['stroperatorcreatedbad'] = 'Operátor nebol vytvorený.';
	$lang['strconfdropoperator'] = 'Naozaj chceš zmazať operátor "%s"?';
	$lang['stroperatordropped'] = 'Operátor zmazaný.';
	$lang['stroperatordroppedbad'] = 'Operátor nebol zmazaný.';

	//Casts
	$lang['strcasts'] = 'Cast-y';
	$lang['strnocasts'] = 'Nenájdené žiadne Cast-y.';
	$lang['strsourcetype'] = 'Zdrojový typ';
	$lang['strtargettype'] = 'Cieľový typ';
	$lang['strimplicit'] = 'Implicitný';
	$lang['strinassignment'] = 'V priradení';
	$lang['strbinarycompat'] = '(Binárne identické)';

	// Conversions
	$lang['strconversions'] = 'Konverzie';
	$lang['strnoconversions'] = 'Nenájdené žiadne konverzie.';
	$lang['strsourceencoding'] = 'Zdojové kódovanie';
	$lang['strtargetencoding'] = 'Cieľové kódovanie';
	
	// Languages
	$lang['strlanguages'] = 'Jazyky';
	$lang['strnolanguages'] = 'Nenájdené žiadne jazyky.';
	$lang['strtrusted'] = 'Trusted';
	
	// Info
	$lang['strnoinfo'] = 'Informácie nedostupné.';
	$lang['strreferringtables'] = 'Referujúce tabuľky';
	$lang['strparenttables'] = 'Rodičovské tabuľky';
	$lang['strchildtables'] = 'Dcérske tabuľky';

	// Aggregates
	$lang['straggregates']  =  'Agregáty';
	$lang['strnoaggregates']  =  'Nenájdené žiadne agregáty.';
	$lang['stralltypes']  =  '(Všetky typy)';

	// Operator Classes
	$lang['stropclasses']  =  'Op Triedy';
	$lang['strnoopclasses']  =  'Nenájdené žiadne op. triedy.';
	$lang['straccessmethod']  =  'Prístupové metódy';

	// Stats and performance
	$lang['strrowperf']  =  'Výkonnosť Riadku'; //to znie dost tupo..
	$lang['strioperf']  =  'I/O Výkon';
	$lang['stridxrowperf']  =  'Výkonnosť Indexovania Riadkov';
	$lang['stridxioperf']  =  'Index I/O Výkon';
	$lang['strpercent']  =  '%';
	$lang['strsequential']  =  'Sekvenčný';
	$lang['strscan']  =  'Scan'; //co s tymto tu???
	$lang['strread']  =  'Načítať';
	$lang['strfetch']  =  'Získať';
	$lang['strheap']  =  'Heap';
	$lang['strtoast']  =  'TOAST';
	$lang['strtoastindex']  =  'TOAST Index';
	$lang['strcache']  =  'Cache';
	$lang['strdisk']  =  'Disk';
	$lang['strrows2']  =  'Riadkov';

	// Tablespaces
	$lang['strtablespace']  =  'Priestor pre tabuľku';
	$lang['strtablespaces']  =  'Priestory tabuliek';
	$lang['strshowalltablespaces']  =  'Zobraziť všetky priestory pre tabuľky';
	$lang['strnotablespaces']  =  'Nenájdené žiadne priestory tabuliek.';
	$lang['strcreatetablespace']  =  'Vytvoriť priestor pre tabuľku';
	$lang['strlocation']  =  'Umiestnenie';
	$lang['strtablespaceneedsname']  =  'Musíš zadať názov priestoru tabuľky.';
	$lang['strtablespaceneedsloc']  =  'Musíš zadať adresár, vktorom sa má vytvoriť priestor pre tabuľku.';
	$lang['strtablespacecreated']  =  'Priestor pre tabuľku bol vytvorený.';
	$lang['strtablespacecreatedbad']  =  'Vytvorenie priestoru pre tabuľku zlyhalo.';
	$lang['strconfdroptablespace']  =  'Naozaj chceš odstrániť priestor tabuľky "%s"?';
	$lang['strtablespacedropped']  =  'Priestor pre tabuľku bol odstránený.';
	$lang['strtablespacedroppedbad']  =  'Odstránenie priestoru zlyhalo.';
	$lang['strtablespacealtered']  =  'Priestor tabuľky zmenený.';
	$lang['strtablespacealteredbad']  =  'Zmenenie priestoru tabuľky zlyhalo.';
	

	// Miscellaneous
	$lang['strtopbar']  =  '%s beží na %s:%s -- si prihlásený ako "%s"';
	$lang['strtimefmt']  =  'jS M, Y g:iA';
	$lang['strhelp']  =  'Pomoc';
	$lang['strhelpicon']  =  '?';
	$lang['strlogintitle']  =  'Prihlasujem do %s';
	$lang['strlogoutmsg']  =  'Odhlásený z %s';
	$lang['strloading']  =  'Spracuvávam...';
	$lang['strerrorloading']  =  'Chyba spracovania';
	$lang['strclicktoreload']  =  'Klikni pre obnovenie';

?>
