<?php
	/**
	* Chinese zh_TW translation file for phpPgAdmin.
	*/

	//Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = '您尚未建立報表資料庫。請參閱指導 INSTALL 檔說明。';

	// Reports
	$plugin_lang['strreport'] = '報表';
	$plugin_lang['strreports'] = '報表';
	$plugin_lang['strshowallreports'] = '顯示全部報表';
	$plugin_lang['strnoreports'] = '找不到任何報表。';
	$plugin_lang['strcreatereport'] = '建立報表';
	$plugin_lang['strreportdropped'] = '報表已移除。';
	$plugin_lang['strreportdroppedbad'] = '報表移除已失敗。';
	$plugin_lang['strconfdropreport'] = '您確定您要移除這個報表 "%s" 嗎?';
	$plugin_lang['strreportneedsname'] = '您必需為您的報表給一個名稱。';
	$plugin_lang['strreportneedsdef'] = '您必需為您的報表給 SQL。';
	$plugin_lang['strreportcreated'] = '報表已儲存。';
	$plugin_lang['strreportcreatedbad'] = '報表儲存已失敗。';
?>
