<?php
	/**
	 * Swedish language file.
	 */

	// Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'Du har inte skapat någon rapportdatabas. Läs filen INSTALL för instruktioner.';

	// Reports
	$plugin_lang['strreport'] = 'Rapport';
	$plugin_lang['strreports'] = 'Rapporter';
	$plugin_lang['strshowallreports'] = 'Visa alla rapporter';
	$plugin_lang['strtopbar'] = '%s körs på %s:%s -- Du är inloggad som användare "%s"';
	$plugin_lang['strtimefmt'] = 'jS M, Y g:iA';
	$plugin_lang['strnoreports'] = 'Hittade inga rapporter.';
	$plugin_lang['strcreatereport'] = 'Skapa rapport';
	$plugin_lang['strreportdropped'] = 'Rapport skapad.';
	$plugin_lang['strreportcreated'] = 'Rapport sparad.';
	$plugin_lang['strreportneedsname'] = 'Du måste namnge din rapport.';
	$plugin_lang['strreportcreatedbad'] = 'Misslyckades att spara rapport.';
	$plugin_lang['strreportdroppedbad'] = 'Misslyckades att skapa rapport.';
	$plugin_lang['strconfdropreport'] = 'Är du säker på att du vill radera rapporten "%s"?';
	$plugin_lang['strreportneedsdef'] = 'Du måste ange din SQL-fråga.';
?>
