<?php
/**
* Chinese language file for phpPgAdmin.
*
* $Id: chinese-utf8-zh_CN.php,v 1.6 2013/04/15 cozhan $
*/
	
	// Language and character set
	$lang['applang'] = '简体中文（统一码）';
	$lang['applocale'] = 'zh-CN.UTF-8';
	$lang['applangdir'] = 'ltr';
	
	// Welcome
	$lang['strintro'] = '欢迎使用 phpPgAdmin。';
	$lang['strppahome'] = 'phpPgAdmin 主页';
	$lang['strpgsqlhome'] = 'PostgreSQL 主页';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQL 文档 (本地)';
	$lang['strreportbug'] = '报告 Bug';
	$lang['strviewfaq'] = '查看在线 FAQ';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';
	
	// Basic strings
	$lang['strlogin'] = '登录';
	$lang['strloginfailed'] = '登录失败';
	$lang['strlogindisallowed'] = '出于安全原因禁止登录。';
	$lang['strserver'] = '服务器';
	$lang['strservers'] = '服务器';
	$lang['strgroupservers']  =  '群组"%s"中的服务器';
	$lang['strallservers']  =  '所有服务器';
	$lang['strintroduction'] = '介绍';
	$lang['strhost'] = '主机';
	$lang['strport'] = '端口';
	$lang['strlogout'] = '注销';
	$lang['strowner'] = '所属人';
	$lang['straction'] = '操作';
	$lang['stractions'] = '操作';
	$lang['strname'] = '名字';
	$lang['strdefinition'] = '定义';
	$lang['strproperties'] = '属性';
	$lang['strbrowse'] = '浏览';
	$lang['strenable'] = '有效';
	$lang['strdisable'] = '无效';
	$lang['strdrop'] = '删除';
	$lang['strdropped'] = '已删除';
	$lang['strnull'] = '空值';
	$lang['strnotnull'] = '非空';
	$lang['strprev'] = '前一页';
	$lang['strnext'] = '下一页';
	$lang['strfirst'] = '<< 第一页';
	$lang['strlast'] = '最后一页 >>';
	$lang['strfailed'] = '失败';
	$lang['strcreate'] = '创建';
	$lang['strcreated'] = '已创建';
	$lang['strcomment'] = '注释';
	$lang['strlength'] = '长度';
	$lang['strdefault'] = '默认';
	$lang['stralter'] = '变更';
	$lang['strok'] = '确认';
	$lang['strcancel'] = '取消';
	$lang['strkill']  =  '终止';
	$lang['strac'] = '自动完成有效';
	$lang['strsave'] = '保存';
	$lang['strreset'] = '重置';
	$lang['strrestart']  =  '重启';
	$lang['strinsert'] = '插入';
	$lang['strselect'] = '选择';
	$lang['strdelete'] = '删除';
	$lang['strupdate'] = '更新';
	$lang['strreferences'] = '参考';
	$lang['stryes'] = '是';
	$lang['strno'] = '否';
	$lang['strtrue'] = 'TRUE';
	$lang['strfalse'] = 'FALSE';
	$lang['stredit'] = '编辑';
	$lang['strcolumn'] = '列';
	$lang['strcolumns'] = '列';
	$lang['strrows'] = '行';
	$lang['strrowsaff'] = '行已影响（变更）。';
	$lang['strobjects'] = '对象';
	$lang['strback'] = '返回';
	$lang['strqueryresults'] = '查询结果';
	$lang['strshow'] = '显示';
	$lang['strempty'] = '清空';
	$lang['strlanguage'] = '语言';
	$lang['strencoding'] = '编码';
	$lang['strvalue'] = '值';
	$lang['strunique'] = '唯一';
	$lang['strprimary'] = '主';
	$lang['strexport'] = '导出';
	$lang['strimport'] = '导入';
	$lang['strallowednulls'] = '允许空串';
	$lang['strbackslashn'] = '\N';
	$lang['stremptystring'] = '空 字符串/字段';
	$lang['strsql'] = 'SQL码';
	$lang['stradmin'] = '管理';
	$lang['strvacuum'] = '清理';
	$lang['stranalyze'] = '分析';
	$lang['strclusterindex'] = '集群';
	$lang['strclustered'] = '集群?';
	$lang['strreindex'] = '重建索引';
	$lang['strexecute'] = '执行';
	$lang['stradd'] = '添加';
	$lang['strevent'] = '事件';
	$lang['strwhere'] = 'Where';
	$lang['strinstead'] = 'Do Instead';
	$lang['strwhen'] = '当';
	$lang['strformat'] = '格式';
	$lang['strdata'] = '数据';
	$lang['strconfirm'] = '确认';
	$lang['strexpression'] = '表达式';
	$lang['strellipsis'] = '。。。';
	$lang['strseparator'] = ': ';
	$lang['strexpand'] = '扩展';
	$lang['strcollapse'] = '崩溃';
	$lang['strfind'] = '查找';
	$lang['stroptions'] = '选项';
	$lang['strrefresh'] = '刷新';
	$lang['strdownload'] = '下载';
	$lang['strdownloadgzipped'] = '下载使用gzip压缩的文件';
	$lang['strinfo'] = '信息';
	$lang['stroids'] = 'OIDs';
	$lang['stradvanced'] = '高级';
	$lang['strvariables'] = '变量';
	$lang['strprocess'] = '进程';
	$lang['strprocesses'] = '进程';
	$lang['strsetting'] = '设置';
	$lang['streditsql'] = '编辑 SQL';
	$lang['strruntime'] = '总执行时间: %s ms';
	$lang['strpaginate'] = '分页结果';
	$lang['struploadscript'] = '或者上传一个 SQL 脚本:';
	$lang['strstarttime'] = '开始时间';
	$lang['strfile'] = '文件';
	$lang['strfileimported'] = '文件已导入。';
	$lang['strtrycred'] = '对所有服务器使用该用户名和密码';
	$lang['strconfdropcred']  =  '因为安全原因，中断连接将会销毁你的登录信息。你确定要中断连接吗？';
	$lang['stractionsonmultiplelines'] = '多行上的操作';
	$lang['strselectall'] = '选择所有';
	$lang['strunselectall'] = '取消选择所有';
	$lang['strlocale'] = '本地';
	$lang['strcollation']  =  '校对';
	$lang['strctype']  =  '字符类型';
	$lang['strdefaultvalues']  =  '默认值';
	$lang['strnewvalues']  =  '新值';
	$lang['strstart']  =  '启动';
	$lang['strstop']  =  '停止';
	$lang['strgotoppage']  =  '回到顶端';
	$lang['strtheme']  =  '主题';
	$lang['strcluster']  =  '集群';

	// Admin
	$lang['stradminondatabase'] = '以下管理功能可应用于数据库 %s.';
	$lang['stradminontable'] = '以下管理功能可应用于表 %s.';

	// User-supplied SQL history
	$lang['strhistory'] = '历史';
	$lang['strnohistory'] = '无历史.';
	$lang['strclearhistory'] = '清空历史';
	$lang['strdelhistory'] = '从历史删除';
	$lang['strconfdelhistory'] = '确定要从历史删除吗 ?';
	$lang['strconfclearhistory'] = '确定要清空历史吗 ?';
	$lang['strnodatabaseselected'] = '请选择一个数据库.';
	
	// Database sizes
	$lang['strnoaccess']  =  '无法访问'; 
	$lang['strsize'] = '大小';
	$lang['strbytes'] = '字节';
	$lang['strkb'] = 'kB';
	$lang['strmb'] = 'MB';
	$lang['strgb'] = 'GB';
	$lang['strtb'] = 'TB';
	
	// Error handling
	$lang['strnoframes'] = '该程序在具有框架功能的浏览器上工作的更好，请按下面的链接在不支持框架的浏览器上工作。';
	$lang['strnoframeslink'] = '不使用框架';
	$lang['strbadconfig'] = '您的 config.inc.php 已失效。您需要自行通过 config.inc.php-ist 恢复。';
	$lang['strnotloaded'] = '您安装的 PHP 不支持PostgreSQL。 你需要重新编译PHP并使用 --with-pgsql 配置选项。';
	$lang['strpostgresqlversionnotsupported'] = '旧版本的PostgreSQL不被支持。 请更新到版本 %s 或更高版本。';
	$lang['strbadschema'] = '无效的模式。';
	$lang['strbadencoding'] = '设定客户端编码错误。';
	$lang['strsqlerror'] = 'SQL:错误';
	$lang['strinstatement'] = '在语句：';
	$lang['strinvalidparam'] = '无效的脚本参数。';
	$lang['strnodata'] = '查无数据行。';
	$lang['strnoobjects'] = '查无对象。';
	$lang['strrownotunique'] = '该行无唯一约束。';
	$lang['strnouploads'] = '文件上传被禁止。';
	$lang['strimporterror'] = '导入错误。';
	$lang['strimporterror-fileformat'] = '导入错误: 自动识别文件类型失败。';
	$lang['strimporterrorline'] = '导入错误，出错行 %s。';
	$lang['strimporterrorline-badcolumnnum'] = '导入错误，出错行 %s:  该行列数不正确。';
	$lang['strimporterror-uploadedfile'] = '导入错误: 文件不能上传到服务器';
	$lang['strcannotdumponwindows'] = '复杂表和模式名称的转储在Windows 不被支持。';
	$lang['strinvalidserverparam'] = '尝试用无效的服务器参数连接,可能有人正尝试攻击你的系统。';
	$lang['strnoserversupplied'] = '没有选择数据库!';
	$lang['strbadpgdumppath']  =  '导出错误：在 conf/config.inc.php 中指定的路径 %s 下执行pg_dump失败。请在配置中修改路径并重新登录。';
	$lang['strbadpgdumpallpath']  =  '导出错误：在 conf/config.inc.php 中指定的路径 %s 下执行pg_dumpall失败。请在配置中修改路径并重新登录。';
	$lang['strconnectionfail']  =  '无法连接服务器。';
	
	// Tables
	$lang['strtable'] = '数据表';
	$lang['strtables'] = '数据表';
	$lang['strshowalltables'] = '显示示所有表。';
	$lang['strnotables'] = '查无数据表。';
	$lang['strnotable'] = '查无此表。';
	$lang['strcreatetable'] = '创建表';
	$lang['strcreatetablelike'] = '创建表(以现有表为模板)';
	$lang['strcreatetablelikeparent'] = '源表';
	$lang['strcreatelikewithdefaults'] = '包含默认值';
	$lang['strcreatelikewithconstraints'] = '包含约束';
	$lang['strcreatelikewithindexes'] = '包含表名';
	$lang['strtablename'] = '表名';
	$lang['strtableneedsname'] = '必须指定表名。';
	$lang['strtablelikeneedslike'] = '必须指定要拷贝的属性所属的数据表.';
	$lang['strtableneedsfield'] = '必须至少指定一个字段。';
	$lang['strtableneedscols'] = '必须指定一个有效的列数。';
	$lang['strtablecreated'] = '数据表已创建。';
	$lang['strtablecreatedbad'] = '数据表创建失败';
	$lang['strconfdroptable'] = '确定要删除"%s"数据表吗？';
	$lang['strtabledropped'] = '数据表已删除。';
	$lang['strtabledroppedbad'] = '数据表删除失败。';
	$lang['strconfemptytable'] = '确定要清空"%s"数据表吗？';
	$lang['strtableemptied'] = '数据表已清空。';
	$lang['strtableemptiedbad'] = '数据表清空失败。';
	$lang['strinsertrow'] = '插入行';
	$lang['strrowinserted'] = '行已插入。';
	$lang['strrowinsertedbad'] = '行插入失败。';
	$lang['strnofkref']  =  '在外键 %s 中找不到相应的值。';
	$lang['strrowduplicate'] = '行插入失败, 尝试再次插入。';
	$lang['streditrow'] = '编辑行';
	$lang['strrowupdated'] = '行已更新。';
	$lang['strrowupdatedbad'] = '行更新失败。';
	$lang['strdeleterow'] = '删除行';
	$lang['strconfdeleterow'] = '确定要删除该行吗？';
	$lang['strrowdeleted'] = '行已删除。';
	$lang['strrowdeletedbad'] = '行删除失败。';
	$lang['strinsertandrepeat'] = '插入 & 替换';
	$lang['strnumcols'] = '列数目';
	$lang['strcolneedsname'] = '必须指定列名';
	$lang['strselectallfields'] = '选择所有字段';
	$lang['strselectneedscol'] = '必须至少显示一列。';
	$lang['strselectunary'] = '单项操作不能有值。';
	$lang['strcolumnaltered'] = '列已变更。';
	$lang['strcolumnalteredbad'] = '列变更失败。';
	$lang['strconfdropcolumn'] = '确定要将列 "%s" 从表 "%s" 中删除吗?';
	$lang['strcolumndropped'] = '列已删除。';
	$lang['strcolumndroppedbad'] = '列删除失败。';
	$lang['straddcolumn'] = '添加列';
	$lang['strcolumnadded'] = '列已添加。';
	$lang['strcolumnaddedbad'] = '列添加失败。';
	$lang['strcascade'] = 'CASCADE';
	$lang['strtablealtered'] = '数据表已变更。';
	$lang['strtablealteredbad'] = '数据表变更失败。';
	$lang['strdataonly'] = '仅数据';
	$lang['strstructureonly'] = '仅结构';
	$lang['strstructureanddata'] = '结构和数据';
	$lang['strtabbed'] = '固定（Tabbed）';
	$lang['strauto'] = '自动';
	$lang['strconfvacuumtable'] = '确定要清理 "%s" 吗?';
	$lang['strconfanalyzetable'] = '确定要分析 "%s" 吗?';
	$lang['strconfreindextable']  =  '确定要重新索引 "%s" 吗?';
	$lang['strconfclustertable']  =  '确定要集群 "%s" 吗?';
	$lang['strestimatedrowcount'] = '估计的行数';
	$lang['strspecifytabletoanalyze'] = '必须至少选择一个表来分析';
	$lang['strspecifytabletoempty'] = '必须至少选择一个表来清空';
	$lang['strspecifytabletodrop'] = '必须至少选择一个表来移除';
	$lang['strspecifytabletovacuum'] = '必须至少选择一个表来清理（vacuum）';
	$lang['strspecifytabletoreindex']  =  '必须至少选择一个要重新索引的表。';
	$lang['strspecifytabletocluster']  =  '必须至少选择一个要集群的表。';
	$lang['strnofieldsforinsert']  =  '无法在没有任何列定义的表中插入数据。';
	
	// Columns
	$lang['strcolprop'] = '列属性';
	$lang['strnotableprovided'] = '没有相应的表!';
	
	// Users
	$lang['struser'] = '用户';
	$lang['strusers'] = '用户';
	$lang['strusername'] = '用名';
	$lang['strpassword'] = '密码';
	$lang['strsuper'] = '超级用户';
	$lang['strcreatedb'] = '创建数据库？';
	$lang['strexpires'] = '过期';
	$lang['strsessiondefaults'] = '会话默认';
	$lang['strnousers'] = '查无此用户。';
	$lang['struserupdated'] = '用户已更新。';
	$lang['struserupdatedbad'] = '用户更新失败。';
	$lang['strshowallusers'] = '显示所有用户';
	$lang['strcreateuser'] = '创建用户';
	$lang['struserneedsname'] = '必须指定用户名称。';
	$lang['strusercreated'] = '用户已创建。';
	$lang['strusercreatedbad'] = '用户创建失败。';
	$lang['strconfdropuser'] = '确定要删除用户"%s"吗？';
	$lang['struserdropped'] = '用户已删除。';
	$lang['struserdroppedbad'] = '用户删除失败。';
	$lang['straccount'] = '帐户';
	$lang['strchangepassword'] = '修改密码';
	$lang['strpasswordchanged'] = '密码已修改。';
	$lang['strpasswordchangedbad'] = '密码修改失败。';
	$lang['strpasswordshort'] = '密码太短了。';
	$lang['strpasswordconfirm'] = '密码不匹配。';
	
	// Groups
	$lang['strgroup'] = '群组';
	$lang['strgroups'] = '群组';
	$lang['strgroupgroups']  =  '在"%s"中的群组';
	$lang['strshowallgroups'] = '显示所有群组';
	$lang['strnogroup'] = '查无此群组。';
	$lang['strnogroups'] = '查无群组。';
	$lang['strcreategroup'] = '创建群组';
	$lang['strgroupneedsname'] = '必须指定群组名称。';
	$lang['strgroupcreated'] = '群组已创建。';
	$lang['strgroupcreatedbad'] = '群组创建失败。';
	$lang['strconfdropgroup'] = '确定要删除群组"%s"吗？';
	$lang['strgroupdropped'] = '群组已删除。';
	$lang['strgroupdroppedbad'] = '群组删除失败。';
	$lang['strmembers'] = '成员';
	$lang['strmemberof'] = '所属成员';
	$lang['stradminmembers'] = '管理成员';
	$lang['straddmember'] = '添加成员';
	$lang['strmemberadded'] = '成员已添加。';
	$lang['strmemberaddedbad'] = '成员添加失败。';
	$lang['strdropmember'] = '删除成员';
	$lang['strconfdropmember'] = '确定要将成员 "%s" 从群组 "%s"中删除吗?';
	$lang['strmemberdropped'] = '成员已删除。';
	$lang['strmemberdroppedbad'] = '成员删除失败。';
	
	// Roles
	$lang['strrole'] = '角色';
	$lang['strroles'] = '角色';
	$lang['strshowallroles'] = '显示所有角色';
	$lang['strnoroles'] = '查无角色。';
	$lang['strinheritsprivs'] = '继承权限?';
	$lang['strcreaterole'] = '创建角色';
	$lang['strcancreaterole'] = '创建角色?';
	$lang['strrolecreated'] = '角色已创建。';
	$lang['strrolecreatedbad'] = '角色创建失败。';
	$lang['strrolealtered'] = '角色已变更。';
	$lang['strrolealteredbad'] = '角色变更失败。';
	$lang['strcanlogin'] = '可以登录?';
	$lang['strconnlimit'] = '连接限制';
	$lang['strdroprole'] = '删除角色';
	$lang['strconfdroprole'] = '确定要删除角色 "%s"吗?';
	$lang['strroledropped'] = '角色已删除。';
	$lang['strroledroppedbad'] = '角色删除失败。';
	$lang['strnolimit'] = '无限制';
	$lang['strnever'] = '从不';
	$lang['strroleneedsname'] = '必须指定角色名称。';
	
	// Privileges
	$lang['strprivilege'] = '权限';
	$lang['strprivileges'] = '权限';
	$lang['strnoprivileges'] = '这个对象拥有默认所属人的权限。';
	$lang['strgrant'] = '赋予';
	$lang['strrevoke'] = '撤回';
	$lang['strgranted'] = '权限已改变';
	$lang['strgrantfailed'] = '权限改变失败';
	$lang['strgrantbad'] = '必须指定至少一个用户或一个组和一个权限。';
	$lang['strgrantor'] = '赋予者';
	$lang['strasterisk'] = '*';
	
	// Databases
	$lang['strdatabase'] = '数据库';
	$lang['strdatabases'] = '数据库';
	$lang['strshowalldatabases'] = '显示所有数据库';
	$lang['strnodatabases'] = '查无数据库。';
	$lang['strcreatedatabase'] = '创建数据库';
	$lang['strdatabasename'] = '数据库名称';
	$lang['strdatabaseneedsname'] = '必须指定数据库名称。';
	$lang['strdatabasecreated'] = '数据库已创建。';
	$lang['strdatabasecreatedbad'] = '数据库创建失败。';
	$lang['strconfdropdatabase'] = '确定要删除数据库"%s"吗？';
	$lang['strdatabasedropped'] = '数据库已删除。';
	$lang['strdatabasedroppedbad'] = '数据库删除失败';
	$lang['strentersql'] = '请在下方输入要执行的SQL语句：';
	$lang['strsqlexecuted'] = 'SQL 已执行。';
	$lang['strvacuumgood'] = '清理完成';
	$lang['strvacuumbad'] = '清理失败';
	$lang['stranalyzegood'] = '分析完成';
	$lang['stranalyzebad'] = '分析失败';
	$lang['strreindexgood'] = '重建索引完成。';
	$lang['strreindexbad'] = '重建索引失败。';
	$lang['strfull'] = '完全';
	$lang['strfreeze'] = '冻结';
	$lang['strforce'] = '强制';
	$lang['strsignalsent'] = '信号已发送。';
	$lang['strsignalsentbad'] = '信号发送失败。';
	$lang['strallobjects'] = '所有对象';
	$lang['strdatabasealtered'] = '数据库已变更。';
	$lang['strdatabasealteredbad'] = '数据库变更失败。';
	$lang['strspecifydatabasetodrop'] = '必须至少指定一个要移除的数据库';
	$lang['strtemplatedb']  =  '模板';
	$lang['strconfanalyzedatabase']  =  '你确定要分析数据库"%s"中的所有表吗?';
	$lang['strconfvacuumdatabase']  =  '你确定要清理数据库"%s"中的所有表吗?';
	$lang['strconfreindexdatabase']  =  '你确定要重新索引数据库"%s"中的所有表吗?';
	$lang['strconfclusterdatabase']  =  '你确定要集群数据库"%s"中的所有表吗?';
	
	// Views
	$lang['strview'] = '视图';
	$lang['strviews'] = '视图';
	$lang['strshowallviews'] = '显示所有视图';
	$lang['strnoview'] = '查无此视图';
	$lang['strnoviews'] = '查无视图。';
	$lang['strcreateview'] = '创建视图';
	$lang['strviewname'] = '视图名称';
	$lang['strviewneedsname'] = '必须指定视图名称。';
	$lang['strviewneedsdef'] = '必须指定视图定义。';
	$lang['strviewneedsfields'] = '必须指定视图里要选择的列。';
	$lang['strviewcreated'] = '视图已创建。';
	$lang['strviewcreatedbad'] = '视图创建失败。';
	$lang['strconfdropview'] = '确定要删除视图"%s"吗？';
	$lang['strviewdropped'] = '视图已删除。';
	$lang['strviewdroppedbad'] = '视图删除失败。';
	$lang['strviewupdated'] = '视图已更新。';
	$lang['strviewupdatedbad'] = '视图更新失败';
	$lang['strviewlink'] = '连接关键字（Linking keys）';
	$lang['strviewconditions'] = '附加条件';
	$lang['strcreateviewwiz'] = '使用向导创建视图';
	$lang['strrenamedupfields'] = '重命名复制的字段';
	$lang['strdropdupfields'] = '移除复制的字段';
	$lang['strerrordupfields'] = '复制字段时发生错误';
	$lang['strviewaltered'] = '视图已变更。';
	$lang['strviewalteredbad'] = '视图变更失败。';
	$lang['strspecifyviewtodrop'] = '必须至少指定一个要移除的视图';
	
	// Sequences
	$lang['strsequence'] = '序列';
	$lang['strsequences'] = '序列';
	$lang['strshowallsequences'] = '显示所有序列';
	$lang['strnosequence'] = '查无此序列';
	$lang['strnosequences'] = '查无序列。';
	$lang['strcreatesequence'] = '创建序列';
	$lang['strlastvalue'] = '最后值';
	$lang['strincrementby'] = '增量';
	$lang['strstartvalue'] = '起始值';
	$lang['strrestartvalue']  =  '重新计算';
	$lang['strmaxvalue'] = '最大值';
	$lang['strminvalue'] = '最小值';
	$lang['strcachevalue'] = '缓存值';
	$lang['strlogcount'] = '日志计数（Log count）';
	$lang['strcancycle'] = '可以循环吗?';
	$lang['striscalled'] = '将在返回下一个值前递增最后的值(is_called)吗？';
	$lang['strsequenceneedsname'] = '必须指定序列名称。';
	$lang['strsequencecreated'] = '序列已创建。';
	$lang['strsequencecreatedbad'] = '序列创建失败。';
	$lang['strconfdropsequence'] = '确定要删除序列"%s"吗？';
	$lang['strsequencedropped'] = '序列已删除。';
	$lang['strsequencedroppedbad'] = '序列删除失败。';
	$lang['strsequencerestart']  =  '重新计算序列。';
	$lang['strsequencerestartbad']  =  '序列重新计算失败。';
	$lang['strsequencereset'] = '序列已重置。';
	$lang['strsequenceresetbad'] = '序列重置失败。';
	$lang['strsequencealtered'] = '序列已变更。';
	$lang['strsequencealteredbad'] = '序列变更失败。';
	$lang['strsetval'] = '设定序列值';
	$lang['strsequencesetval'] = '序列值已设定。';
	$lang['strsequencesetvalbad'] = '序列值设置失败。';
	$lang['strnextval'] = '递增序列值';
	$lang['strsequencenextval'] = '序列值已递增。';
	$lang['strsequencenextvalbad'] = '序列值递增失败。';
	$lang['strspecifysequencetodrop'] = '必须至少指定一个序列来删除';
	
	// Indexes
	$lang['strindex'] = '索引';
	$lang['strindexes'] = '索引';
	$lang['strindexname'] = '索引名';
	$lang['strshowallindexes'] = '显示所有索引';
	$lang['strnoindex'] = '查无此索引';
	$lang['strnoindexes'] = '查无索引';
	$lang['strcreateindex'] = '创建索引';
	$lang['strtabname'] = '数据表名';
	$lang['strcolumnname'] = '列名';
	$lang['strindexneedsname'] = '必须指定索引名称。';
	$lang['strindexneedscols'] = '必须给索引指定有效的列数。';
	$lang['strindexcreated'] = '索引已创建';
	$lang['strindexcreatedbad'] = '索引创建失败。';
	$lang['strconfdropindex'] = '确定要删除"%s"索引？';
	$lang['strindexdropped'] = '索引已删除。';
	$lang['strindexdroppedbad'] = '索引删除失败。';
	$lang['strkeyname'] = '键名';
	$lang['struniquekey'] = '唯一键';
	$lang['strprimarykey'] = '主键';
	$lang['strindextype'] = '索引类型';
	$lang['strtablecolumnlist'] = '表中的列';
	$lang['strindexcolumnlist'] = '索引中的列';
	$lang['strconfcluster'] = '确定要集群 "%s"吗?';
	$lang['strclusteredgood'] = '集群完成。';
	$lang['strclusteredbad'] = '集群失败。';
	$lang['strconcurrently']  =  '并发';
	$lang['strnoclusteravailable']  =  '表中没有集群索引。';
	
	// Rules
	$lang['strrules'] = '规则';
	$lang['strrule'] = '规则';
	$lang['strshowallrules'] = '显示所有规则';
	$lang['strnorule'] = '查无此规则。';
	$lang['strnorules'] = '查无规则';
	$lang['strcreaterule'] = '创建规则';
	$lang['strrulename'] = '规则名称';
	$lang['strruleneedsname'] = '必须指定规则名称。';
	$lang['strrulecreated'] = '规则已创建。';
	$lang['strrulecreatedbad'] = '规则创建失败。';
	$lang['strconfdroprule'] = '确定要将规则"%s"从"%s"中删除吗？';
	$lang['strruledropped'] = '规则已删除。';
	$lang['strruledroppedbad'] = '规则删除失败。';
	
	// Constraints
	$lang['strconstraint'] = '约束';
	$lang['strconstraints'] = '约束';
	$lang['strshowallconstraints'] = '显示所有约束。';
	$lang['strnoconstraints'] = '查无此约束。';
	$lang['strcreateconstraint'] = '创建约束';
	$lang['strconstraintcreated'] = '约束已创建。';
	$lang['strconstraintcreatedbad'] = '约束创建失败。';
	$lang['strconfdropconstraint'] = '确定要将强制"%s"从"%s"中删除吗？';
	$lang['strconstraintdropped'] = '约束已删除。';
	$lang['strconstraintdroppedbad'] = '约束删除失败。';
	$lang['straddcheck'] = '添加检查约束';
	$lang['strcheckneedsdefinition'] = '必须指定检查约束的定义。';
	$lang['strcheckadded'] = '检查约束已添加。';
	$lang['strcheckaddedbad'] = '检查约束添加失败。';
	$lang['straddpk'] = '添加主键';
	$lang['strpkneedscols'] = '主键至少需指定一列。';
	$lang['strpkadded'] = '主键已添加。';
	$lang['strpkaddedbad'] = '主键添加失败。';
	$lang['stradduniq'] = '添加唯一键';
	$lang['struniqneedscols'] = '唯一键至少需指定一列。';
	$lang['struniqadded'] = '唯一键已添加。';
	$lang['struniqaddedbad'] = '唯一键添加失败。';
	$lang['straddfk'] = '添加外键';
	$lang['strfkneedscols'] = '外键至少需指定一列。';
	$lang['strfkneedstarget'] = '外键需指定一个目标数据表。';
	$lang['strfkadded'] = '外键已添加。';
	$lang['strfkaddedbad'] = '外键添加失败。';
	$lang['strfktarget'] = '目标数据表';
	$lang['strfkcolumnlist'] = '键中的列';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';
	
	// Functions
	$lang['strfunction'] = '函数';
	$lang['strfunctions'] = '函数';
	$lang['strshowallfunctions'] = '显示所有函数';
	$lang['strnofunction'] = '查无此函数';
	$lang['strnofunctions'] = '查无函数';
	$lang['strcreateplfunction'] = '创建 SQL/PL 函数';
	$lang['strcreateinternalfunction'] = '创建内部函数';
	$lang['strcreatecfunction'] = '创建 C 函数';
	$lang['strfunctionname'] = '函数名称';
	$lang['strreturns'] = '返回';
	$lang['strproglanguage'] = '过程语言';
	$lang['strfunctionneedsname'] = '必须指定函数名称。';
	$lang['strfunctionneedsdef'] = '必须指定函数定义。';
	$lang['strfunctioncreated'] = '函数已创建';
	$lang['strfunctioncreatedbad'] = '函数创建失败';
	$lang['strconfdropfunction'] = '确定要删除函数"%s"吗？';
	$lang['strfunctiondropped'] = '函数已删除。';
	$lang['strfunctiondroppedbad'] = '函数删除失败。';
	$lang['strfunctionupdated'] = '函数已更新。';
	$lang['strfunctionupdatedbad'] = '函数更新失败。';
	$lang['strobjectfile'] = '对象文件';
	$lang['strlinksymbol'] = '连接对象';
	$lang['strarguments'] = '参数';
	$lang['strargmode'] = '模式';
	$lang['strargtype'] = '类型';
	$lang['strargadd'] = '新添加一个参数';
	$lang['strargremove'] = '移除这个参数';
	$lang['strargnoargs'] = '该函数无参数。';
	$lang['strargenableargs'] = '使该函数的参数有效。';
	$lang['strargnorowabove'] = '在该行上面须有一行。';
	$lang['strargnorowbelow'] = '在该行下面须有一行。';
	$lang['strargraise'] = '上移。';
	$lang['strarglower'] = '下移。';
	$lang['strargremoveconfirm'] = '确定要移除这个参数吗？这个操作不能撤销。';
	$lang['strfunctioncosting'] = '函数代价(Function Costing)';
	$lang['strresultrows'] = '结果行';
	$lang['strexecutioncost'] = '执行代价';
	$lang['strspecifyfunctiontodrop'] = '必须至少指定一个函数来删除';
	
	// Triggers
	$lang['strtrigger'] = '触发器';
	$lang['strtriggers'] = '触发器';
	$lang['strshowalltriggers'] = '显示所有触发器';
	$lang['strnotrigger'] = '查无此触发器。';
	$lang['strnotriggers'] = '查无触发器。';
	$lang['strcreatetrigger'] = '创建触发器';
	$lang['strtriggerneedsname'] = '必须指定触发器名称。';
	$lang['strtriggerneedsfunc'] = '必须给触发器指定一个函数。';
	$lang['strtriggercreated'] = '触发器已创建。';
	$lang['strtriggercreatedbad'] = '触发器创建失败。';
	$lang['strconfdroptrigger'] = '确定要将触发器"%s"从"%s"中删除吗？';
	$lang['strconfenabletrigger'] = '确定要使触发器 "%s" 在 "%s"上有效吗?';
	$lang['strconfdisabletrigger'] = '确定要使触发器 "%s" 在 "%s"上无效吗?';
	$lang['strtriggerdropped'] = '触发器已删除。';
	$lang['strtriggerdroppedbad'] = '触发器删除失败。';
	$lang['strtriggerenabled'] = '触发器已有效。';
	$lang['strtriggerenabledbad'] = '触发器有效化失败。';
	$lang['strtriggerdisabled'] = '触发器已无效。';
	$lang['strtriggerdisabledbad'] = '触发器无效化失败。';
	$lang['strtriggeraltered'] = '触发器已变更。';
	$lang['strtriggeralteredbad'] = '触发器变更失败。';
	$lang['strforeach'] = '给每一个';
	
	// Types
	$lang['strtype'] = '类型';
	$lang['strtypes'] = '类型';
	$lang['strshowalltypes'] = '显示所有的类型';
	$lang['strnotype'] = '查无此类型';
	$lang['strnotypes'] = '查无类型。';
	$lang['strcreatetype'] = '创建类型';
	$lang['strcreatecomptype'] = '创建组合类型';
	$lang['strcreateenumtype'] = '创建枚举类型';
	$lang['strtypeneedsfield'] = '必须至少指定一个字段。';
	$lang['strtypeneedsvalue'] = '必须至少指定一个值';
	$lang['strtypeneedscols'] = '必须指定有效的字段数。';
	$lang['strtypeneedsvals'] = '必须指定一个有效的字段数。';
	$lang['strinputfn'] = '输入函数';
	$lang['stroutputfn'] = '输出函数';
	$lang['strpassbyval'] = '传值？';
	$lang['stralignment'] = '参数';
	$lang['strelement'] = '元素';
	$lang['strdelimiter'] = '分隔符';
	$lang['strstorage'] = '磁盘存储';
	$lang['strfield'] = '字段';
	$lang['strnumfields'] = '列数';
	$lang['strnumvalues'] = '值数';
	$lang['strtypeneedsname'] = '必须指定类型名称。';
	$lang['strtypeneedslen'] = '必须指定类型长度。';
	$lang['strtypecreated'] = '类型已创建。';
	$lang['strtypecreatedbad'] = '类型创建失败。';
	$lang['strconfdroptype'] = '确定要删除"%s"类型吗？';
	$lang['strtypedropped'] = '类型已删除。';
	$lang['strtypedroppedbad'] = '类型删除失败。';
	$lang['strflavor'] = '风格（Flavor）';
	$lang['strbasetype'] = '基本';
	$lang['strcompositetype'] = '组合';
	$lang['strpseudotype'] = '伪（Pseudo）';
	$lang['strenum'] = 'Enum';
	$lang['strenumvalues'] = '枚举类型';
	
	// Schemas
	$lang['strschema'] = '模式';
	$lang['strschemas'] = '模式';
	$lang['strshowallschemas'] = '显示所有模式';
	$lang['strnoschema'] = '查无此模式';
	$lang['strnoschemas'] = '查无模式';
	$lang['strcreateschema'] = '创建模式';
	$lang['strschemaname'] = '模式名称';
	$lang['strschemaneedsname'] = '必须指定模式名称';
	$lang['strschemacreated'] = '模式已创建';
	$lang['strschemacreatedbad'] = '模式创建失败';
	$lang['strconfdropschema'] = '确定要删除模式"%s"吗？';
	$lang['strschemadropped'] = '模式已删除';
	$lang['strschemadroppedbad'] = '模式删除失败';
	$lang['strschemaaltered'] = '模式已变更。';
	$lang['strschemaalteredbad'] = '模式变更失败。';
	$lang['strsearchpath'] = '模式查找路径';
	$lang['strspecifyschematodrop'] = '必须至少指定一个模式来删除';
	
	// Reports
	
	// Domains
	$lang['strdomain'] = '域';
	$lang['strdomains'] = '域';
	$lang['strshowalldomains'] = '显示所有域';
	$lang['strnodomains'] = '查无 域。';
	$lang['strcreatedomain'] = '创建域';
	$lang['strdomaindropped'] = '域已删除。';
	$lang['strdomaindroppedbad'] = '域删除失败。';
	$lang['strconfdropdomain'] = '确定要删除域 "%s"吗?';
	$lang['strdomainneedsname'] = '必须指定域名称。';
	$lang['strdomaincreated'] = '域已创建。';
	$lang['strdomaincreatedbad'] = '域创建失败。';
	$lang['strdomainaltered'] = '域已变更。';
	$lang['strdomainalteredbad'] = '域变更失败。';
	
	// Operators
	$lang['stroperator'] = '操作符';
	$lang['stroperators'] = '操作符';
	$lang['strshowalloperators'] = '显示所有操作符';
	$lang['strnooperator'] = '查无此操作符。';
	$lang['strnooperators'] = '查无操作符。';
	$lang['strcreateoperator'] = '创建操作符';
	$lang['strleftarg'] = '左参数类型';
	$lang['strrightarg'] = '右参数类型';
	$lang['strcommutator'] = '转换符';
	$lang['strnegator'] = '非操作符';
	$lang['strrestrict'] = '受限';
	$lang['strjoin'] = '连接';
	$lang['strhashes'] = '哈希';
	$lang['strmerges'] = '合并';
	$lang['strleftsort'] = '左排序';
	$lang['strrightsort'] = '右排序';
	$lang['strlessthan'] = '小于';
	$lang['strgreaterthan'] = '大于';
	$lang['stroperatorneedsname'] = '必须指定操作符名称。';
	$lang['stroperatorcreated'] = '操作符已创建';
	$lang['stroperatorcreatedbad'] = '操作符创建失败。';
	$lang['strconfdropoperator'] = '确定要删除操作符 "%s"吗?';
	$lang['stroperatordropped'] = '操作符已删除。';
	$lang['stroperatordroppedbad'] = '操作符删除失败。';
	
	// Casts
	$lang['strcasts'] = '类型转换';
	$lang['strnocasts'] = '查无类型转换。';
	$lang['strsourcetype'] = '源类型';
	$lang['strtargettype'] = '目标类型';
	$lang['strimplicit'] = '隐含的';
	$lang['strinassignment'] = '委派中';
	$lang['strbinarycompat'] = '(二进制兼容)';
	
	// Conversions
	$lang['strconversions'] = '编码转换';
	$lang['strnoconversions'] = '查无编码转换。';
	$lang['strsourceencoding'] = '源编码';
	$lang['strtargetencoding'] = '目标编码';
	
	// Languages
	$lang['strlanguages'] = '过程语言';
	$lang['strnolanguages'] = '查无过程语言。';
	$lang['strtrusted'] = '信任的';
	
	// Info
	$lang['strnoinfo'] = '无资料（information）可用。';
	$lang['strreferringtables'] = '查询（Referring）表';
	$lang['strparenttables'] = '父表';
	$lang['strchildtables'] = '子表';
	
	// Aggregates
	$lang['straggregate'] = '聚集';
	$lang['straggregates'] = '聚集';
	$lang['strnoaggregates'] = '查无聚集。';
	$lang['stralltypes'] = '(所有类型)';
	$lang['strcreateaggregate'] = '创建聚集';
	$lang['straggrbasetype'] = '输入数据类型';
	$lang['straggrsfunc'] = '状态转化函数';
	$lang['straggrstype'] = '状态类型';
	$lang['straggrffunc'] = '最终函数';
	$lang['straggrinitcond'] = '初始函数';
	$lang['straggrsortop'] = '排序操作符';
	$lang['strconfdropaggregate'] = '确定要删除聚集 "%s"吗?';
	$lang['straggregatedropped'] = '聚集已删除。';
	$lang['straggregatedroppedbad'] = '聚集删除失败。';
	$lang['straggraltered'] = '聚集已变更。';
	$lang['straggralteredbad'] = '聚集变更失败。';
	$lang['straggrneedsname'] = '必须指定聚集的名称';
	$lang['straggrneedsbasetype'] = '必须指定聚集的输入数据类型';
	$lang['straggrneedssfunc'] = '必须指定聚集的状态转换函数';
	$lang['straggrneedsstype'] = '必须指定聚集的状态值的数据类型';
	$lang['straggrcreated'] = '聚集已创建。';
	$lang['straggrcreatedbad'] = '聚集创建失败。';
	$lang['straggrshowall'] = '显示所有聚集';
	
	// Operator Classes
	$lang['stropclasses'] = '操作符类';
	$lang['strnoopclasses'] = '查无此操作符类。';
	$lang['straccessmethod'] = '存取方法';
	
	// Stats and performance
	$lang['strrowperf'] = '行性能';
	$lang['strioperf'] = 'I/O 性能';
	$lang['stridxrowperf'] = '索引行性能';
	$lang['stridxioperf'] = '索引 I/O 性能';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = '顺序扫描';
	$lang['strscan'] = '扫描';
	$lang['strread'] = '读取';
	$lang['strfetch'] = '取得';
	$lang['strheap'] = '堆';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'TOAST 索引';
	$lang['strcache'] = '缓存';
	$lang['strdisk'] = '硬盘';
	$lang['strrows2'] = '行';
	
	// Tablespaces
	$lang['strtablespace'] = '表空间';
	$lang['strtablespaces'] = '表空间';
	$lang['strshowalltablespaces'] = '显示所有表空间';
	$lang['strnotablespaces'] = '查无此表空间。';
	$lang['strcreatetablespace'] = '创建表空间';
	$lang['strlocation'] = '位置';
	$lang['strtablespaceneedsname'] = '必须指定表空间名称。';
	$lang['strtablespaceneedsloc'] = '必须指定创建表空间的文件夹。';
	$lang['strtablespacecreated'] = '表空间已创建。';
	$lang['strtablespacecreatedbad'] = '表空间创建失败。';
	$lang['strconfdroptablespace'] = '确定要删除表空间 "%s"吗?';
	$lang['strtablespacedropped'] = '表空间已删除。';
	$lang['strtablespacedroppedbad'] = '表空间删除失败。';
	$lang['strtablespacealtered'] = '表空间已变更。';
	$lang['strtablespacealteredbad'] = '表空间变更失败。';
	
	// Miscellaneous
	$lang['strtopbar'] = '%s 架于 %s：%s － 您是 "%s"';
	$lang['strtimefmt'] = 'jS M, Y g:iA';
	$lang['strhelp'] = '帮助';
	$lang['strhelpicon'] = '?';
	$lang['strhelppagebrowser'] = '帮助页面浏览';
	$lang['strselecthelppage'] = '选择一个帮助页面';
	$lang['strinvalidhelppage'] = '无效的帮助页面。';
	$lang['strlogintitle'] = '登入 %s';
	$lang['strlogoutmsg'] = '注销 %s';
	$lang['strloading'] = '加载中。。。';
	$lang['strerrorloading'] = '加载错误';
	$lang['strclicktoreload'] = '点击重新加载';
	
	// Autovacuum
	$lang['strautovacuum'] = '自动清理(Autovacuum)';
	$lang['strturnedon'] = '打开';
	$lang['strturnedoff'] = '关闭';
	$lang['strenabled'] = '有效';
	$lang['strnovacuumconf']  =  '没有自动清理配置。';
	$lang['strvacuumbasethreshold'] = '清理基本临界值';
	$lang['strvacuumscalefactor'] = '清理换算系数';
	$lang['stranalybasethreshold'] = '分析基本临界值';
	$lang['stranalyzescalefactor'] = '分析换算系数';
	$lang['strvacuumcostdelay'] = '清理成本延迟';
	$lang['strvacuumcostlimit'] = '清理成本限制';
	$lang['strvacuumpertable']  =  '此表的自动清理配置';
	$lang['straddvacuumtable']  =  '为此表增加自动清理配置';
	$lang['streditvacuumtable']  =  '编辑表 %s 的自动清理配置';
	$lang['strdelvacuumtable']  =  '删除表 %s 的自动清理配置?';
	$lang['strvacuumtablereset']  =  '还原表 %s 的自动清理配置为默认值';
	$lang['strdelvacuumtablefail']  =  '无法删除表 %s 的自动清理配置';
	$lang['strsetvacuumtablesaved']  =  '已保存表 %s 的自动清理配置';
	$lang['strsetvacuumtablefail']  =  '表 %s 的自动清理配置失败';
	$lang['strspecifydelvacuumtable']  =  '请指定你希望移除自动清理配置的表。';
	$lang['strspecifyeditvacuumtable']  =  '请指定你希望编辑自动清理配置的表。';
	$lang['strnotdefaultinred']  =  '非默认值被标注为红色。';
	
	// Table-level Locks
	$lang['strlocks'] = '锁';
	$lang['strtransaction'] = '事务ID';
	$lang['strvirtualtransaction'] = '虚拟事务ID';
	$lang['strprocessid'] = '进程ID';
	$lang['strmode'] = '锁定模式';
	$lang['strislockheld'] = '拥有锁?';
	
	// Prepared transactions
	$lang['strpreparedxacts'] = '已准备事务';
	$lang['strxactid'] = '事务ID';
	$lang['strgid'] = '全域ID';
	
	// Fulltext search
	$lang['strfulltext'] = '全文检索';
	$lang['strftsconfig'] = '全文检索配置';
	$lang['strftsconfigs'] = '配置';
	$lang['strftscreateconfig'] = '创建 全文检索配置';
	$lang['strftscreatedict'] = '创建字典';
	$lang['strftscreatedicttemplate'] = '创建字典模板';
	$lang['strftscreateparser'] = '创建分析器';
	$lang['strftsnoconfigs'] = '没有找到全文检索配置。';
	$lang['strftsconfigdropped'] = '全文检索配置已移除。';
	$lang['strftsconfigdroppedbad'] = '全文检索移除失败。';
	$lang['strconfdropftsconfig'] = '确定要移除全文检索检索配置 "%s"吗?';
	$lang['strconfdropftsdict'] = '确定要移除全文检索字典 "%s"吗?';
	$lang['strconfdropftsmapping'] = '确定要将映射 "%s" 从全文检索配置 "%s"中移除吗?';
	$lang['strftstemplate'] = '模板';
	$lang['strftsparser'] = '分析器';
	$lang['strftsconfigneedsname'] = '必须指定全文检索配置名称。';
	$lang['strftsconfigcreated'] = '全文检索配置已创建';
	$lang['strftsconfigcreatedbad'] = '全文检索配置创建失败。';
	$lang['strftsmapping'] = '映射';
	$lang['strftsdicts'] = '字典';
	$lang['strftsdict'] = '字典';
	$lang['strftsemptymap'] = '空的全文检索配置映射。';
	$lang['strftsconfigaltered'] = '全文检索已变更。';
	$lang['strftsconfigalteredbad'] = '全文检索变更失败。';
	$lang['strftsconfigmap'] = '全文检索配置映射';
	$lang['strftsparsers'] = '全文检索分析器';
	$lang['strftsnoparsers'] = '无有效的全文检索分析器。';
	$lang['strftsnodicts'] = '无有效的全文检索字典。';
	$lang['strftsdictcreated'] = '全文检索字典已创建';
	$lang['strftsdictcreatedbad'] = '全文检索字典创建失败。';
	$lang['strftslexize'] = 'Lexize';
	$lang['strftsinit'] = '初始化';
	$lang['strftsoptionsvalues'] = '选项和值';
	$lang['strftsdictneedsname'] = '必须指定全文检索字典名称。';
	$lang['strftsdictdropped'] = '全文检索字典已移除。';
	$lang['strftsdictdroppedbad'] = '全文检索字典移除失败。';
	$lang['strftsdictaltered'] = '全文检索字典已变更。';
	$lang['strftsdictalteredbad'] = '全文检索字典变更失败。';
	$lang['strftsaddmapping'] = '添加映射';
	$lang['strftsspecifymappingtodrop'] = '必须最少指定一个映射来移除';
	$lang['strftsspecifyconfigtoalter'] = '必须指定一个全文检索配置来变更';
	$lang['strftsmappingdropped'] = '全文检索映射已删除。';
	$lang['strftsmappingdroppedbad'] = '全文检索映射移除失败。';
	$lang['strftsnodictionaries'] = '查无字典。';
	$lang['strftsmappingaltered'] = '全文检索映射已变更。';
	$lang['strftsmappingalteredbad'] = '全文检索映射变更失败。';
	$lang['strftsmappingadded'] = '全文检索映射已添加。';
	$lang['strftsmappingaddedbad'] = '全文检索映射添加失败。';
	$lang['strftstabconfigs'] = '配置';
	$lang['strftstabdicts'] = '字典';
	$lang['strftstabparsers'] = '分析器';
	$lang['strftscantparsercopy']  =  '不能在创建全文检索配置时指定分析器和模板。';

	//Plugins
	$lang['strpluginnotfound']  =  '错误：没有找到\'%s\'插件。请检查该插件是否在plugins/目录下，或插件是否包含plugin.php。注意插件名大小写敏感。';
	$lang['stractionnotfound']  =  '错误：动作\'%s\'不在插件\'%s\'中，或没有被指定为合法的动作。';
	$lang['strhooknotfound']  =  '错误：连接\'%s\'不可用.';
?>
