<?php

        /**
         * Ukrainian KOI8-U language file for phpPgAdmin. 
         * @maintainer Alex Rootoff [rootoff{AT}pisem.net]
         */

        // Language and character set
        $lang['applang'] = 'Українська';
        $lang['applocale'] = 'uk-UA';
        $lang['applangdir'] = 'ltr';

        // Welcome  
        $lang['strintro'] = 'Вітаємо вас в phpPgAdmin.';
        $lang['strppahome'] = 'phpPgAdmin - домашня сторінка';
        $lang['strpgsqlhome'] = 'PostgreSQL - домашня сторінка';
        $lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
        $lang['strlocaldocs'] = 'PostgreSQL - документація (локальна)';
        $lang['strreportbug'] = 'Звіт про помилки';
        $lang['strviewfaq'] = 'Перегляд онлайн FAQ';
        $lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';
        
        // Basic strings
        $lang['strlogin'] = 'Логін';
        $lang['strloginfailed'] = 'Неправильний пароль';
        $lang['strlogindisallowed'] = 'Логін недопустимий із міркувань безпеки';
        $lang['strserver'] = 'Сервер';
        $lang['strlogout'] = 'Перереєстрація';
        $lang['strowner'] = 'Користувач';
        $lang['straction'] = 'Дія';
        $lang['stractions'] = 'Дії';
        $lang['strname'] = 'Ім"я';
        $lang['strdefinition'] = 'Визначення';
        $lang['strproperties'] = 'Властивості';
        $lang['strbrowse'] = 'Переглянути';
        $lang['strdrop'] = 'Видалити';
        $lang['strdropped'] = 'Видалено';
        $lang['strnull'] = 'Null';
        $lang['strnotnull'] = 'Not Null';
        $lang['strprev'] = '< Поперед.';
        $lang['strnext'] = 'Наст. >';
        $lang['strfirst'] = '<< Перший';
        $lang['strlast'] = 'Остан. >>';
        $lang['strfailed'] = 'Перервано';
        $lang['strcreate'] = 'Створити';
        $lang['strcreated'] = 'Створено';
        $lang['strcomment'] = 'Коментар';
        $lang['strlength'] = 'Довжина';
        $lang['strdefault'] = 'По замовчуванню';
        $lang['stralter'] = 'Змінити';
        $lang['strok'] = 'Гаразд';
        $lang['strcancel'] = 'Відмінити';
        $lang['strsave'] = 'Зберегти';
        $lang['strreset'] = 'Скинути';
        $lang['strinsert'] = 'Вставити';
        $lang['strselect'] = 'Вибрати';
        $lang['strdelete'] = 'Видалити';
        $lang['strupdate'] = 'Оновити';
        $lang['strreferences'] = 'Посилання';
        $lang['stryes'] = 'Так';
        $lang['strno'] = 'Ні';
        $lang['strtrue'] = 'Істина';
        $lang['strfalse'] = 'Фальш';
        $lang['stredit'] = 'Редагувати';
        $lang['strcolumns'] = 'Атрибути';
        $lang['strrows'] = 'запис(и/ів)';
        $lang['strrowsaff'] = 'запис(и/ів) опрацьовано.';
        $lang['strobjects'] = 'об"єкт(и/ів)';
        $lang['strexample'] = 'і т.д.';
        $lang['strback'] = 'Назад';         
        $lang['strqueryresults'] = 'Результати запиту';
        $lang['strshow'] = 'Показати';
        $lang['strempty'] = 'Очистити';
        $lang['strlanguage'] = 'Мова';
        $lang['strencoding'] = 'Кодування';
        $lang['strvalue'] = 'Значення';
        $lang['strunique'] = 'Унікальний';
        $lang['strprimary'] = 'Первинний';
        $lang['strexport'] = 'Експорт';
        $lang['strimport'] = 'Імпорт';
        $lang['strsql'] = 'SQL';
        $lang['strgo'] = 'Виконати';
        $lang['stradmin'] = 'Управління';
        $lang['strvacuum'] = 'Перебудувати';
        $lang['stranalyze'] = 'Аналізувати';
        $lang['strclusterindex'] = 'Кластеризувати';
        $lang['strclustered'] = 'Кластеризовано?';
        $lang['strreindex'] = 'Перебудувати індекс';
        $lang['strrun'] = 'Виконати';
        $lang['stradd'] = 'Додати';
        $lang['strevent'] = 'Подія';
        $lang['strwhere'] = 'Де';
        $lang['strinstead'] = 'Робити замість';
        $lang['strwhen'] = 'Коли';
        $lang['strformat'] = 'Формат';
        $lang['strdata'] = 'Данні';
        $lang['strconfirm'] = 'Підтвердити';
        $lang['strexpression'] = 'Вираз';
        $lang['strellipsis'] = '...';
        $lang['strexpand'] = 'Разширити';
        $lang['strcollapse'] = 'Згорнути';
        $lang['strexplain'] = 'Пояснити';
        $lang['strexplainanalyze'] = 'Пояснити аналіз';
        $lang['strfind'] = 'Знайти';
        $lang['stroptions'] = 'Опції';
        $lang['strrefresh'] = 'Оновити';
        $lang['strdownload'] = 'Завантажити';
        $lang['strdownloadgzipped'] = 'Завантажити архів gzip';
        $lang['strinfo'] = 'Відомості';
        $lang['stroids'] = 'OIDs';
        $lang['stradvanced'] = 'Додатково';
        $lang['strvariables'] = 'Змінні';
        $lang['strprocess'] = 'Процес';
        $lang['strprocesses'] = 'Процеси';
        $lang['strsetting'] = 'Налаштування';
        $lang['streditsql'] = 'Редагувати SQL';
        $lang['strruntime'] = 'Час виконання: %s мсек';
        $lang['strpaginate'] = 'Нумерувати сторінки з результатами';
        $lang['struploadscript'] = 'чи завантажити SQL-скрипт:';
        $lang['strstarttime'] = 'Час початку';
        $lang['strfile'] = 'Файл';
        $lang['strfileimported'] = 'Файл імпортовано.';

        // Error handling
        $lang['strbadconfig'] = 'Ваш config.inc.php застарів. Вам необхідно оновити його із config.inc.php-dist.';
        $lang['strnotloaded'] = 'Ваша інсталяція PHP не підтримує PostgreSQL. Вам необхідно перекомпілювати PHP, використавши параметр --with-pgsql для configure.';
        $lang['strbadschema'] = 'Виявлено неправильну схему.';
        $lang['strbadencoding'] = 'Неможливо встановити Ваше кодування в базі даних.';
        $lang['strsqlerror'] = 'Помилка SQL:';
        $lang['strinstatement'] = 'В операторі:';
        $lang['strinvalidparam'] = 'Неправильний параметр скрипта.';
        $lang['strnodata'] = 'Даних не виявлено.';
        $lang['strnoobjects'] = 'Об"єктів не виявлено.';
        $lang['strrownotunique'] = 'Немає унікального ідентифікатора для цього запису.';
        $lang['strnouploads'] = 'Завантаження файла неможливе.';
        $lang['strimporterror'] = 'Помилка при імпортуванні.';
        $lang['strimporterrorline'] = 'Помилка каналу при імпортові %s.';

        // Tables
        $lang['strtable'] = 'Таблиця';
        $lang['strtables'] = 'Таблиці';
        $lang['strshowalltables'] = 'Показати всі таблиці';
        $lang['strnotables'] = 'Таблиць не виявлено.';
        $lang['strnotable'] = ' Таблицю не знайдено.';
        $lang['strcreatetable'] = 'Створити таблицю';
        $lang['strtablename'] = 'Ім"я таблиці';
        $lang['strtableneedsname'] = 'Вам необхідно визначити ім"я таблиці.';
        $lang['strtableneedsfield'] = 'Вам необхідно визначити щонайменше одне поле.';
        $lang['strtableneedscols'] = 'Вам необхідно вказати допустиме число атрибутів.';
        $lang['strtablecreated'] = 'Таблицю створено.';
        $lang['strtablecreatedbad'] = 'Створення таблиці перервано.';
        $lang['strconfdroptable'] = 'Ви впевнені, що бажаєте видалити таблицю "%s"?';
        $lang['strtabledropped'] = 'Таблицю видалено.';
        $lang['strtabledroppedbad'] = 'Видалення таблиці перервано.';
        $lang['strconfemptytable'] = 'Ви впевнені, що бажаєте очистити таблицю "%s"?';
        $lang['strtableemptied'] = 'Таблицю очищено.';
        $lang['strtableemptiedbad'] = 'Очищення таблиці перервано.';
        $lang['strinsertrow'] = 'Додати запис';
        $lang['strrowinserted'] = 'Запис додано.';
        $lang['strrowinsertedbad'] = 'Додавання запису перервано.';
        $lang['streditrow'] = 'Редагувати запис';
        $lang['strrowupdated'] = 'Запис оновлено.';
        $lang['strrowupdatedbad'] = 'Оновлення запису перервано.';
        $lang['strdeleterow'] = 'Видалити запис';
        $lang['strconfdeleterow'] = 'Ви впевнені, що бажаєте видалити запис?';
        $lang['strrowdeleted'] = 'Запис видалено.';
        $lang['strrowdeletedbad'] = 'Видалення запису перервано.';
        $lang['strsaveandrepeat'] = 'Вставити і повторити';
        $lang['strfield'] = 'Поле';
        $lang['strfields'] = 'Поля';
        $lang['strnumfields'] = 'К-ть полів';
        $lang['strfieldneedsname'] = 'Вам необхідно назвати поле';
        $lang['strselectallfields'] = 'Вибрати всі поля';
        $lang['strselectneedscol'] = 'Вам необхідно вказати щонайменше один атрибут';
        $lang['strselectunary'] = 'Унарний оператор не может мати величину.';
        $lang['straltercolumn'] = 'Змінити атрибут';
        $lang['strcolumnaltered'] = 'Атрибут змінено.';
        $lang['strcolumnalteredbad'] = 'Зміну атрибута перервано.';
        $lang['strconfdropcolumn'] = 'Ви впевнені, що бажаєте видалити атрибут "%s" таблиці "%s"?';
        $lang['strcolumndropped'] = 'Атрибут видалено.';
        $lang['strcolumndroppedbad'] = 'Видалення атрибута перервано.';
        $lang['straddcolumn'] = 'Додати атрибут';
        $lang['strcolumnadded'] = 'Атрибут додано.';
        $lang['strcolumnaddedbad'] = 'Додавання атрибута перервано.';
        $lang['strdataonly'] = 'Тільки дані';
        $lang['strcascade'] = 'Каскадом';
        $lang['strtablealtered'] = 'Таблицю змінено.';
        $lang['strtablealteredbad'] = 'Зміну таблиці перервано.';
        $lang['strdataonly'] = 'Лише дані';
        $lang['strstructureonly'] = 'Лише структуру';
        $lang['strstructureanddata'] = 'Структуру і дані';
        $lang['strtabbed'] = 'Через табуляцію';
        $lang['strauto'] = 'Авто';

        // Users
        $lang['struser'] = 'Користувач';
        $lang['strusers'] = 'Користувачі';
        $lang['strusername'] = 'Ім"я користувача';
        $lang['strpassword'] = 'Пароль';
        $lang['strsuper'] = 'Суперкористувач?';
        $lang['strcreatedb'] = 'Створити базу даних?';
        $lang['strexpires'] = 'Термін дії';
        $lang['strsessiondefaults'] = 'Опції сеансу за замовчуванням';
        $lang['strnousers'] = 'Немає таких користувачів.';
        $lang['struserupdated'] = 'Користувача оновлено.';
        $lang['struserupdatedbad'] = 'Оновлення користувача перервано.';
        $lang['strshowallusers'] = 'Показати всіх користувачів';
        $lang['strcreateuser'] = 'Створити користувача';
        $lang['struserneedsname'] = 'Ви повинні ввести ім"я користувача.';
        $lang['strusercreated'] = 'Користувача створено.';
        $lang['strusercreatedbad'] = 'Створення користувача перервано.';
        $lang['strconfdropuser'] = 'Ви впевнені, що бажаєте видалити користувача "%s"?';
        $lang['struserdropped'] = 'Користувача видалено.';
        $lang['struserdroppedbad'] = 'Видалення користувача перервано.';
        $lang['straccount'] = 'Обліковий запис';
        $lang['strchangepassword'] = 'Змінити пароль';
        $lang['strpasswordchanged'] = 'Пароль змінено.';
        $lang['strpasswordchangedbad'] = 'Зміну пароля перервано.';
        $lang['strpasswordshort'] = 'Пароль закороткий.';
        $lang['strpasswordconfirm'] = 'Пароль не відповідає підтвержденню.';

        // Groups
        $lang['strgroup'] = 'Група';
        $lang['strgroups'] = 'Групи';
        $lang['strnogroup'] = 'Групу не виявлено.';
        $lang['strnogroups'] = 'Жодної групи не виявлено.';
        $lang['strcreategroup'] = 'Створити групу';
        $lang['strshowallgroups'] = 'Показати всі групи';
        $lang['strgroupneedsname'] = 'Вам необхідно вказати назву групи.';
        $lang['strgroupcreated'] = 'Групу створено.';
        $lang['strgroupcreatedbad'] = 'Створення групи перервано.';
        $lang['strconfdropgroup'] = 'Ви впевненні, що бажаєте видалити групу "%s"?';
        $lang['strgroupdropped'] = 'Групу видалено.';
        $lang['strgroupdroppedbad'] = 'Видалення групи перервано.';
        $lang['strmembers'] = 'Учасників';
        $lang['straddmember'] = 'Додати учасника';
        $lang['strmemberadded'] = 'Учасника додано.';
        $lang['strmemberaddedbad'] = 'Додавання учасника перервано.';
        $lang['strdropmember'] = 'Видалити учасника';
        $lang['strconfdropmember'] = 'Ви впевненні, що бажаєте видалити учасника "%s" із групи "%s"?';
        $lang['strmemberdropped'] = 'Учасника видалено.';
        $lang['strmemberdroppedbad'] = 'Видалення учасника перервано.';

        // Privileges
        $lang['strprivilege'] = 'Привілей';
        $lang['strprivileges'] = 'Привілеї';
        $lang['strnoprivileges'] = 'Об"єкт не володіє привілеями.';
        $lang['strgrant'] = 'Підсилити';
        $lang['strrevoke'] = 'Послабити';
        $lang['strgranted'] = 'Привілеї змінено.';
        $lang['strgrantfailed'] = 'Зміну привілеїв перервано.';
        $lang['strgrantbad'] = 'Вам необхідно вказати щонайменше одного користувача чи групу і щонайменше один привілей.';
        $lang['stralterprivs'] = 'Змінити привілеї';
        $lang['strgrantor'] = 'Донор';
        $lang['strasterisk'] = '*';

        // Databases
        $lang['strdatabase'] = 'База даних';
        $lang['strdatabases'] = 'Бази даних';
        $lang['strshowalldatabases'] = 'Показати всі бази даних';
        $lang['strnodatabase'] = 'Базу даних не виявлено.';
        $lang['strnodatabases'] = 'Жодної бази даних не виявлено.';
        $lang['strcreatedatabase'] = 'Створити базу даних';
        $lang['strdatabasename'] = 'Ім"я бази даних';
        $lang['strdatabaseneedsname'] = 'Вам необхідно присвоїти ім"я Вашій базі даних.';
        $lang['strdatabasecreated'] = 'Базу даних створено.';
        $lang['strdatabasecreatedbad'] = 'Створення бази даних перервано.';
        $lang['strconfdropdatabase'] = 'Ви впевненні, що бажаєте видалити базу даних "%s"?';
        $lang['strdatabasedropped'] = ' Базу даних видалено.';
        $lang['strdatabasedroppedbad'] = 'Видалення бази даних перервано.';
        $lang['strentersql'] = 'Введіть SQL-запит:';
        $lang['strsqlexecuted'] = 'SQL-запит виконано.';
        $lang['strvacuumgood'] = 'Операцію перебудови завершено.';
        $lang['strvacuumbad'] = 'Операцію перебудови перервано.';
        $lang['stranalyzegood'] = ' Операцію аналізу завершено.';
        $lang['stranalyzebad'] = ' Операцію аналізу завершено.';
        $lang['strreindexgood'] = 'Переіндексацію завершено.';
        $lang['strreindexbad'] = 'Переіндексацію перервано.';
        $lang['strfull'] = 'Повністю';
        $lang['strfreeze'] = 'Заморозити';
        $lang['strforce'] = 'Примусово';

        // Views
        $lang['strview'] = 'Показ';
        $lang['strviews'] = 'Покази';
        $lang['strshowallviews'] = 'Представити всі покази';
        $lang['strnoview'] = 'Показу не виявлено.';
        $lang['strnoviews'] = 'Жодного показу не виявлено.';
        $lang['strcreateview'] = 'Створити показ';
        $lang['strviewname'] = 'Ім"я показу';
        $lang['strviewneedsname'] = 'Вам необхідно вказати ім"я показу.';
        $lang['strviewneedsdef'] = 'Вам необхідно визначити атрибуты показу.';
        $lang['strviewneedsfields'] = 'Вам необхідно визначити атрибуты для вибірки в ваш показ.';
        $lang['strviewcreated'] = 'Показ створено.';
        $lang['strviewcreatedbad'] = 'Створення показу перервано.';
        $lang['strconfdropview'] = 'Ви впевнені, що бажаєте видалити показ "%s"?';
        $lang['strviewdropped'] = 'Показ видалено.';
        $lang['strviewdroppedbad'] = 'Видалення показу перервано.';
        $lang['strviewupdated'] = 'Показ оновлено.';
        $lang['strviewupdatedbad'] = 'Оновлення показу перервано.';
        $lang['strviewlink'] = 'Пов"язані ключі';
        $lang['strviewconditions'] = 'Додаткові умови';
        $lang['strcreateviewwiz'] = 'Створити показ, скориставшись майстром';

        // Sequences
        $lang['strsequence'] = 'Послідовність';
        $lang['strsequences'] = ' Послідовності';
        $lang['strshowallsequences'] = 'Показати всі послідовності';
        $lang['strnosequence'] = 'Послідовність не виявлено.';
        $lang['strnosequences'] = 'Жодної послідовності не виявлено.';
        $lang['strcreatesequence'] = 'Створити послідовність';
        $lang['strlastvalue'] = 'Останнє значення';
        $lang['strincrementby'] = 'Збільшення на';
        $lang['strstartvalue'] = 'Початкове значення';
        $lang['strmaxvalue'] = 'Макс. значення';
        $lang['strminvalue'] = 'Мін. значення';
        $lang['strcachevalue'] = 'Розмір кеша';
        $lang['strlogcount'] = 'Log Count';
        $lang['striscycled'] = 'Зациклити?';
        $lang['strsequenceneedsname'] = 'Вам необхідно вказати ім"я послідовності.';
        $lang['strsequencecreated'] = 'Послідовність створено.';
        $lang['strsequencecreatedbad'] = 'Створення послідовності перервано.';
        $lang['strconfdropsequence'] = 'Ви впевнені, що бажаєте видалити послідовність "%s"?';
        $lang['strsequencedropped'] = 'Послідовність видалено.';
        $lang['strsequencedroppedbad'] = 'Видалення послідовності перервано.';
        $lang['strsequencereset'] = 'Послідовність скинуто.';
        $lang['strsequenceresetbad'] = 'Скинення послідовності перервано.'; 

        // Indexes
        $lang['strindex'] = 'Індекс';
        $lang['strindexes'] = 'Індекси';
        $lang['strindexname'] = 'Ім"я індекса';
        $lang['strshowallindexes'] = 'Показати всі індекси';
        $lang['strnoindex'] = 'Індекс не виявлено.';
        $lang['strnoindexes'] = 'Жодного індекса не знайдено.';
        $lang['strcreateindex'] = 'Створити індекс';
        $lang['strtabname'] = 'Ім"я таблиці';
        $lang['strcolumnname'] = 'Ім"я атрибута';
        $lang['strindexneedsname'] = 'Вам необхідно вказати ім"я індекса';
        $lang['strindexneedscols'] = 'Вам необхідно вказати можливу кількість атрибутів.';
        $lang['strindexcreated'] = 'Індекс створено.';
        $lang['strindexcreatedbad'] = 'Створення індекса перервано.';
        $lang['strconfdropindex'] = 'Ви впевнені, що бажаєте видалити індекс "%s"?';
        $lang['strindexdropped'] = 'Індекс видалено.';
        $lang['strindexdroppedbad'] = 'Видалення індекса перервано.';
        $lang['strkeyname'] = 'Ім"я ключа';
        $lang['struniquekey'] = 'Унікальний ключ';
        $lang['strprimarykey'] = 'Первинний ключ';
        $lang['strindextype'] = 'Вид індекса';
        $lang['strindexname'] = 'Ім"я індекса';
        $lang['strtablecolumnlist'] = 'Атрибутів в таблиці';
        $lang['strindexcolumnlist'] = 'Атрибутів в індексі';
        $lang['strconfcluster'] = 'Ви впевнені, що бажаєте кластеризувати "%s"?';
        $lang['strclusteredgood'] = 'Кластеризацію завершено.';
        $lang['strclusteredbad'] = 'Кластеризацію перервано.';

        // Rules
        $lang['strrules'] = 'Правила';
        $lang['strrule'] = 'Правило';
        $lang['strshowallrules'] = 'Показати всі правила';
        $lang['strnorule'] = 'Правило не виявлено.';
        $lang['strnorules'] = 'Жодного правила не виявлено.';
        $lang['strcreaterule'] = 'Створити правило';
        $lang['strrulename'] = 'Ім"я правила';
        $lang['strruleneedsname'] = 'Вам необхідно вказати ім"я правила.';
        $lang['strrulecreated'] = 'Правило створено.';
        $lang['strrulecreatedbad'] = 'Створення правила перервано.';
        $lang['strconfdroprule'] = 'Ви впевнені, що бажаєте видалити правило "%s" з "%s"?';
        $lang['strruledropped'] = 'Правило видалено.';
        $lang['strruledroppedbad'] = 'Видалення правила перервано.';

        // Constraints
        $lang['strconstraints'] = 'Обмеження';
        $lang['strshowallconstraints'] = 'Показати всі обмеження';
        $lang['strnoconstraints'] = 'Жодного обмеження не виявлено.';
        $lang['strcreateconstraint'] = 'Створити обмеження';
        $lang['strconstraintcreated'] = 'Обмеження створено.';
        $lang['strconstraintcreatedbad'] = 'Створення обмеження перервано.';
        $lang['strconfdropconstraint'] = 'Ви впевнені, що бажаєте видалити обмеження "%s" з "%s"?';
        $lang['strconstraintdropped'] = 'Обмеження видалено.';
        $lang['strconstraintdroppedbad'] = 'Видалення обмеження перервано.';
        $lang['straddcheck'] = 'Додати перевірку';
        $lang['strcheckneedsdefinition'] = 'Обмеження перевірки потребує визначення.';
        $lang['strcheckadded'] = 'Обмеження перевірки додано.';
        $lang['strcheckaddedbad'] = 'Додавання обмеження перевірки перервано.';
        $lang['straddpk'] = 'Додати первинний ключ';
        $lang['strpkneedscols'] = 'Первинний ключ повинен містити хочя б один атрибут.';
        $lang['strpkadded'] = 'Первинний ключ додано.';
        $lang['strpkaddedbad'] = 'Додавання первинного ключа перервано.';
        $lang['stradduniq'] = 'Додати унікальний ключ';
        $lang['struniqneedscols'] = 'Унікальний ключ повинен містити хоча б один атрибут.';
        $lang['struniqadded'] = 'Унікальний ключ додано.';
        $lang['struniqaddedbad'] = 'Додавання унікального ключа перервано.';
        $lang['straddfk'] = 'Додати зовнішній ключ';
        $lang['strfkneedscols'] = 'Зовнішній ключ повинен містити хоча б один атрибут.';
        $lang['strfkneedstarget'] = 'Зовнішньому ключеві необхідно вказати цільову таблицю.';
        $lang['strfkadded'] = 'Зовнішній ключ додано.';
        $lang['strfkaddedbad'] = 'Додавання зовнішнього ключа перервано.';
        $lang['strfktarget'] = 'Цільова таблиця';
        $lang['strfkcolumnlist'] = 'Атрибуты в ключі';
        $lang['strondelete'] = 'ON DELETE';
        $lang['stronupdate'] = 'ON UPDATE';        

        // Functions
        $lang['strfunction'] = 'Функція';
        $lang['strfunctions'] = ' Функції';
        $lang['strshowallfunctions'] = 'Показати всі функції';
        $lang['strnofunction'] = 'Функцію не виявлено.';
        $lang['strnofunctions'] = 'Жодної функції не виявлено.';
        $lang['strcreatefunction'] = 'Створити функцію';
        $lang['strfunctionname'] = 'Ім"я функції';
        $lang['strreturns'] = 'Результат, що повертає';
        $lang['strarguments'] = 'Аргументи';
        $lang['strproglanguage'] = 'Мова програмування';
        $lang['strproglanguage'] = 'Мова';
        $lang['strfunctionneedsname'] = 'Вам необхідно вказати ім"я функції.';
        $lang['strfunctionneedsdef'] = 'Вам необхідно визначити функцію.';
        $lang['strfunctioncreated'] = 'Функцію створено.';
        $lang['strfunctioncreatedbad'] = 'Створення функції перервано.';
        $lang['strconfdropfunction'] = 'Ви впевнені, що бажаєте видалити функцію "%s"?';
        $lang['strfunctiondropped'] = 'Функцію видалено.';
        $lang['strfunctiondroppedbad'] = 'Видалення функції перервано.';
        $lang['strfunctionupdated'] = 'Функцію оновлено.';
        $lang['strfunctionupdatedbad'] = 'Оновлення функції перервано.';

        // Triggers
        $lang['strtrigger'] = 'Трігер';
        $lang['strtriggers'] = ' Трігери';
        $lang['strshowalltriggers'] = 'Показати всі трігери';
        $lang['strnotrigger'] = 'Трігер не виявлено.';
        $lang['strnotriggers'] = 'Жодного трігера не виявлено.';
        $lang['strcreatetrigger'] = 'Створити трігер';
        $lang['strtriggerneedsname'] = 'Вам необхідно вказать ім"я трігера.';
        $lang['strtriggerneedsfunc'] = 'Вам необхідно визначити функцію трігера.';
        $lang['strtriggercreated'] = 'Трігер створено.';
        $lang['strtriggercreatedbad'] = 'Створення трігера перервано.';
        $lang['strconfdroptrigger'] = 'Ви впевнені, що бажаєтее видалити трігер "%s" на "%s"?';
        $lang['strtriggerdropped'] = 'Трігер видалено.';
        $lang['strtriggerdroppedbad'] = 'Видалення трігера перервано.';
        $lang['strtriggeraltered'] = 'Трігер змінено.';
        $lang['strtriggeralteredbad'] = 'Зміну трігера перервано.';

        // Types
        $lang['strtype'] = 'Тип даних';
        $lang['strtypes'] = 'Типи даних';
        $lang['strshowalltypes'] = 'Показати всі типи даних';
        $lang['strnotype'] = 'Тип даних не виявлено.';
        $lang['strnotypes'] = 'Жодного типу даних не виявлено.';
        $lang['strcreatetype'] = 'Створити тип даних';
        $lang['strtypename'] = 'Ім"я типу даних';
        $lang['strinputfn'] = 'Функція вводу';
        $lang['stroutputfn'] = 'Функція виводу';
        $lang['strpassbyval'] = 'Передати за значенням?';
        $lang['stralignment'] = 'Вирівнювання';
        $lang['strelement'] = 'Елемент';
        $lang['strdelimiter'] = 'Роздільник';
        $lang['strstorage'] = 'Зберігання';
        $lang['strtypeneedsname'] = 'Вам необхідно вказати ім"я типу даних.';
        $lang['strtypeneedslen'] = 'Вам необхідно вказати розмір для типу даних.';
        $lang['strtypecreated'] = 'Тип даних створено.';
        $lang['strtypecreatedbad'] = 'Створення типу даних перервано.';
        $lang['strconfdroptype'] = 'Ви впевнені, що бажаєте видалити тип даних "%s"?';
        $lang['strtypedropped'] = 'Тип даних видалено.';
        $lang['strtypedroppedbad'] = 'Видалення типу даних перервано.';

        // Schemas
        $lang['strschema'] = 'Схема';
        $lang['strschemas'] = 'Схеми';
        $lang['strshowallschemas'] = 'Показати всі схеми';
        $lang['strnoschema'] = 'Схему не виявлено.';
        $lang['strnoschemas'] = 'Жодної схеми не виявлено.';
        $lang['strcreateschema'] = 'Створити схему';
        $lang['strschemaname'] = 'Ім"я схеми';
        $lang['strschemaneedsname'] = 'Вам необхідно вказати ім"я схеми.';
        $lang['strschemacreated'] = 'Схему створено.';
        $lang['strschemacreatedbad'] = 'Створення схеми перервано.';
        $lang['strconfdropschema'] = 'Ви впевнені, що бажаєте видалити схему "%s"?';
        $lang['strschemadropped'] = 'Схему видалено.';
        $lang['strschemadroppedbad'] = 'Видалення схеми перервано.';
        $lang['strschemaaltered'] = 'Схему оновлено.';
        $lang['strschemaalteredbad'] = 'Оновлення схеми перервано.';

        // Reports

        // Domains
        $lang['strdomain'] = 'Домен';
        $lang['strdomains'] = 'Домени';
        $lang['strshowalldomains'] = 'Показати всі домени';
        $lang['strnodomains'] = 'Жодного домена не виявлено.';
        $lang['strcreatedomain'] = 'Створити домен';
        $lang['strdomaindropped'] = 'Домен видалено.';
        $lang['strdomaindroppedbad'] = 'Видалення домена перервано.';
        $lang['strconfdropdomain'] = 'Ви впевнені, що бажаєте видалити домен "%s"?';
        $lang['strdomainneedsname'] = 'Вам необхідно вказати ім"я домена.';
        $lang['strdomaincreated'] = 'Домен створено.';
        $lang['strdomaincreatedbad'] = 'Створення домена перервано.';        
        $lang['strdomainaltered'] = 'Домен змінено.';
        $lang['strdomainalteredbad'] = 'Зміну домена перервано.';        

        // Operators
        $lang['stroperator'] = 'Оператор';
        $lang['stroperators'] = 'Оператори';
        $lang['strshowalloperators'] = 'Показати всі оператори';
        $lang['strnooperator'] = 'Оператор не виявлено.';
        $lang['strnooperators'] = 'Операторів не виявлено.';
        $lang['strcreateoperator'] = 'Створити оператор';
        $lang['strleftarg'] = 'Тип лівого аргумента';
        $lang['strrightarg'] = 'Тип правого аргумента';
        $lang['strcommutator'] = 'Перетворення';
        $lang['strnegator'] = 'Заперечення';
        $lang['strrestrict'] = 'Послаблення';
        $lang['strjoin'] = 'Об"єднання';
        $lang['strhashes'] = 'Хешування';
        $lang['strmerges'] = 'Об"єднання';
        $lang['strleftsort'] = 'Сортування за лівим';
        $lang['strrightsort'] = 'Сортування за правим';
        $lang['strlessthan'] = 'Менше';
        $lang['strgreaterthan'] = 'Більше';
        $lang['stroperatorneedsname'] = 'Вам необхідно вказати назву оператора.';
        $lang['stroperatorcreated'] = 'Оператор створено';
        $lang['stroperatorcreatedbad'] = 'Створення оператора перервано.';
        $lang['strconfdropoperator'] = 'Ви впевнені, що бажаєтее видалити оператор "%s"?';
        $lang['stroperatordropped'] = 'Оператор видалено.';
        $lang['stroperatordroppedbad'] = 'Видалення оператора перервано.';

        // Casts
        $lang['strcasts'] = 'Взірці';
        $lang['strnocasts'] = 'Взірців не виявлено.';
        $lang['strsourcetype'] = 'Тип джерела';
        $lang['strtargettype'] = 'Тип приймача';
        $lang['strimplicit'] = 'Неявний';
        $lang['strinassignment'] = 'В призначенні';
        $lang['strbinarycompat'] = '(двійково сумісний)';
        
        // Conversions
        $lang['strconversions'] = 'Перетворення';
        $lang['strnoconversions'] = 'Перетворень не виявлено.';
        $lang['strsourceencoding'] = 'Кодування джерела';
        $lang['strtargetencoding'] = 'Кодування приймача';
        
        // Languages
        $lang['strlanguages'] = 'Мови';
        $lang['strnolanguages'] = 'Мов не виявлено.';
        $lang['strtrusted'] = 'Перевірено';
        
        // Info
        $lang['strnoinfo'] = 'Немає доступної інформації.';
        $lang['strreferringtables'] = 'Таблиці, що посилаються';
        $lang['strparenttables'] = 'Батьківські таблиці';
        $lang['strchildtables'] = 'Дочірні таблиці';

        // Aggregates
        $lang['straggregates'] = 'Агрегатні вирази';
        $lang['strnoaggregates'] = 'Агрегатних виразів не виявлено.';
        $lang['stralltypes'] = '(Всі типи)';

        // Operator Classes
        $lang['stropclasses'] = 'Класи операторів';
        $lang['strnoopclasses'] = 'Класів операторів не виявлено.';
        $lang['straccessmethod'] = 'Метод доступа';

        // Stats and performance
        $lang['strrowperf'] = 'Показ запису';
        $lang['strioperf'] = 'Показ вводу/виводу';
        $lang['stridxrowperf'] = 'Показ індекса запису';
        $lang['stridxioperf'] = 'Показ індекса вводу/виводу';
        $lang['strpercent'] = '%';
        $lang['strsequential'] = 'Послідовний';
        $lang['strscan'] = 'Сканувати';
        $lang['strread'] = 'Читати';
        $lang['strfetch'] = 'Витягнути';
        $lang['strheap'] = 'Сміття';
        $lang['strtoast'] = 'TOAST';
        $lang['strtoastindex'] = 'TOAST індекс';
        $lang['strcache'] = 'Кеш';
        $lang['strdisk'] = 'Диск';
        $lang['strrows2'] = 'Записи';

        // Miscellaneous
        $lang['strtopbar'] = '%s виконується на %s:%s -- Ви зареєструвались як "%s"';
        $lang['strtimefmt'] = ' j-m-Y  g:i';
        $lang['strhelp'] = 'Допомога';

?>
