<?php
	/**
	 * Russian UTF-8 language file. 
	 */

	// Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'Вы не создали базу данных отчетов. Читайте разъяснения в файле INSTALL.';

	// Reports
	$plugin_lang['strreport'] = 'Отчет';
	$plugin_lang['strreports'] = 'Отчеты';
	$plugin_lang['strshowallreports'] = 'Показать все отчеты';
	$plugin_lang['strnoreports'] = 'Отчетов нет.';
	$plugin_lang['strcreatereport'] = 'Создать отчет';
	$plugin_lang['strreportdropped'] = 'Отчет уничтожен.';
	$plugin_lang['strreportdroppedbad'] = 'Уничтожение отчета прервано.';
	$plugin_lang['strconfdropreport'] = 'Вы уверены, что хотите уничтожить отчет "%s"?';
	$plugin_lang['strreportneedsname'] = 'Вам необходимо указать имя отчета.';
	$plugin_lang['strreportneedsdef'] = 'Вам необходимо указать SQL-запрос для Вашего отчета.';
	$plugin_lang['strreportcreated'] = 'Отчет сохранен.';
	$plugin_lang['strreportcreatedbad'] = 'Сохранение отчета прервано.';
?>
