<?php

/**
 * Help links for PostgreSQL 9.5 documentation
 *
 * $Id: PostgresDoc84.php,v 1.3 2008/11/18 21:35:48 ioguix Exp $
 */

include('./help/PostgresDoc94.php');

$this->help_base = sprintf($GLOBALS['conf']['help_base'], '9.5');

?>
