<?php
	/**
	 * English language file for phpPgAdmin.
	 */

	//Basic
	$plugin_lang['strplugindescription'] = 'Report plugin';
	$plugin_lang['strnoreportsdb'] = 'You have not created the reports database. Read the INSTALL file for directions.';

	// Reports
	$plugin_lang['strreport'] = 'Report';
	$plugin_lang['strreports'] = 'Reports';
	$plugin_lang['strshowallreports'] = 'Show all reports';
	$plugin_lang['strnoreports'] = 'No reports found.';
	$plugin_lang['strcreatereport'] = 'Create report';
	$plugin_lang['streditreport'] = 'Edit report';
	$plugin_lang['strreportdropped'] = 'Report dropped.';
	$plugin_lang['strreportdroppedbad'] = 'Report drop failed.';
	$plugin_lang['strconfdropreport'] = 'Are you sure you want to drop the report "%s"?';
	$plugin_lang['strreportneedsname'] = 'You must give a name for your report.';
	$plugin_lang['strreportneedsdef'] = 'You must give SQL for your report.';
	$plugin_lang['strreportcreated'] = 'Report saved.';
	$plugin_lang['strreportcreatedbad'] = 'Failed to save report.';
?>
