<?php

	/**
	 * Mongolian  language file for phpPgAdmin. 
	 * @maintainer Erdenemandal Bat-Erdene [endeeuk@yahoo.com]
	 *
	 * $Id: mongol.php,v 1.5 2007/04/24 11:42:07 soranzo Exp $
	 */

	// Language and character set
	$lang['applang'] = 'Mongolian';
	$lang['applocale'] = 'mn-MN';
	$lang['applangdir'] = 'ltr';

	// Welcome  
	$lang['strintro'] = 'phpPgAdmin-Ф дСздСЪ ЭЯвЩЬЮЯ ее.';
	$lang['strppahome'] = 'phpPgAdmin - ?ЮФгмЮ ФмЬЧмУ';
	$lang['strpgsqlhome'] = 'PostgreSQL - ?ЮФгмЮ ФмЬЧмУ';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'PostgreSQL - тЩоЩЧ ТСвЩЭд (ьЯЫСЬ)';
	$lang['strreportbug'] = 'сЬФССЮй ЭмФммЬмЬ';
	$lang['strviewfaq'] = 'сгееЬд ТС ШСвЩеЬд';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';
	
	// Basic strings
	$lang['strlogin'] = 'шЯЬТЯЧФЯШ';
	$lang['strloginfailed'] = 'шЯЬТЯЬдйЮ СЬФСС';
	$lang['strlogindisallowed'] = 'шЯЬТЯЧФЯШ ТЯЬЯЭжЧ?Ъ';
	$lang['strserver'] = 'є?з ЫЯЭаиРдХв' ;
	$lang['strlogout'] = 'чСвСШ';
	$lang['strowner'] = 'ќкмЭлЩЧо';
	$lang['straction'] = '?ЪЬФмЬ';
	$lang['stractions'] = '?ЪЬФмЬ??Ф';
	$lang['strname'] = 'юмв';
	$lang['strdefinition'] = 'єЯФЯвШЯЪЬЯЬд';
	$lang['straggregates'] = 'юмЧдЧмШ';
	$lang['strproperties'] = 'є?Ь?з (лЩЮж оСЮСв)';
	$lang['strbrowse'] = 'шСвСШ';
	$lang['strdrop'] = 'шСгСШ';
	$lang['strdropped'] = 'шСгСЧФгСЮ';
	$lang['strnull'] = 'шЯЯгЯЮ';
	$lang['strnotnull'] = 'шЯЯгЯШ ТЩл';
	$lang['strprev'] = '< ?ЭЮ?Ш';
	$lang['strnext'] = 'фСвССЧЩЪЮ >';
	$lang['strfirst'] = '<< ќШмЮФ';
	$lang['strlast'] = 'ѓ??ЬФ >>';
	$lang['strfailed'] = 'сЬФСС';
	$lang['strcreate'] = '??гЧмШ';
	$lang['strcreated'] = '??гЧмгмЮ';
	$lang['strcomment'] = 'єСЪЬТСв';
	$lang['strlength'] = 'ѕвд';
	$lang['strdefault'] = 'єЯФЯвШЯЪ Тег';
	$lang['stralter'] = '??воЩЬ?Ш';
	$lang['strok'] = 'OK';
	$lang['strcancel'] = 'ш?оЩЮЧ?Ъ ТЯЬЧЯШ';
	$lang['strsave'] = 'шСФЧСЬСШ';
	$lang['strreset'] = 'свЩЬЧСШ';
	$lang['strinsert'] = 'явееЬЧС ШЩЪШ';
	$lang['strselect'] = 'ѓЯЮЧЯШ';
	$lang['strdelete'] = 'ѕгдЧСШ';
	$lang['strupdate'] = 'ѓСЪжЩвееЬСШ';
	$lang['strreferences'] = 'шСЭССвСЬ';
	$lang['stryes'] = 'єЩЪЭ';
	$lang['strno'] = '?Ч?Ъ';
	$lang['strtrue'] = '?ЮмЮ';
	$lang['strfalse'] = 'шеФСЬ';
	$lang['stredit'] = 'њСгСШ';
	$lang['strcolumns'] = 'тСЧСЮС';
	$lang['strrows'] = 'э?в';
	$lang['strobjects'] = 'яТиХЫд';
	$lang['strexample'] = 'ЧмШ Эмд';
	$lang['strback'] = 'теУСШ'; 	
	$lang['strqueryresults'] = 'сгееЬЧйЮ ?в Ф?Ю';
	$lang['strshow'] = '?кмШ';
	$lang['strempty'] = 'шЯЯгЬЯШ';
	$lang['strlanguage'] = 'шмЬ';
	$lang['strencoding'] = 'ыЯФоЩЬЯШ';
	$lang['strvalue'] = 'ѕдЧС';
	$lang['strunique'] = 'яЮУЧЯЪ';
	$lang['strprimary'] = '?ЮФгмЮ';
	$lang['strexport'] = 'ќЫгаЯвд';
	$lang['strimport'] = 'щЭаЯвд';
	$lang['strsql'] = 'SQL';
	$lang['strgo'] = '?вЧмЬжЬ??Ь';
	$lang['stradmin'] = 'њЯШЩЯЮ ТСЪЧееЬСШ';
	$lang['strvacuum'] = 'Vacuum';
	$lang['stranalyze'] = 'ф?Ю лЩЮжЩЬЧмм';
	$lang['strclusterindex'] = 'ыЬСгдХв';
	$lang['strclustered'] = 'ыЬСгдХв';
	$lang['strreindex'] = 'фСШЩЮ ЩЮФХЫгЬмШ';
	$lang['strrun'] = 'сжЩЬЬееЬСШ';
	$lang['stradd'] = 'юмЭмШ';
	$lang['strevent'] = 'є?Ь?з';
	$lang['strwhere'] = 'шССЮС';
	$lang['strinstead'] = 'явЯЮФ Юи ';
	$lang['strwhen'] = 'шмкмм';
	$lang['strformat'] = 'цЯвЭСд';
	$lang['strdata'] = '?Ч?ЧФ?Ь';
	$lang['strconfirm'] = 'тСдСЬЧССжееЬСШ';
	$lang['strexpression'] = '?ЪЬФмЬ';
	$lang['strellipsis'] = '...';
	$lang['strexpand'] = '?вЧ?дЧ?Ш';
	$lang['strcollapse'] = 'ѕЮСЬд';
	$lang['strexplain'] = 'єСЪЬТСв';
	$lang['strfind'] = 'яЬЯШ';
	$lang['stroptions'] = 'ѓЯЮЧЯЬд';
	$lang['strrefresh'] = 'ѓмвЧммШ';
	$lang['strdownload'] = 'єСдСж СзСШ';
	$lang['strinfo'] = 'эмФммЬмЬ';
	$lang['stroids'] = 'OIDs';
	$lang['stradvanced'] = 'юмЭмЬд';

	// Error handling
	$lang['strbadconfig'] = 'єСЮй config.inc.php ШееоЩвгСЮ ТСЪЮС. config.inc.php-dist ?ССг ФСШЩЮ ??гЧм.';
	$lang['strnotloaded'] = 'єСЮй PHP гееЬЧСЬд Юи PostgreSQL ?Ч?ЧФЬЩЪЮ гСЮдСЪ ШСЭдвСЮ СжЭЬЬСШ ТЯЬЯжЧ?Ъ ТСЪЮС. єС  PHP ?ЧСС ФСШЩЮ --with-pgsql дЯШЩвЧЯЯдЯЪ гееЬЧС.';
	$lang['strbadschema'] = 'єЯШЩвЧЯЯ Тевее';
	$lang['strbadencoding'] = 'Failed to set client encoding in database.';
	$lang['strsqlerror'] = 'SQL СЬФСС:';
	$lang['strinstatement'] = 'ї ЯаХвСдЯвХ:';
	$lang['strinvalidparam'] = 'юХзХвЮйЪ аСвСЭХдв гЫвЩадС.';
	$lang['strnodata'] = 'фСЮЮйШ ЮХ ЯТЮСвежХЮЯ.';
	$lang['strnoobjects'] = 'яТпХЫдЯз ЮХ ЯТЮСвежХЮЯ.';
	$lang['strrownotunique'] = 'юХд еЮЩЫСЬиЮЯЧЯ ЩФХЮдЩЦЩЫСдЯвС ФЬб мдЯЪ кСаЩгЩ.';

	// Tables
	$lang['strtable'] = 'єСТЬЩУС';
	$lang['strtables'] = 'єСТЬЩУй';
	$lang['strshowalltables'] = '№ЯЫСкСди згХ дСТЬЩУй';
	$lang['strnotables'] = 'єСТЬЩУ ЮХ ЯТЮСвежХЮЯ.';
	$lang['strnotable'] = ' єСТЬЩУС ЮХ ЯТЮСвежХЮС.';
	$lang['strcreatetable'] = 'ѓЯкФСди дСТЬЩУе';
	$lang['strtablename'] = 'щЭб дСТЬЩУй';
	$lang['strtableneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ ЯавХФХЬЩди ЩЭб дСТЬЩУй.';
	$lang['strtableneedsfield'] = 'їСЭ ЮХЯТШЯФЩЭЯ ЯавХФХЬЩди аЯ ЫвСЪЮХЪ ЭХвХ ЯФЮЯ аЯЬХ.';
	$lang['strtableneedscols'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ФЯаегдЩЭЯХ оЩгЬЯ СдвЩТедЯз.';
	$lang['strtablecreated'] = 'єСТЬЩУС гЯкФСЮС.';
	$lang['strtablecreatedbad'] = 'ѓЯкФСЮЩХ дСТЬЩУй авХвзСЮЯ.';
	$lang['strconfdroptable'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еФСЬЩди дСТЬЩУе "%s"?';
	$lang['strtabledropped'] = 'єСТЬЩУС еФСЬХЮС.';
	$lang['strtabledroppedbad'] = 'ѕФСЬХЮЩХ дСТЬЩУй авХвзСЮЯ.';
	$lang['strconfemptytable'] = 'їй езХвХЮй, одЯ ШЯдЩдХ ЯоЩгдЩди дСТЬЩУе "%s"?';
	$lang['strtableemptied'] = 'єСТЬЩУС ЯоЩнХЮС.';
	$lang['strtableemptiedbad'] = 'яоЩгдЫС дСТЬЩУй авХвзСЮС.';
	$lang['strinsertrow'] = 'фЯТСзЩди кСаЩги';
	$lang['strrowinserted'] = 'њСаЩги ФЯТСзЬХЮС.';
	$lang['strrowinsertedbad'] = 'фЯТСзЬХЮЩХ кСаЩгЩ авХвзСЮЯ.';
	$lang['streditrow'] = 'ђХФСЫдЩвЯзСди кСаЩги';
	$lang['strrowupdated'] = 'њСаЩги ЯТЮЯзЬХЮС.';
	$lang['strrowupdatedbad'] = 'яТЮЯзЬХЮЩХ кСаЩгЩ авХвзСЮЯ.';
	$lang['strdeleterow'] = 'ѕФСЬЩди кСаЩги';
	$lang['strconfdeleterow'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еФСЬЩди кСаЩги?';
	$lang['strrowdeleted'] = 'њСаЩги еФСЬХЮС.';
	$lang['strrowdeletedbad'] = 'ѕФСЬХЮЩХ кСаЩгЩ авХвзСЮЯ.';
	$lang['strsaveandrepeat'] = 'їгдСзЩди Щ аЯздЯвЩди';
	$lang['strfield'] = '№ЯЬХ';
	$lang['strfields'] = '№ЯЬб';
	$lang['strnumfields'] = 'ыЯЬ-зЯ аЯЬХЪ';
	$lang['strfieldneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ ЮСкзСди аЯЬХ';
	$lang['strselectallfields'] = 'їйТвСди згХ аЯЬб';
	$lang['strselectneedscol'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди аЯ ЫвСЪЮХЪ ЭХвХ ЯФЩЮ СдвЩТед';
	$lang['strselectunary'] = 'ѕЮСвЮйЪ ЯаХвСдЯв ЮХ ЭЯжХд ЩЭХди зХЬЩоЩЮе.';
	$lang['straltercolumn'] = 'щкЭХЮЩди СдвЩТед';
	$lang['strcolumnaltered'] = 'сдвЩТед ЩкЭХЮХЮ.';
	$lang['strcolumnalteredbad'] = 'щкЭХЮХЮЩХ СдвЩТедС авХвзСЮЯ.';
	$lang['strconfdropcolumn'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еФСЬЩди СдвЩТед "%s" дСТЬЩУй "%s"?';
	$lang['strcolumndropped'] = 'сдвЩТед еФСЬХЮ.';
	$lang['strcolumndroppedbad'] = 'ѕФСЬХЮЩХ СдвЩТедС авХвзСЮЯ.';
	$lang['straddcolumn'] = 'фЯТСзЩди СдвЩТед';
	$lang['strcolumnadded'] = 'сдвЩТед ФЯТСзЬХЮ.';
	$lang['strcolumnaddedbad'] = 'фЯТСзЬХЮЩХ СдвЩТедС авХвзСЮЯ.';
	$lang['strdataonly'] = 'єЯЬиЫЯ ФСЮЮйХ';
	$lang['strcascade'] = 'ыСгЫСФЯЭ';
	$lang['strtablealtered'] = 'єСТЬЩУС ЩкЭХЮХЮС.';
	$lang['strtablealteredbad'] = 'щкЭХЮХЮЩХ дСТЬЩУй авХвзСЮЯ.';
	$lang['strdataonly'] = 'єЯЬиЫЯ ФСЮЮйХ';
	$lang['strstructureonly'] = 'єЯЬиЫЯ гдвеЫдеве';
	$lang['strstructureanddata'] = 'ѓдвеЫдеве Щ ФСЮЮйХ';

	// Users
	$lang['struser'] = '№ЯЬикЯзСдХЬи';
	$lang['strusers'] = '№ЯЬикЯзСдХЬЩ';
	$lang['strusername'] = 'щЭб аЯЬикЯзСдХЬб';
	$lang['strpassword'] = '№СвЯЬи';
	$lang['strsuper'] = 'ѓеаХваЯЬикЯзСдХЬи?';
	$lang['strcreatedb'] = 'ѓЯкФСди ТСке ФСЮЮйШ?';
	$lang['strexpires'] = 'ѓвЯЫ ФХЪгдзЩб';
	$lang['strnousers'] = 'юХд дСЫЩШ аЯЬикЯзСдХЬХЪ.';
	$lang['struserupdated'] = '№ЯЬикЯзСдХЬи ЯТЮЯзЬХЮ.';
	$lang['struserupdatedbad'] = 'яТЮЯзЬХЮЩХ аЯЬикЯзСдХЬб авХвзСЮЯ.';
	$lang['strshowallusers'] = '№ЯЫСкСди згХШ аЯЬикЯзСдХЬХЪ';
	$lang['strcreateuser'] = 'ѓЯкФСди аЯЬикЯзСдХЬб';
	$lang['struserneedsname'] = 'їй ФЯЬжЮй ззХгдЩ ЩЭб аЯЬикЯзСдХЬб.';
	$lang['strusercreated'] = '№ЯЬикЯзСдХЬи гЯкФСЮ.';
	$lang['strusercreatedbad'] = 'ѓЯкФСЮЩХ аЯЬикЯзСдХЬб авХвзСЮЯ.';
	$lang['strconfdropuser'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еФСЬЩди аЯЬикЯзСдХЬб "%s"?';
	$lang['struserdropped'] = '№ЯЬикЯзСдХЬи еФСЬХЮ.';
	$lang['struserdroppedbad'] = 'ѕФСЬХЮЩХ аЯЬикЯзСдХЬб авХвзСЮЯ.';
	$lang['straccount'] = 'сЫЫСеЮд';
	$lang['strchangepassword'] = 'щкЭХЮЩди аСвЯЬи';
	$lang['strpasswordchanged'] = '№СвЯЬи ЩкЭХЮХЮ.';
	$lang['strpasswordchangedbad'] = 'щкЭХЮХЮЩХ аСвЯЬб авХвзСЮЯ.';
	$lang['strpasswordshort'] = '№СвЯЬи гЬЩлЫЯЭ ЫЯвЯдЫЩЪ.';
	$lang['strpasswordconfirm'] = '№СвЯЬи ЮХ гЯЯдзХдгдзеХд аЯФдзХвжФХЮЩР.';

	// Groups
	$lang['strgroup'] = 'чвеааС';
	$lang['strgroups'] = 'чвеаай';
	$lang['strnogroup'] = 'чвеааС ЮХ ЯТЮСвежХЮС.';
	$lang['strnogroups'] = 'юЩ ЯФЮЯЪ Чвеаай ЮХ ЯТЮСвежХЮЯ.';
	$lang['strcreategroup'] = 'ѓЯкФСди Чвеаае';
	$lang['strshowallgroups'] = '№ЯЫСкСди згХ Чвеаай';
	$lang['strgroupneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ЮСкзСЮЩХ Чвеаай.';
	$lang['strgroupcreated'] = 'чвеааС гЯкФСЮС.';
	$lang['strgroupcreatedbad'] = 'ѓЯкФСЮЩХ Чвеаай авХвзСЮЯ.';
	$lang['strconfdropgroup'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еФСЬЩди Чвеаае "%s"?';
	$lang['strgroupdropped'] = 'чвеааС еФСЬХЮС.';
	$lang['strgroupdroppedbad'] = 'ѕФСЬХЮЩХ Чвеаай авХвзСЮЯ.';
	$lang['strmembers'] = 'ѕоСгдЮЩЫЯз';
	$lang['straddmember'] = 'фЯТСзЩди еоСгдЮЩЫС';
	$lang['strmemberadded'] = 'ѕоСгдЮЩЫ ФЯТСзЬХЮ.';
	$lang['strmemberaddedbad'] = 'фЯТСзЬХЮЩХ еоСгдЮЩЫС авХвзСЮЯ.';
	$lang['strdropmember'] = 'ѕФСЬЩди еоСгдЮЩЫС';
	$lang['strconfdropmember'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еФСЬЩди еоСгдЮЩЫС "%s" Щк Чвеаай "%s"?';
	$lang['strmemberdropped'] = 'ѕоСгдЮЩЫ еФСЬХЮ.';
	$lang['strmemberdroppedbad'] = 'ѕФСЬХЮЩХ еоСгдЮЩЫС авХвзСЮЯ.';

	// Privilges
	$lang['strprivilege'] = '№вЩзЩЬХЧЩб';
	$lang['strprivileges'] = '№вЩзЩЬХЧЩЩ';
	$lang['strnoprivileges'] = 'яТпХЫд ЮХ ЩЭХХд авЩзЩЬХЧЩЪ.';
	$lang['strgrant'] = 'ѕгЩЬЩди';
	$lang['strrevoke'] = 'ягЬСТЩди';
	$lang['strgranted'] = '№вЩзЩЬХЧЩЩ ЩкЭХЮХЮй.';
	$lang['strgrantfailed'] = 'щкЭХЮХЮЩХ авЩзЩЬХЧЩЪ авХвзСЮЯ.';
	$lang['strgrantbad'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ШЯдб Тй ЯФЮЯЧЯ аЯЬикЯзСдХЬб ЩЬЩ Чвеаае Щ ШЯдб Тй ЯФЮе авЩзЩЬХЧЩР.';
	$lang['stralterprivs'] = 'щкЭХЮЩди авЩзЩЬХЧЩЩ';
	$lang['strgrantor'] = 'фЯЮЯв';
	$lang['strasterisk'] = '*';

	// Databases
	$lang['strdatabase'] = 'тСкС ФСЮЮйШ';
	$lang['strdatabases'] = 'тСкй ФСЮЮйШ';
	$lang['strshowalldatabases'] = '№ЯЫСкСди згХ ТСкй ФСЮЮйШ';
	$lang['strnodatabase'] = 'тСкС ФСЮЮйШ ЮХ ЯТЮСвежХЮС.';
	$lang['strnodatabases'] = 'юЩ ЯФЮЯЪ ТСкй ФСЮЮйШ ЮХ ЯТЮСвежХЮЯ.';
	$lang['strcreatedatabase'] = 'ѓЯкФСди ТСке ФСЮЮйШ';
	$lang['strdatabasename'] = 'щЭб ТСкй ФСЮЮйШ';
	$lang['strdatabaseneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ авЩгзЯЩди ЩЭб їСлХЪ ТСкХ ФСЮЮйШ.';
	$lang['strdatabasecreated'] = 'тСкС ФСЮЮйШ гЯкФСЮС.';
	$lang['strdatabasecreatedbad'] = 'ѓЯкФСЮЩХ ТСкй ФСЮЮйШ авХвзСЮЯ.';
	$lang['strconfdropdatabase'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еЮЩодЯжЩди ТСке ФСЮЮйШ "%s"?';
	$lang['strdatabasedropped'] = ' тСкС ФСЮЮйШ еЮЩодЯжХЮС.';
	$lang['strdatabasedroppedbad'] = 'ѕЮЩодЯжХЮЩХ ТСкй ФСЮЮйШ авХвзСЮЯ.';
	$lang['strentersql'] = 'їзХФЩдХ SQL-кСавЯг ЮЩжХ:';
	$lang['strvacuumgood'] = 'яаХвСУЩб аХвХгдвЯЪЫЩ кСзХвлХЮС.';
	$lang['strvacuumbad'] = 'яаХвСУЩб аХвХгдвЯЪЫЩ авХвзСЮС.';
	$lang['stranalyzegood'] = ' яаХвСУЩб СЮСЬЩкС кСзХвлХЮС.';
	$lang['stranalyzebad'] = ' яаХвСУЩб СЮСЬЩкС кСзХвлХЮС.';

	// Views
	$lang['strview'] = '№вХФгдСзЬХЮЩХ';
	$lang['strviews'] = '№вХФгдСзЬХЮЩб';
	$lang['strshowallviews'] = '№ЯЫСкСди згХ авХФгдСзЬХЮЩб';
	$lang['strnoview'] = '№вХФгдСзЬХЮЩХ ЮХ ЯТЮСвежХЮЯ.';
	$lang['strnoviews'] = 'юЩ ЯФЮЯЧЯ авХФгдСзЬХЮЩб ЮХ ЯТЮСвежХЮЯ.';
	$lang['strcreateview'] = 'ѓЯкФСди авХФгдСзЬХЮЩХ';
	$lang['strviewname'] = 'щЭб авХФгдСзЬХЮЩб';
	$lang['strviewneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ЩЭб авХФгдСзЬХЮЩб.';
	$lang['strviewneedsdef'] = ' їСЭ ЮХЯТШЯФЩЭЯ ЯавХФХЬЩди СдвЩТедй авХФгдСзЬХЮЩб.';
	$lang['strviewcreated'] = '№вХФгдСзЬХЮЩХ гЯкФСЮЯ.';
	$lang['strviewcreatedbad'] = 'ѓЯкФСЮЩХ авХФгдСзЬХЮЩб авХвзСЮЯ.';
	$lang['strconfdropview'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еЮЩодЯжЩди авХФгдСзЬХЮЩХ "%s"?';
	$lang['strviewdropped'] = '№вХФгдСзЬХЮЩХ еЮЩодЯжХЮЯ.';
	$lang['strviewdroppedbad'] = 'ѕЮЩодЯжХЮЩХ авХФгдСзЬХЮЩб авХвзСЮЯ.';
	$lang['strviewupdated'] = '№вХФгдСзЬХЮЩХ ЯТЮЯзЬХЮЯ.';
	$lang['strviewupdatedbad'] = 'яТЮЯзЬХЮЩХ авХФгдСзЬХЮЩб авХвзСЮЯ.';

	// Sequences
	$lang['strsequence'] = '№ЯгЬХФЯзСдХЬиЮЯгди';
	$lang['strsequences'] = ' №ЯгЬХФЯзСдХЬиЮЯгдЩ';
	$lang['strshowallsequences'] = '№ЯЫСкСди згХ аЯгЬХФЯзСдХЬиЮЯгдЩ';
	$lang['strnosequence'] = '№ЯгЬХФЯзСдХЬиЮЯгди ЮХ ЯТЮСвежХЮС.';
	$lang['strnosequences'] = 'юЩ ЯФЮЯЪ аЯгЬХФЯзСдХЬиЮЯгдЩ ЮХ ЯТЮСвежХЮЯ.';
	$lang['strcreatesequence'] = 'ѓЯкФСди аЯгЬХФЯзСдХЬиЮЯгди';
	$lang['strlastvalue'] = '№ЯгЬХФЮХХ кЮСоХЮЩХ';
	$lang['strincrementby'] = 'ѕзХЬЩоХЮЩХ ЮС';
	$lang['strstartvalue'] = 'юСоСЬиЮЯХ кЮСоХЮЩХ';
	$lang['strmaxvalue'] = 'эСЫг. зХЬЩоЩЮС';
	$lang['strminvalue'] = 'эЩЮ. зХЬЩоЩЮС';
	$lang['strcachevalue'] = 'ђСкЭХв ЫмлС';
	$lang['strlogcount'] = 'Log Count';
	$lang['striscycled'] = 'њСУЩЫЬЩди?';
	$lang['strsequenceneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ЩЭб аЯгЬХФЯзСдХЬиЮЯгдЩ.';
	$lang['strsequencecreated'] = '№ЯгЬХФЯзСдХЬиЮЯгди гЯкФСЮС.';
	$lang['strsequencecreatedbad'] = 'ѓЯкФСЮЩХ аЯгЬХФЯзСдХЬиЮЯгдЩ авХвзСЮЯ.';
	$lang['strconfdropsequence'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еЮЩодЯжЩди аЯгЬХФЯзСдХЬиЮЯгди "%s"?';
	$lang['strsequencedropped'] = '№ЯгЬХФЯзСдХЬиЮЯгди еЮЩодЯжХЮС.';
	$lang['strsequencedroppedbad'] = 'ѕЮЩодЯжХЮЩХ аЯгЬХФЯзСдХЬиЮЯгдЩ авХвзСЮЯ.';
	$lang['strsequencereset'] = '№ЯгЬХФЯзСдХЬиЮЯгди гТвЯлХЮС.';
	$lang['strsequenceresetbad'] = 'ѓТвЯг аЯгЬХФЯзСдХЬиЮЯгдЩ авХвзСЮ.'; 

	// Indexes
	$lang['strindexes'] = 'щЮФХЫг';
	$lang['strindexname'] = 'щЭб ЩЮФХЫгС';
	$lang['strshowallindexes'] = '№ЯЫСкСди згХ ЩЮФХЫгй';
	$lang['strnoindex'] = 'щЮФХЫг ЮХ ЯТЮСвежХЮ.';
	$lang['strnoindexes'] = 'юЩ ЯФЮЯЧЯ ЩЮФХЫгС ЮХ ЯТЮСвежХЮЯ.';
	$lang['strcreateindex'] = 'ѓЯкФСди ЩЮФХЫг';
	$lang['strtabname'] = 'щЭб дСТЬЩУй';
	$lang['strcolumnname'] = 'щЭб СдвЩТедС';
	$lang['strindexneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ЩЭб ЩЮФХЫгС';
	$lang['strindexneedscols'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ФЯаегдЩЭЯХ ЫЯЬЩоХгдзЯ СдвЩТедЯз.';
	$lang['strindexcreated'] = 'щЮФХЫг гЯкФСЮ.';
	$lang['strindexcreatedbad'] = 'ѓЯкФСЮЩХ ЩЮФХЫгС авХвзСЮЯ.';
	$lang['strconfdropindex'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еЮЩодЯжЩди ЩЮФХЫг "%s"?';
	$lang['strindexdropped'] = 'щЮФХЫг еЮЩодЯжХЮ.';
	$lang['strindexdroppedbad'] = 'ѕЮЩодЯжХЮЩХ ЩЮФХЫгС авХвзСЮЯ.';
	$lang['strkeyname'] = 'щЭб ЫЬРоС';
	$lang['struniquekey'] = 'ѕЮЩЫСЬиЮйЪ ЫЬРо';
	$lang['strprimarykey'] = '№ХвзЩоЮйЪ ЫЬРо';
	$lang['strindextype'] = 'їЩФ ЩЮФХЫгС';
	$lang['strindexname'] = 'щЭб ЩЮФХЫгС';
	$lang['strtablecolumnlist'] = 'сдвЩТедЯз з дСТЬЩУХ';
	$lang['strindexcolumnlist'] = 'сдвЩТедЯз з ЩЮФХЫгХ';
	$lang['strconfcluster'] = 'їй езХвХЮй, одЯ ШЯдЩдХ ЫЬСгдХвЩкЯзСди "%s"?';
	$lang['strclusteredgood'] = 'ыЬСгдХвЩкСУЩб кСзХвлХЮС.';
	$lang['strclusteredbad'] = 'ыЬСгдХвЩкСУЩб авХвзСЮС.';

	// Rules
	$lang['strrules'] = '№вСзЩЬС';
	$lang['strrule'] = '№вСзЩЬЯ';
	$lang['strshowallrules'] = '№ЯЫСкСди згХ авСзЩЬС';
	$lang['strnorule'] = '№вСзЩЬЯ ЮХ ЯТЮСвежХЮЯ.';
	$lang['strnorules'] = 'юЩ ЯФЮЯЧЯ авСзЩЬС ЮХ ЯТЮСвежХЮЯ.';
	$lang['strcreaterule'] = 'ѓЯкФСди авСзЩЬЯ';
	$lang['strrulename'] = 'щЭб авСзЩЬС';
	$lang['strruleneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ЩЭб авСзЩЬС.';
	$lang['strrulecreated'] = '№вСзЩЬЯ гЯкФСЮЯ.';
	$lang['strrulecreatedbad'] = 'ѓЯкФСЮЩХ авСзЩЬС авХвзСЮЯ.';
	$lang['strconfdroprule'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еЮЩодЯжЩди авСзЩЬЯ "%s" on "%s"?';
	$lang['strruledropped'] = '№вСзЩЬЯ еЮЩодЯжХЮЯ.';
	$lang['strruledroppedbad'] = 'ѕЮЩодЯжХЮЩХ авСзЩЬС авХвзСЮЯ.';

	// Constraints
	$lang['strconstraints'] = 'яЧвСЮЩоХЮЩб';
	$lang['strshowallconstraints'] = '№ЯЫСкСди згХ ЯЧвСЮЩоХЮЩб';
	$lang['strnoconstraints'] = 'юЩ ЯФЮЯЧЯ ЯЧвСЮЩоХЮЩб ЮХ ЯТЮСвежХЮЯ.';
	$lang['strcreateconstraint'] = 'ѓЯкФСди ЯЧвСЮЩоХЮЩХ';
	$lang['strconstraintcreated'] = 'яЧвСЮЩоХЮЩХ гЯкФСЮЯ.';
	$lang['strconstraintcreatedbad'] = 'ѓЯкФСЮЩХ ЯЧвСЮЩоХЮЩб авХвзСЮЯ.';
	$lang['strconfdropconstraint'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еЮЩодЯжЩди ЯЧвСЮЩоХЮЩХ "%s" on "%s"?';
	$lang['strconstraintdropped'] = 'яЧвСЮЩоХЮЩХ еЮЩодЯжХЮЯ.';
	$lang['strconstraintdroppedbad'] = 'ѕЮЩодЯжХЮЩХ ЯЧвСЮЩоХЮЩб авХвзСЮЯ.';
	$lang['straddcheck'] = 'фЯТСзЩди авЯзХвЫе';
	$lang['strcheckneedsdefinition'] = 'яЧвСЮЩоХЮЩХ авЯзХвЫЩ ЮежФСХдгб з ЯавХФХЬХЮЩЩ.';
	$lang['strcheckadded'] = 'яЧвСЮЩоХЮЩХ авЯзХвЫЩ ФЯТСзЬХЮЯ.';
	$lang['strcheckaddedbad'] = 'фЯТСзЬХЮЩХ ЯЧвСЮЩоХЮЩб авЯзХвЫЩ авХвзСЮЯ.';
	$lang['straddpk'] = 'фЯТСзЩди аХвзЩоЮйЪ ЫЬРо';
	$lang['strpkneedscols'] = '№ХвзЩоЮйЪ ЫЬРо ФЯЬжХЮ зЫЬРоСди ШЯдб Тй ЯФЩЮ СдвЩТед.';
	$lang['strpkadded'] = '№ХвзЩоЮйЪ ЫЬРо ФЯТСзЬХЮ.';
	$lang['strpkaddedbad'] = 'фЯТСзЬХЮЩХ аХвзЩоЮЯЧЯ ЫЬРоС авХвзСЮЯ.';
	$lang['stradduniq'] = 'фЯТСзЩди еЮЩЫСЬиЮйЪ ЫЬРо';
	$lang['struniqneedscols'] = 'ѕЮЩЫСЬиЮйЪ ЫЬРо ФЯЬжХЮ зЫЬРоСди ШЯдб Тй ЯФЩЮ СдвЩТед.';
	$lang['struniqadded'] = 'ѕЮЩЫСЬиЮйЪ ЫЬРо ФЯТСзЬХЮ.';
	$lang['struniqaddedbad'] = 'фЯТСзЬХЮЩХ еЮЩЫСЬиЮЯЧЯ ЫЬРоС авХвзСЮЯ.';
	$lang['straddfk'] = 'фЯТСзЩди зЮХлЮЩЪ ЫЬРо';
	$lang['strfkneedscols'] = 'їЮХлЮЩЪ ЫЬРо ФЯЬжХЮ зЫЬРоСди ШЯдб Тй ЯФЩЮ СдвЩТед.';
	$lang['strfkneedstarget'] = 'їЮХлЮХЭе ЫЬРое ЮХЯТШЯФЩЭЯ еЫСкСди УХЬХзеР дСТЬЩУе.';
	$lang['strfkadded'] = 'їЮХлЮЩЪ ЫЬРо ФЯТСзЬХЮ.';
	$lang['strfkaddedbad'] = 'фЯТСзЬХЮЩХ зЮХлЮХЧЯ ЫЬРоС авХвзСЮЯ.';
	$lang['strfktarget'] = 'уХЬХзСб дСТЬЩУС';
	$lang['strfkcolumnlist'] = 'сдвЩТедй з ЫЬРоХ';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';	

	// Functions
	$lang['strfunction'] = 'цеЮЫУЩб';
	$lang['strfunctions'] = ' цеЮЫУЩЩ';
	$lang['strshowallfunctions'] = '№ЯЫСкСди згХ ЦеЮЫУЩЩ';
	$lang['strnofunction'] = 'цеЮЫУЩб ЮХ ЯТЮСвежХЮС.';
	$lang['strnofunctions'] = 'юЩ ЯФЮЯЪ ЦеЮЫУЩЩ ЮХ ЯТЮСвежХЮЯ.';
	$lang['strcreatefunction'] = 'ѓЯкФСди ЦеЮЫУЩР';
	$lang['strfunctionname'] = 'щЭб ЦеЮЫУЩЩ';
	$lang['strreturns'] = 'їЯкзвСнСХЭЯХ кЮСоХЮЩХ';
	$lang['strarguments'] = 'свЧеЭХЮдй';
	$lang['strproglanguage'] = 'ёкйЫ авЯЧвСЭЭЩвЯзСЮЩб';
	$lang['strproglanguage'] = 'ёкйЫ';
	$lang['strfunctionneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ЩЭб ЦеЮЫУЩЩ.';
	$lang['strfunctionneedsdef'] = 'їСЭ ЮХЯТШЯФЩЭЯ ЯавХФХЬЩди ЦеЮЫУЩР.';
	$lang['strfunctioncreated'] = 'цеЮЫУЩб гЯкФСЮС.';
	$lang['strfunctioncreatedbad'] = 'ѓЯкФСЮЩХ ЦеЮЫУЩЩ авХвзСЮЯ.';
	$lang['strconfdropfunction'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еЮЩодЯжЩди ЦеЮЫУЩР "%s"?';
	$lang['strfunctiondropped'] = 'цеЮЫУЩб еЮЩодЯжХЮС.';
	$lang['strfunctiondroppedbad'] = 'ѕЮЩодЯжХЮЩХ ЦеЮЫУЩЩ авХвзСЮЯ.';
	$lang['strfunctionupdated'] = 'цеЮЫУЩб ЯТЮЯзЬХЮС.';
	$lang['strfunctionupdatedbad'] = 'яТЮЯзЬХЮЩХ ЦеЮЫУЩЩ авХвзСЮЯ.';

	// Triggers
	$lang['strtrigger'] = 'євЩЧЧХв';
	$lang['strtriggers'] = ' євЩЧЧХвй';
	$lang['strshowalltriggers'] = '№ЯЫСкСди згХ двЩЧЧХвй';
	$lang['strnotrigger'] = 'євЩЧЧХв ЮХ ЯТЮСвежХЮ.';
	$lang['strnotriggers'] = 'юЩ ЯФЮЯЧЯ двЩЧЧХвС ЮХ ЯТЮСвежХЮЯ.';
	$lang['strcreatetrigger'] = 'ѓЯкФСди двЩЧЧХв';
	$lang['strtriggerneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ЩЭб двЩЧЧХвС.';
	$lang['strtriggerneedsfunc'] = 'їСЭ ЮХЯТШЯФЩЭЯ ЯавХФХЬЩди ЦеЮЫУЩР двЩЧЧХвС.';
	$lang['strtriggercreated'] = 'євЩЧЧХв гЯкФСЮ.';
	$lang['strtriggercreatedbad'] = 'ѓЯкФСЮЩХ двЩЧЧХвС авХвзСЮЯ.';
	$lang['strconfdroptrigger'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еЮЩодЯжЩди двЩЧЧХв "%s" ЮС "%s"?';
	$lang['strtriggerdropped'] = 'євЩЧЧХв еЮЩодЯжХЮ.';
	$lang['strtriggerdroppedbad'] = 'ѕЮЩодЯжХЮЩХ двЩЧЧХвС авХвзСЮЯ.';
	$lang['strtriggeraltered'] = 'євЩЧЧХв ЩкЭХЮХЮ.';
	$lang['strtriggeralteredbad'] = 'щкЭХЮХЮЩХ двЩЧЧХвС авХвзСЮЯ.';

	// Types
	$lang['strtype'] = 'єЩа ФСЮЮйШ';
	$lang['strtypes'] = 'єЩай ФСЮЮйШ';
	$lang['strshowalltypes'] = '№ЯЫСкСди згХ дЩай ФСЮЮйШ';
	$lang['strnotype'] = 'єЩа ФСЮЮйШ ЮХ ЯТЮСвежХЮ.';
	$lang['strnotypes'] = 'юЩ ЯФЮЯЧЯ дЩаС ФСЮЮйШ ЮХ ЯТЮСвежХЮЯ.';
	$lang['strcreatetype'] = 'ѓЯкФСди дЩа ФСЮЮйШ';
	$lang['strtypename'] = 'щЭб дЩаС ФСЮЮйШ';
	$lang['strinputfn'] = 'цеЮЫУЩб ззЯФС';
	$lang['stroutputfn'] = 'цеЮЫУЩб зйзЯФС';
	$lang['strpassbyval'] = '№ХвХФСди аЯ кЮСоХЮЩР?';
	$lang['stralignment'] = 'їйвСзЮЩзСЮЩХ';
	$lang['strelement'] = 'ќЬХЭХЮд';
	$lang['strdelimiter'] = 'ђСкФХЬЩдХЬи';
	$lang['strstorage'] = 'Storage';
	$lang['strtypeneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ЩЭб дЩаС ФСЮЮйШ.';
	$lang['strtypeneedslen'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди вСкЭХв ФЬб дЩаС ФСЮЮйШ.';
	$lang['strtypecreated'] = 'єЩа ФСЮЮйШ гЯкФСЮ.';
	$lang['strtypecreatedbad'] = 'ѓЯкФСЮЩХ дЩаС ФСЮЮйШ авХвзСЮЯ.';
	$lang['strconfdroptype'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еЮЩодЯжЩди дЩа ФСЮЮйШ "%s"?';
	$lang['strtypedropped'] = 'єЩа ФСЮЮйШ еЮЩодЯжХЮ.';
	$lang['strtypedroppedbad'] = 'ѕЮЩодЯжХЮЩХ дЩаС ФСЮЮйШ авХвзСЮЯ.';

	// Schemas
	$lang['strschema'] = 'ѓШХЭС';
	$lang['strschemas'] = 'ѓШХЭй';
	$lang['strshowallschemas'] = '№ЯЫСкСди згХ гШХЭй';
	$lang['strnoschema'] = 'ѓШХЭС ЮХ ЯТЮСвежХЮС.';
	$lang['strnoschemas'] = 'юЩ ЯФЮЯЪ гШХЭй ЮХ ЯТЮСвежХЮЯ.';
	$lang['strcreateschema'] = 'ѓЯкФСди гШХЭе';
	$lang['strschemaname'] = 'щЭб гШХЭй';
	$lang['strschemaneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ЩЭб гШХЭй.';
	$lang['strschemacreated'] = 'ѓШХЭС гЯкФСЮС.';
	$lang['strschemacreatedbad'] = 'ѓЯкФСЮЩХ гШХЭй авХвзСЮЯ.';
	$lang['strconfdropschema'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еЮЩодЯжЩди гШХЭе "%s"?';
	$lang['strschemadropped'] = 'ѓШХЭС еЮЩодЯжХЮС.';
	$lang['strschemadroppedbad'] = 'ѕЮЩодЯжХЮЩХ гШХЭй авХвзСЮЯ.';

	// Reports

	// Domains
	$lang['strdomain'] = 'фЯЭХЮ';
	$lang['strdomains'] = 'фЯЭХЮй';
	$lang['strshowalldomains'] = '№ЯЫСкСди згХ ФЯЭХЮй';
	$lang['strnodomains'] = 'юЩ ЯФЮЯЧЯ ФЯЭХЮС ЮХ ЯТЮСвежХЮЯ.';
	$lang['strcreatedomain'] = 'ѓЯкФСди ФЯЭХЮ';
	$lang['strdomaindropped'] = 'фЯЭХЮ еФСЬХЮ.';
	$lang['strdomaindroppedbad'] = 'ѕФСЬХЮЩХ ФЯЭХЮС авХвзСЮЯ.';
	$lang['strconfdropdomain'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еФСЬЩди ФЯЭХЮ "%s"?';
	$lang['strdomainneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ЩЭб ФЯЭХЮС.';
	$lang['strdomaincreated'] = 'фЯЭХЮ гЯкФСЮ.';
	$lang['strdomaincreatedbad'] = 'ѓЯкФСЮЩХ ФЯЭХЮС авХвзСЮЯ.';	
	$lang['strdomainaltered'] = 'фЯЭХЮ ЩкЭХЮХЮ.';
	$lang['strdomainalteredbad'] = 'щкЭХЮХЮЩХ ФЯЭХЮС авХвзСЮЯ.';	

	// Operators
	$lang['stroperator'] = 'яаХвСдЯв';
	$lang['stroperators'] = 'яаХвСдЯвй';
	$lang['strshowalloperators'] = '№ЯЫСкСди згХ ЯаХвСдЯвй';
	$lang['strnooperator'] = 'яаХвСдЯв ЮХ ЯТЮСвежХЮ.';
	$lang['strnooperators'] = 'яаХвСдЯвй ЮХ ЯТЮСвежХЮй.';
	$lang['strcreateoperator'] = 'ѓЯкФСди ЯаХвСдЯв';
	$lang['strleftarg'] = 'єЩа ЬХзЯЧЯ СвЧеЭХЮдС';
	$lang['strrightarg'] = 'єЩа авСзЯЧЯ СвЧеЭХЮдС';
	$lang['strcommutator'] = '№вХЯТвСкЯзСЮЩХ';
	$lang['strnegator'] = 'ядвЩУСЮЩХ';
	$lang['strrestrict'] = 'ягЬСТЬХЮЩХ';
	$lang['strjoin'] = 'яТпХФЩЮХЮЩХ';
	$lang['strhashes'] = 'шХлЩвЯзСЮЩХ';
	$lang['strmerges'] = 'ѓЬЩбЮЩХ';
	$lang['strleftsort'] = 'ѓЯдЩвЯзЫС аЯ ЬХзЯЭе';
	$lang['strrightsort'] = 'ѓЯдЩвЯзЫС аЯ авСзЯЭе';
	$lang['strlessthan'] = 'эХЮилХ';
	$lang['strgreaterthan'] = 'тЯЬилХ';
	$lang['stroperatorneedsname'] = 'їСЭ ЮХЯТШЯФЩЭЯ еЫСкСди ЮСкзСЮЩХ ЯаХвСдЯвС.';
	$lang['stroperatorcreated'] = 'яаХвСдЯв гЯкФСЮ';
	$lang['stroperatorcreatedbad'] = 'ЯкФСЮЩХ ЯаХвСдЯвС авХвзСЮЯ.';
	$lang['strconfdropoperator'] = 'їй езХвХЮй, одЯ ШЯдЩдХ еЮЩодЯжЩди ЯаХвСдЯв "%s"?';
	$lang['stroperatordropped'] = 'яаХвСдЯв еФСЬХЮ.';
	$lang['stroperatordroppedbad'] = 'ѕФСЬХЮЩХ ЯаХвСдЯвС авХвзСЮЯ.';

	// Casts
	$lang['strcasts'] = 'яТвСкУй';
	$lang['strnocasts'] = 'яТвСкУЯз ЮХ ЯТЮСвежХЮЯ.';
	$lang['strsourcetype'] = 'єЩа ЩгдЯоЮЩЫС';
	$lang['strtargettype'] = 'єЩа авЩХЭЮЩЫС';
	$lang['strimplicit'] = 'юХбзЮйЪ';
	$lang['strinassignment'] = 'ї ЮСкЮСоХЮЩЩ';
	$lang['strbinarycompat'] = '(ФзЯЩоЮЯ гЯзЭХгдЩЭйЪ)';
	
	// Conversions
	$lang['strconversions'] = '№вХЯТвСкЯзСЮЩХ';
	$lang['strnoconversions'] = '№вХЯТвСкЯзСЮЩЪ ЮХ ЯТЮСвежХЮЯ.';
	$lang['strsourceencoding'] = 'ыЯФЩвЯзЫС ЩгдЯоЮЩЫС';
	$lang['strtargetencoding'] = 'ыЯФЩвЯзЫС авЩХЭЮЩЫС';
	
	// Languages
	$lang['strlanguages'] = 'ёкйЫЩ';
	$lang['strnolanguages'] = 'ёкйЫЯз ЮХ ЯТЮСвежХЮЯ.';
	$lang['strtrusted'] = '№вЯзХвХЮЯ';
	
	// Info
	$lang['strnoinfo'] = 'юХд ФЯгдеаЮЯЪ ЩЮЦЯвЭСУЩЩ.';
	$lang['strreferringtables'] = 'ѓгйЬСРнЩХгб дСТЬЩУй';
	$lang['strparenttables'] = 'ђЯФЩдХЬигЫЩХ дСТЬЩУй';
	$lang['strchildtables'] = 'фЯоХвЮЩХ дСТЬЩУй';

	// Miscellaneous
	$lang['strtopbar'] = '%s зйаЯЬЮбХдгб ЮС %s:%s -- їй кСвХЧЩгдвЩвЯзСЮй ЫСЫ "%s"';
	$lang['strtimefmt'] = ' j-m-Y  g:i';

?>

