<?php
/**
	* Romanian language file, based on the english language file for phpPgAdmin.
	* Alin Vaida [alin.vaida@gmail.com]
	*
	* $Id: romanian.php,v 1.7 2007/04/24 11:42:07 soranzo Exp $
	*/

	// Language and character set
	$lang['applang'] = 'Română';
	$lang['applocale'] = 'ro-RO';
	$lang['applangdir'] = 'ltr';

	// Welcome
	$lang['strintro'] = 'Bun venit în phpPgAdmin.';
	$lang['strppahome'] = 'Pagina phpPgAdmin';
	$lang['strpgsqlhome'] = 'Pagina PostgreSQL';
	$lang['strpgsqlhome_url'] = 'http://www.postgresql.org/';
	$lang['strlocaldocs'] = 'Documentaţie locală PostgreSQL';
	$lang['strreportbug'] = 'Raportaţi o eroare';
	$lang['strviewfaq'] = 'Întrebări frecvente online';
	$lang['strviewfaq_url'] = 'http://phppgadmin.sourceforge.net/doku.php?id=faq';

	// Basic strings
	$lang['strlogin'] = 'Autentificare';
	$lang['strloginfailed'] = 'Autentificare eşuată';
	$lang['strlogindisallowed'] = 'Autentificare nepermisă din motive de securitate.';
	$lang['strserver'] = 'Server';
	$lang['strservers'] = 'Servere';
	$lang['strintroduction'] = 'Introducere';
	$lang['strhost'] = 'Gazdă';
	$lang['strport'] = 'Port';
	$lang['strlogout'] = 'Ieşire';
	$lang['strowner'] = 'Proprietar';
	$lang['straction'] = 'Acţiune';
	$lang['stractions'] = 'Acţiuni';
	$lang['strname'] = 'Nume';
	$lang['strdefinition'] = 'Definiţie';
	$lang['strproperties'] = 'Proprietăţi';
	$lang['strbrowse'] = 'Vizualizare';
	$lang['strenable'] = 'Activare';
	$lang['strdisable'] = 'Dezactivare';
	$lang['strdrop'] = 'Ştergere';
	$lang['strdropped'] = 'Şters';
	$lang['strnull'] = 'Nul';
	$lang['strnotnull'] = 'Ne-nul';
	$lang['strprev'] = '< Înapoi';
	$lang['strnext'] = 'Înainte >';
	$lang['strfirst'] = '<< Început';
	$lang['strlast'] = 'Sfârşit >>';
	$lang['strfailed'] = 'Eşuat';
	$lang['strcreate'] = 'Creare';
	$lang['strcreated'] = 'Creat';
	$lang['strcomment'] = 'Comentariu';
	$lang['strlength'] = 'Lungime';
	$lang['strdefault'] = 'Implicit';
	$lang['stralter'] = 'Modificare';
	$lang['strok'] = 'OK';
	$lang['strcancel'] = 'Anulare';
	$lang['strac'] = 'Activare Auto-completare';
	$lang['strsave'] = 'Salvare';
	$lang['strreset'] = 'Reiniţializare';
	$lang['strinsert'] = 'Inserare';
	$lang['strselect'] = 'Selectare';
	$lang['strdelete'] = 'Ştergere';
	$lang['strupdate'] = 'Actualizare';
	$lang['strreferences'] = 'Referinţe';
	$lang['stryes'] = 'Da';
	$lang['strno'] = 'Nu';
	$lang['strtrue'] = 'TRUE';
	$lang['strfalse'] = 'FALSE';
	$lang['stredit'] = 'Editare';
	$lang['strcolumn'] = 'Coloană';
	$lang['strcolumns'] = 'Coloane';
	$lang['strrows'] = 'rând(uri)';
	$lang['strrowsaff'] = 'rând(uri) afectate.';
	$lang['strobjects'] = 'obiect(e)';
	$lang['strback'] = 'Înapoi';
	$lang['strqueryresults'] = 'Rezultatele interogării';
	$lang['strshow'] = 'Afişare';
	$lang['strempty'] = 'Golire';
	$lang['strlanguage'] = 'Limbă';
	$lang['strencoding'] = 'Codificare';
	$lang['strvalue'] = 'Valoare';
	$lang['strunique'] = 'Unic';
	$lang['strprimary'] = 'Primar';
	$lang['strexport'] = 'Export';
	$lang['strimport'] = 'Import';
	$lang['strallowednulls'] = 'Caractere NULL permise';
	$lang['strbackslashn'] = '\N';
	$lang['stremptystring'] = 'Şir/câmp gol';
	$lang['strsql'] = 'SQL';
	$lang['stradmin'] = 'Administrare';
	$lang['strvacuum'] = 'Vacuum';
	$lang['stranalyze'] = 'Analiză';
	$lang['strclusterindex'] = 'Grupare';
	$lang['strclustered'] = 'Grupat?';
	$lang['strreindex'] = 'Re-indexare';
	$lang['strrun'] = 'Executare';
	$lang['stradd'] = 'Adăugare';
	$lang['strevent'] = 'Eveniment';
	$lang['strwhere'] = 'În schimb';
	$lang['strinstead'] = 'Execută în schimb';
	$lang['strwhen'] = 'Când';
	$lang['strformat'] = 'Format';
	$lang['strdata'] = 'Dată';
	$lang['strconfirm'] = 'Confirmare';
	$lang['strexpression'] = 'Expresie';
	$lang['strellipsis'] = '...';
	$lang['strseparator'] = ': ';
	$lang['strexpand'] = 'Expandare';
	$lang['strcollapse'] = 'Restrângere';
	$lang['strexplain'] = 'Explicare';
	$lang['strexplainanalyze'] = 'Explicare & Analiză';
	$lang['strfind'] = 'Căutare';
	$lang['stroptions'] = 'Opţiuni';
	$lang['strrefresh'] = 'Reîmprospătare';
	$lang['strdownload'] = 'Transfer';
	$lang['strdownloadgzipped'] = 'Transfer comprimat cu gzip';
	$lang['strinfo'] = 'Info';
	$lang['stroids'] = 'OID-uri';
	$lang['stradvanced'] = 'Avansat';
	$lang['strvariables'] = 'Variabile';
	$lang['strprocess'] = 'Proces';
	$lang['strprocesses'] = 'Procese';
	$lang['strsetting'] = 'Valoare';
	$lang['streditsql'] = 'Editare SQL';
	$lang['strruntime'] = 'Timp total de rulare:%s ms';
	$lang['strpaginate'] = 'Paginare rezultate';
	$lang['struploadscript'] = 'sau încărcare script SQL:';
	$lang['strstarttime'] = 'Timp start';
	$lang['strfile'] = 'Fişier';
	$lang['strfileimported'] = 'Fişier importat';
	$lang['strtrycred'] = 'Folosiţi aceste acreditări pentru toate serverele';
	$lang['strexecute'] = 'Executare';

	// Database sizes
	$lang['strsize'] = 'Dimensiune';
	$lang['strbytes'] = 'octeţi';
	$lang['strkb'] = 'kB';
	$lang['strmb'] = 'MB';
	$lang['strgb'] = 'GB';
	$lang['strtb'] = 'TB';

	// Error handling
	$lang['strnoframes'] = 'Această aplicaţie funcţionează cel mai bine într-un browser ce suportă frame-uri , dar poate fi folosită şi fără frame-uri, urmând legătura de mai jos.';
	$lang['strnoframeslink'] = 'Fără frame-uri';
	$lang['strbadconfig'] = 'Fişierul config.inc.php este învechit. Trebuie să-l re-generaţi folosind noul fişier config.inc.php-dist.';
	$lang['strnotloaded'] = 'Instalarea de PHP nu suportă PostgreSQL. Trebuie să re-compilaţi PHP folosind opţiunea --with-pgsql la configurare.';
	$lang['strpostgresqlversionnotsupported'] = 'Versiune de PostgreSQL ne-suportată. Actualizaţi la versiunea %s sau ulterioară.';
	$lang['strbadschema'] = 'Schemă specificată incorectă.';
	$lang['strbadencoding'] = 'Imposibil de setat codificarea client în baza de date.';
	$lang['strsqlerror'] = 'Eroare SQL:';
	$lang['strinstatement'] = 'În instrucţiunea:';
	$lang['strinvalidparam'] = 'Parametrii scriptului sunt incorecţi.';
	$lang['strnodata'] = 'Nici un rând găsit.';
	$lang['strnoobjects'] = 'Nici un obiect găsit.';
	$lang['strrownotunique'] = 'Nici un identificator unic pentru acest rând.';
	$lang['strnouploads'] = 'Încărcarea de fişiere este dezactivată.';
	$lang['strimporterror'] = 'Eroare la importare.';
	$lang['strimporterror-fileformat'] = 'Eroare la importare: Imposibil de determinat în mod automat formatul fişierului.';
	$lang['strimporterrorline'] = 'Eroare la importare pe linia %s.';
	$lang['strimporterrorline-badcolumnnum'] = 'Eroare la importare pe linia %s:  Linia nu are numărul corect de coloane.';
	$lang['strimporterror-uploadedfile'] = 'Eroare la importare: Fişierul nu a putut fi încărcat pe server';
	$lang['strcannotdumponwindows'] = 'Descărcarea de tabele complexe şi nume de scheme în Windows nu este suportată.';

	// Tables
	$lang['strtable'] = 'Tabelă';
	$lang['strtables'] = 'Tabele';
	$lang['strshowalltables'] = 'Afişare toate tabelele';
	$lang['strnotables'] = 'Nici o tabelă găsită.';
	$lang['strnotable'] = 'Nici o tabelă găsită.';
	$lang['strcreatetable'] = 'Creare tabelă.';
	$lang['strtablename'] = 'Nume tabelă';
	$lang['strtableneedsname'] = 'Specificaţi un nume pentru tabelă.';
	$lang['strtableneedsfield'] = 'Specificaţi cel puţin un câmp.';
	$lang['strtableneedscols'] = 'Specificaţi un număr corect de coloane.';
	$lang['strtablecreated'] = 'Tabelă creată.';
	$lang['strtablecreatedbad'] = 'Creare tabelă eşuată.';
	$lang['strconfdroptable'] = 'Sigur ştergeţi tabela "%s"?';
	$lang['strtabledropped'] = 'Tabelă ştearsă.';
	$lang['strtabledroppedbad'] = 'Ştergere tabelă eşuată.';
	$lang['strconfemptytable'] = 'Sigur goliţi tabela "%s"?';
	$lang['strtableemptied'] = 'Tabelă golită.';
	$lang['strtableemptiedbad'] = 'Golire tabelă eşuată.';
	$lang['strinsertrow'] = 'Inserare rând';
	$lang['strrowinserted'] = 'Rând inserat';
	$lang['strrowinsertedbad'] = 'Inserare rând eşuată.';
	$lang['strrowduplicate'] = 'Inserare de rând eşuată, s-a încercat inserarea unui duplicat.';
	$lang['streditrow'] = 'Editare rând';
	$lang['strrowupdated'] = 'Rând actualizat.';
	$lang['strrowupdatedbad'] = 'Actualizare rând eşuată.';
	$lang['strdeleterow'] = 'Ştergere rând.';
	$lang['strconfdeleterow'] = 'Sigur ştergeţi acest rând?';
	$lang['strrowdeleted'] = 'Rând şters.';
	$lang['strrowdeletedbad'] = 'Ştergere rând eşuată.';
	$lang['strinsertandrepeat'] = 'Inserare & Repetare';
	$lang['strnumcols'] = 'Număr de coloane';
	$lang['strcolneedsname'] = 'Specificaţi un nume pentru coloană';
	$lang['strselectallfields'] = 'Selectare toate câmpurile';
	$lang['strselectneedscol'] = 'Afişaţi cel puţin o coloană.';
	$lang['strselectunary'] = 'Operatorii unari nu pot avea valori.';
	$lang['straltercolumn'] = 'Modificare coloană';
	$lang['strcolumnaltered'] = 'Coloană modificată.';
	$lang['strcolumnalteredbad'] = 'Modificare coloană eşuată.';
	$lang['strconfdropcolumn'] = 'Sigur ştergeţi coloana "%s" din tabela "%s"?';
	$lang['strcolumndropped'] = 'Coloană ştearsă.';
	$lang['strcolumndroppedbad'] = 'Ştergere coloană eşuată.';
	$lang['straddcolumn'] = 'Adăugare coloană';
	$lang['strcolumnadded'] = 'Coloană adăugată.';
	$lang['strcolumnaddedbad'] = 'Adăugare coloană eşuată.';
	$lang['strcascade'] = 'CASCADE';
	$lang['strtablealtered'] = 'Tabelă modificată.';
	$lang['strtablealteredbad'] = 'Modificare tabelă eşuată.';
	$lang['strdataonly'] = 'Numai date';
	$lang['strstructureonly'] = 'Numai structură';
	$lang['strstructureanddata'] = 'Structură şi date';
	$lang['strtabbed'] = 'Cu tab-uri';
	$lang['strauto'] = 'Automat';
	$lang['strconfvacuumtable'] = 'Sigur executaţi "vacuum" pe "%s"?';
	$lang['strestimatedrowcount'] = 'Număr estimat de rânduri';

	// Columns
	$lang['strcolprop'] = 'Proprietăţi coloană';

	// Users
	$lang['struser'] = 'Utilizator';
	$lang['strusers'] = 'Utilizatori';
	$lang['strusername'] = 'Nume utilizator';
	$lang['strpassword'] = 'Parolă';
	$lang['strsuper'] = 'Utilizator privilegiat?';
	$lang['strcreatedb'] = 'Creează BD?';
	$lang['strexpires'] = 'Expiră la';
	$lang['strsessiondefaults'] = 'Valori implicite pentru sesiune';
	$lang['strnousers'] = 'Nici un utilizator găsit.';
	$lang['struserupdated'] = 'Utilizator actualizat.';
	$lang['struserupdatedbad'] = 'Actualizare utilizator eşuată.';
	$lang['strshowallusers'] = 'Afişare toţi utilizatorii';
	$lang['strcreateuser'] = 'Creare utilizator';
	$lang['struserneedsname'] = 'Specificaţi un nume pentru utilizator.';
	$lang['strusercreated'] = 'Utilizator creat.';
	$lang['strusercreatedbad'] = 'Creare utilizator eşuată.';
	$lang['strconfdropuser'] = 'Sigur ştergeţi utilizatorul "%s"?';
	$lang['struserdropped'] = 'Utilizator şters.';
	$lang['struserdroppedbad'] = 'Ştergere utilizator eşuată.';
	$lang['straccount'] = 'Cont';
	$lang['strchangepassword'] = 'Schimbare parolă';
	$lang['strpasswordchanged'] = 'Parolă schimbată.';
	$lang['strpasswordchangedbad'] = 'Schimbare parolă eşuată.';
	$lang['strpasswordshort'] = 'Parola este prea scurtă.';
	$lang['strpasswordconfirm'] = 'Parola nu se confirmă.';

	// Groups
	$lang['strgroup'] = 'Grup';
	$lang['strgroups'] = 'Grupuri';
	$lang['strshowallgroups'] = 'Afişare toate grupurile';
	$lang['strnogroup'] = 'Grup negăsit.';
	$lang['strnogroups'] = 'Nici un grup găsit.';
	$lang['strcreategroup'] = 'Creare grup';
	$lang['strgroupneedsname'] = 'Specificaţi un nume pentru grup.';
	$lang['strgroupcreated'] = 'Grup creat.';
	$lang['strgroupcreatedbad'] = 'Creare grup eşuată.';
	$lang['strconfdropgroup'] = 'Sigur ştergeţi grupul "%s"?';
	$lang['strgroupdropped'] = 'Grup şters.';
	$lang['strgroupdroppedbad'] = 'Ştergere grup eşuată.';
	$lang['strmembers'] = 'Membri';
	$lang['strmemberof'] = 'Membru al';
	$lang['stradminmembers'] = 'Membri administratori';
	$lang['straddmember'] = 'Adăugare membru';
	$lang['strmemberadded'] = 'Membru adăugat.';
	$lang['strmemberaddedbad'] = 'Adăugare membru eşuată.';
	$lang['strdropmember'] = 'Ştergere membru';
	$lang['strconfdropmember'] = 'Sigur ştergeţi membrul "%s" din grupul "%s"?';
	$lang['strmemberdropped'] = 'Membru şters.';
	$lang['strmemberdroppedbad'] = 'Ştergere membru eşuată.';

	// Roles
	$lang['strrole'] = 'Rol';
	$lang['strroles'] = 'Roluri';
	$lang['strshowallroles'] = 'Afişare toate rolurile';
	$lang['strnoroles'] = 'Nici un rol găsit';
	$lang['strinheritsprivs'] = 'Moştenire privilegii?';
	$lang['strcreaterole'] = 'Creare rol';
	$lang['strcancreaterole'] = 'Creare rol posibilă?';
	$lang['strrolecreated'] = 'Rol creat';
	$lang['strrolecreatedbad'] = 'Creare rol eşuată';
	$lang['stralterrole'] = 'Modificare rol';
	$lang['strrolealtered'] = 'Rol modificat';
	$lang['strrolealteredbad'] = 'Modificare rol eşuată';
	$lang['strcanlogin'] = 'Autentificare posibilă?';
	$lang['strconnlimit'] = 'Limită conectare';
	$lang['strdroprole'] = 'Ştergere rol';
	$lang['strconfdroprole'] = 'Sigur ştergeţi rolul "%s"?';
	$lang['strroledropped'] = 'Rol şters';
	$lang['strroledroppedbad'] = 'Ştergere rol eşuată';
	$lang['strnolimit'] = 'Fără limită';
	$lang['strnever'] = 'Niciodată';
	$lang['strroleneedsname'] = 'Specificaţi un nume pentru rol';

	// Privileges
	$lang['strprivilege'] = 'Privilegiu';
	$lang['strprivileges'] = 'Privilegii';
	$lang['strnoprivileges'] = 'Acest obiect are privilegiile implicite ale proprietarului.';
	$lang['strgrant'] = 'Acordare';
	$lang['strrevoke'] = 'Revocare';
	$lang['strgranted'] = 'Privilegii schimbate.';
	$lang['strgrantfailed'] = 'Schimbare privilegii eşuată.';
	$lang['strgrantbad'] = 'Specificaţi cel puţin un utilizator sau grup şi cel puţin un privilegiu.';
	$lang['strgrantor'] = 'Acordat de';
	$lang['strasterisk'] = '*';

	// Databases
	$lang['strdatabase'] = 'Bază de date';
	$lang['strdatabases'] = 'Baze de date';
	$lang['strshowalldatabases'] = 'Afişare toate bazele de date';
	$lang['strnodatabases'] = 'Nici o bază de date găsită.';
	$lang['strcreatedatabase'] = 'Creare bază de date';
	$lang['strdatabasename'] = 'Nume bază de date';
	$lang['strdatabaseneedsname'] = 'Specificaţi un nume pentru baza de date.';
	$lang['strdatabasecreated'] = 'Bază de date creată.';
	$lang['strdatabasecreatedbad'] = 'Creare bază de date eşuată.';
	$lang['strconfdropdatabase'] = 'Sigur ştergeţi baza de date "%s"?';
	$lang['strdatabasedropped'] = 'Bază de date ştearsă.';
	$lang['strdatabasedroppedbad'] = 'Ştergere bază de date eşuată.';
	$lang['strentersql'] = 'Introduceţi instrucţiunea SQL de executat:';
	$lang['strsqlexecuted'] = 'Instrucţiune SQL executată.';
	$lang['strvacuumgood'] = 'Vacuum terminat.';
	$lang['strvacuumbad'] = 'Vacuum eşuat.';
	$lang['stranalyzegood'] = 'Analiză terminată.';
	$lang['stranalyzebad'] = 'Analiză eşuată.';
	$lang['strreindexgood'] = 'Re-indexare terminată.';
	$lang['strreindexbad'] = 'Re-indexare eşuată.';
	$lang['strfull'] = 'Complet';
	$lang['strfreeze'] = 'Îngheţare';
	$lang['strforce'] = 'Forţare';
	$lang['strsignalsent'] = 'Semnal trimis.';
	$lang['strsignalsentbad'] = 'Trimitere semnal eşuată.';
	$lang['strallobjects'] = 'Toate obiectele';
	$lang['strdatabasealtered'] = 'Bază de date modificată.';
	$lang['strdatabasealteredbad'] = 'Modificarea bazei de date a eşuat.';

	// Views
	$lang['strview'] = 'Vizualizare';
	$lang['strviews'] = 'Vizualizări';
	$lang['strshowallviews'] = 'Afişare toate vizualizările';
	$lang['strnoview'] = 'Nici o vizualizare găsită.';
	$lang['strnoviews'] = 'Nici o vizualizare găsită.';
	$lang['strcreateview'] = 'Creare vizualizare';
	$lang['strviewname'] = 'Nume vizualizare';
	$lang['strviewneedsname'] = 'Specificaţi un nume pentru vizualizare.';
	$lang['strviewneedsdef'] = 'Specificaţi o definiţie pentru vizualizare.';
	$lang['strviewneedsfields'] = 'Specificaţi coloanele pe care le doriţi selectate în vizualizare.';
	$lang['strviewcreated'] = 'Vizualizare creată.';
	$lang['strviewcreatedbad'] = 'Creare vizualizare eşuată.';
	$lang['strconfdropview'] = 'Sigur ştergeţi vizualizarea "%s"?';
	$lang['strviewdropped'] = 'Vizualizare ştearsă.';
	$lang['strviewdroppedbad'] = 'Ştergere vizualizare eşuată.';
	$lang['strviewupdated'] = 'Vizualizare actualizată';
	$lang['strviewupdatedbad'] = 'Actualizare vizualizare eşuată.';
	$lang['strviewlink'] = 'Chei de legătură';
	$lang['strviewconditions'] = 'Condiţii suplimentare';
	$lang['strcreateviewwiz'] = 'Creare vizualizare folosind expertul';

	// Sequences
	$lang['strsequence'] = 'Secvenţă';
	$lang['strsequences'] = 'Secvenţe';
	$lang['strshowallsequences'] = 'Afişare toate secvenţele';
	$lang['strnosequence'] = 'Nici o secvenţă găsită.';
	$lang['strnosequences'] = 'Nici o secvenţă găsită.';
	$lang['strcreatesequence'] = 'Creare secvenţă';
	$lang['strlastvalue'] = 'Ultima valoare';
	$lang['strincrementby'] = 'Incrementare cu';
	$lang['strstartvalue'] = 'Valoare de start';
	$lang['strmaxvalue'] = 'Valoare maximă';
	$lang['strminvalue'] = 'Valoare minimă';
	$lang['strcachevalue'] = 'Valoare cache';
	$lang['strlogcount'] = 'Log count';
	$lang['striscycled'] = 'Ciclică?';
	$lang['strsequenceneedsname'] = 'Specificaţi un nume pentru secvenţă.';
	$lang['strsequencecreated'] = 'Secvenţă creată.';
	$lang['strsequencecreatedbad'] = 'Creare secvenţă eşuată.';
	$lang['strconfdropsequence'] = 'Sigur ştergeţi secvenţa "%s"?';
	$lang['strsequencedropped'] = 'Secvenţă ştearsă.';
	$lang['strsequencedroppedbad'] = 'Ştergere secvenţă eşuată.';
	$lang['strsequencereset'] = 'Reiniţializare secvenţă.';
	$lang['strsequenceresetbad'] = 'Reiniţializare secvenţă eşuată.';
	$lang['straltersequence'] = 'Modificare secvenţă';
	$lang['strsequencealtered'] = 'Secvenţă modificată';
	$lang['strsequencealteredbad'] = 'Modificare secvenţă eşuată';
	$lang['strsetval'] = 'Setare valoare';
	$lang['strsequencesetval'] = 'Valoare secvenţă setată';
	$lang['strsequencesetvalbad'] = 'Setare valoare secvenţă eşuată';
	$lang['strnextval'] = 'Valoare increment';
	$lang['strsequencenextval'] = 'Secvenţă incrementată';
	$lang['strsequencenextvalbad'] = 'Incremetare secvenţă eşuată';

	// Indexes
	$lang['strindex'] = 'Index';
	$lang['strindexes'] = 'Indexuri';
	$lang['strindexname'] = 'Nume index';
	$lang['strshowallindexes'] = 'Afişare toate indexurile';
	$lang['strnoindex'] = 'Nici un index găsit.';
	$lang['strnoindexes'] = 'Nici un index găsit.';
	$lang['strcreateindex'] = 'Creare index';
	$lang['strtabname'] = 'Nume tabelă';
	$lang['strcolumnname'] = 'Nume coloană';
	$lang['strindexneedsname'] = 'Specificaţi un nume pentru index.';
	$lang['strindexneedscols'] = 'Indexurile necesită un număr corect de coloane.';
	$lang['strindexcreated'] = 'Index creat';
	$lang['strindexcreatedbad'] = 'Creare index eşuată.';
	$lang['strconfdropindex'] = 'Sigur ştergeţi indexul "%s"?';
	$lang['strindexdropped'] = 'Index şters.';
	$lang['strindexdroppedbad'] = 'Ştergere index eşuată.';
	$lang['strkeyname'] = 'Nume cheie';
	$lang['struniquekey'] = 'Cheie unică';
	$lang['strprimarykey'] = 'Cheie primară';
	$lang['strindextype'] = 'Tip de index';
	$lang['strtablecolumnlist'] = 'Coloane în tabelă';
	$lang['strindexcolumnlist'] = 'Coloane în index';
	$lang['strconfcluster'] = 'Sigur grupaţi "%s"?';
	$lang['strclusteredgood'] = 'Grupare completă.';
	$lang['strclusteredbad'] = 'Grupare eşuată.';
	$lang['strcluster'] = 'Grupare';

	// Rules
	$lang['strrules'] = 'Reguli';
	$lang['strrule'] = 'Regulă';
	$lang['strshowallrules'] = 'Afişare toate regulile';
	$lang['strnorule'] = 'Nici o regulă găsită.';
	$lang['strnorules'] = 'Nici o regulă găsită.';
	$lang['strcreaterule'] = 'Creare regulă';
	$lang['strrulename'] = 'Nume regulă';
	$lang['strruleneedsname'] = 'Specificaţi un nume pentru regulă.';
	$lang['strrulecreated'] = 'Regulă creată.';
	$lang['strrulecreatedbad'] = 'Creare regulă eşuată.';
	$lang['strconfdroprule'] = 'Sigur ştergeţi regula "%s"?';
	$lang['strruledropped'] = 'Regulă ştearsă.';
	$lang['strruledroppedbad'] = 'Ştergere regulă eşuată.';

	// Constraints
	$lang['strconstraint'] = 'Restricţie';
	$lang['strconstraints'] = 'Restricţii';
	$lang['strshowallconstraints'] = 'Afişare toate restricţiile';
	$lang['strnoconstraints'] = 'Nici o restricţie găsită.';
	$lang['strcreateconstraint'] = 'Creare restricţie';
	$lang['strconstraintcreated'] = 'Restricţie creată.';
	$lang['strconstraintcreatedbad'] = 'Creare restricţie eşuată.';
	$lang['strconfdropconstraint'] = 'Sigur ştergeţi restricţia "%s"?';
	$lang['strconstraintdropped'] = 'Restricţie ştearsă.';
	$lang['strconstraintdroppedbad'] = 'Ştergere restricţie eşuată.';
	$lang['straddcheck'] = 'Adăugare verificare';
	$lang['strcheckneedsdefinition'] = 'Verificarea de restricţie necesită o definiţie.';
	$lang['strcheckadded'] = 'Verificare de restricţie adăugată.';
	$lang['strcheckaddedbad'] = 'Adăugare verificare de restricţie eşuată.';
	$lang['straddpk'] = 'Adăugare cheie primară';
	$lang['strpkneedscols'] = 'Cheia primară necesită cel puţin o coloană.';
	$lang['strpkadded'] = 'Cheie primară adăugată.';
	$lang['strpkaddedbad'] = 'Adăugare cheie primară eşuată.';
	$lang['stradduniq'] = 'Adăugare cheie unică';
	$lang['struniqneedscols'] = 'Cheia unică necesită cel puţin o coloană.';
	$lang['struniqadded'] = 'Cheie unică adăugată.';
	$lang['struniqaddedbad'] = 'Adăugare cheie unică eşuată.';
	$lang['straddfk'] = 'Adăugare cheie străină';
	$lang['strfkneedscols'] = 'Cheia străină necesită cel puţin o coloană.';
	$lang['strfkneedstarget'] = 'Cheia străină necesită o tabelă de destinaţie.';
	$lang['strfkadded'] = 'Cheie străină adăugată.';
	$lang['strfkaddedbad'] = 'Adăugare cheie străină eşuată.';
	$lang['strfktarget'] = 'Tabelă de destinaţie';
	$lang['strfkcolumnlist'] = 'Coloane în cheie';
	$lang['strondelete'] = 'ON DELETE';
	$lang['stronupdate'] = 'ON UPDATE';

	// Functions
	$lang['strfunction'] = 'Funcţie';
	$lang['strfunctions'] = 'Funcţii';
	$lang['strshowallfunctions'] = 'Afişare toate funcţiile';
	$lang['strnofunction'] = 'Nici o functie găsită.';
	$lang['strnofunctions'] = 'Nici o functie găsită.';
	$lang['strcreateplfunction'] = 'Creare funcţie SQL/PL';
	$lang['strcreateinternalfunction'] = 'Creare funcţie internă';
	$lang['strcreatecfunction'] = 'Creare funcţie C';
	$lang['strfunctionname'] = 'Nume funcţie';
	$lang['strreturns'] = 'Întoarce';
	$lang['strproglanguage'] = 'Limbaj de programare';
	$lang['strfunctionneedsname'] = 'Specificaţi un nume pentru funcţie.';
	$lang['strfunctionneedsdef'] = 'Specificaţi o definiţie pentru functie.';
	$lang['strfunctioncreated'] = 'Funcţie creată.';
	$lang['strfunctioncreatedbad'] = 'Creare funcţie eşuată.';
	$lang['strconfdropfunction'] = 'Sigur ştergeţi funcţia "%s"?';
	$lang['strfunctiondropped'] = 'Funcţie ştearsă.';
	$lang['strfunctiondroppedbad'] = 'Ştergere funcţie eşuată.';
	$lang['strfunctionupdated'] = 'Funcţie actualizată.';
	$lang['strfunctionupdatedbad'] = 'Actualizare funcţie eşuată.';
	$lang['strobjectfile'] = 'Fişier obiect';
	$lang['strlinksymbol'] = 'Simbol de legătură';
	$lang['strarguments'] = 'Argumente';
	$lang['strargmode'] = 'Mod';
	$lang['strargtype'] = 'Tip';
	$lang['strargadd'] = 'Adăugare alt argument';
	$lang['strargremove'] = 'Eliminare argument';
	$lang['strargnoargs'] = 'Această funcţie nu acceptă nici un argument';
	$lang['strargenableargs'] = 'Activare argumente pasate acestei funcţii';
	$lang['strargnorowabove'] = 'Trebuie să existe un rând deasupra acestui rând';
	$lang['strargnorowbelow'] = 'Trebuie să existe un rând dedesubtul acestui rând';
	$lang['strargraise'] = 'Mutare în sus';
	$lang['strarglower'] = 'Mutare în jos';
	$lang['strargremoveconfirm'] = 'Sigur eliminaţi acest argument? Această acţiune NU poate fi revocată.';

	// Triggers
	$lang['strtrigger'] = 'Declanşator';
	$lang['strtriggers'] = 'Declanşatori';
	$lang['strshowalltriggers'] = 'Afişare toate declanşatoarele';
	$lang['strnotrigger'] = 'Nici un declanşator găsit.';
	$lang['strnotriggers'] = 'Nici un declanşator găsit.';
	$lang['strcreatetrigger'] = 'Creare declanşator';
	$lang['strtriggerneedsname'] = 'Specificaţi un nume pentru declanşator.';
	$lang['strtriggerneedsfunc'] = 'Specificaţi o funcţie pentru declanşator.';
	$lang['strtriggercreated'] = 'Declanşator creat.';
	$lang['strtriggercreatedbad'] = 'Creare declanşator eşuată.';
	$lang['strconfdroptrigger'] = 'Sigur ştergeţi declanşatorul "%s" de pe "%s"?';
	$lang['strconfenabletrigger'] = 'Sigur activaţi declanşatorul "%s" pentru "%s"?';
	$lang['strconfdisabletrigger'] = 'Sigur dezactivaţi declanşatorul "%s" pentru "%s"?';
	$lang['strtriggerdropped'] = 'Declanşator şters.';
	$lang['strtriggerdroppedbad'] = 'Ştergere declanşator eşuată.';
	$lang['strtriggerenabled'] = 'Declanşator activat';
	$lang['strtriggerenabledbad'] = 'Activare declanşator eşuată';
	$lang['strtriggerdisabled'] = 'Declanşator dezactivat';
	$lang['strtriggerdisabledbad'] = 'Dezactivare declanşator eşuată';
	$lang['strtriggeraltered'] = 'Declanşator modificat.';
	$lang['strtriggeralteredbad'] = 'Modificare declanşator eşuată.';
	$lang['strforeach'] = 'Pentru fiecare';

	// Types
	$lang['strtype'] = 'Tip';
	$lang['strtypes'] = 'Tipuri';
	$lang['strshowalltypes'] = 'Afişare toate tipurile';
	$lang['strnotype'] = 'Nici un tip găsit.';
	$lang['strnotypes'] = 'Nici un tip găsit.';
	$lang['strcreatetype'] = 'Creare tip';
	$lang['strcreatecomptype'] = 'Creare tip compus';
	$lang['strtypeneedsfield'] = 'Specificaţi cel puţin un câmp.';
	$lang['strtypeneedscols'] = 'Specificaţi un număr corect de cămpuri.';
	$lang['strtypename'] = 'Nume tip';
	$lang['strinputfn'] = 'Funcţie de intrare';
	$lang['stroutputfn'] = 'Funcţie de ieşire';
	$lang['strpassbyval'] = 'Transmis prin valoare?';
	$lang['stralignment'] = 'Aliniere';
	$lang['strelement'] = 'Element';
	$lang['strdelimiter'] = 'Delimitator';
	$lang['strstorage'] = 'Stocare';
	$lang['strfield'] = 'Câmp';
	$lang['strnumfields'] = 'Număr de câmpuri';
	$lang['strtypeneedsname'] = 'Specificaţi un nume pentru tip.';
	$lang['strtypeneedslen'] = 'Specificaţi o lungime pentru tip.';
	$lang['strtypecreated'] = 'Tip creat.';
	$lang['strtypecreatedbad'] = 'Creare tip eşuată.';
	$lang['strconfdroptype'] = 'Sigur ştergeţi tipul "%s"?';
	$lang['strtypedropped'] = 'Tip şters.';
	$lang['strtypedroppedbad'] = 'Ştergere tip eşuată.';
	$lang['strflavor'] = 'Flavor';
	$lang['strbasetype'] = 'Bază';
	$lang['strcompositetype'] = 'Compus';
	$lang['strpseudotype'] = 'Pseudo';

	// Schemas
	$lang['strschema'] = 'Schemă';
	$lang['strschemas'] = 'Scheme';
	$lang['strshowallschemas'] = 'Afişare toate schemele';
	$lang['strnoschema'] = 'Nici o schemă găsită.';
	$lang['strnoschemas'] = 'Nici o schemă găsită.';
	$lang['strcreateschema'] = 'Creare schemă';
	$lang['strschemaname'] = 'Nume schemă';
	$lang['strschemaneedsname'] = 'Specificaţi un nume pentru schemă.';
	$lang['strschemacreated'] = 'Schemă creată.';
	$lang['strschemacreatedbad'] = 'Creare schemă eşuată.';
	$lang['strconfdropschema'] = 'Sigur ştergeţi schema "%s"?';
	$lang['strschemadropped'] = 'Schemă ştearsă.';
	$lang['strschemadroppedbad'] = 'Ştergere schemă eşuată.';
	$lang['strschemaaltered'] = 'Schemă modificată.';
	$lang['strschemaalteredbad'] = 'Modificare schemă eşuată.';
	$lang['strsearchpath'] = 'Cale de căutare pentru schemă';

	// Reports

	// Domains
	$lang['strdomain'] = 'Domeniu';
	$lang['strdomains'] = 'Domenii';
	$lang['strshowalldomains'] = 'Afişare toate domeniile';
	$lang['strnodomains'] = 'Nici un domeniu găsit.';
	$lang['strcreatedomain'] = 'Creare domeniu';
	$lang['strdomaindropped'] = 'Domeniu şters.';
	$lang['strdomaindroppedbad'] = 'Ştergere domeniu eşuată.';
	$lang['strconfdropdomain'] = 'Sigur ştergeţi domeniul "%s"?';
	$lang['strdomainneedsname'] = 'Specificaţi un nume pentru domeniu.';
	$lang['strdomaincreated'] = 'Domeniu creat.';
	$lang['strdomaincreatedbad'] = 'Creare domeniu eşuată.';
	$lang['strdomainaltered'] = 'Domeniu modificat.';
	$lang['strdomainalteredbad'] = 'Modificare domeniu eşuată.';

	// Operators
	$lang['stroperator'] = 'Operator';
	$lang['stroperators'] = 'Operatori';
	$lang['strshowalloperators'] = 'Afişare toţi operatorii';
	$lang['strnooperator'] = 'Nici un operator găsit.';
	$lang['strnooperators'] = 'Nici un operator găsit.';
	$lang['strcreateoperator'] = 'Creare operator';
	$lang['strleftarg'] = 'Tipul argumentului stâng';
	$lang['strrightarg'] = 'Tipul argumentului drept';
	$lang['strcommutator'] = 'Comutator';
	$lang['strnegator'] = 'Negator';
	$lang['strrestrict'] = 'Restrict';
	$lang['strjoin'] = 'Relaţionare';
	$lang['strhashes'] = 'Hashes';
	$lang['strmerges'] = 'Îmbină';
	$lang['strleftsort'] = 'Sortare stânga';
	$lang['strrightsort'] = 'Sortare dreapta';
	$lang['strlessthan'] = 'Mai mic decăt';
	$lang['strgreaterthan'] = 'Mai mare decăt';
	$lang['stroperatorneedsname'] = 'Specificaţi un nume pentru operator.';
	$lang['stroperatorcreated'] = 'Operator creat.';
	$lang['stroperatorcreatedbad'] = 'Creare operator eşuată.';
	$lang['strconfdropoperator'] = 'Sigur ştergeţi operatorul "%s"?';
	$lang['stroperatordropped'] = 'Operator şters.';
	$lang['stroperatordroppedbad'] = 'Ştergere operator eşuată.';

	// Casts
	$lang['strcasts'] = 'Conversii de tip';
	$lang['strnocasts'] = 'Nici o conversie de tip găsită.';
	$lang['strsourcetype'] = 'Tip sursă';
	$lang['strtargettype'] = 'Tip destinaţie';
	$lang['strimplicit'] = 'Implicit';
	$lang['strinassignment'] = 'În alocare';
	$lang['strbinarycompat'] = '(Compatibil binar)';

	// Conversions
	$lang['strconversions'] = 'Conversii';
	$lang['strnoconversions'] = 'Nici o conversie găsită.';
	$lang['strsourceencoding'] = 'Codificare sursă';
	$lang['strtargetencoding'] = 'Codificare destinaţie';

	// Languages
	$lang['strlanguages'] = 'Limbaje';
	$lang['strnolanguages'] = 'Nici un limbaj găsit.';
	$lang['strtrusted'] = 'Sigur';

	// Info
	$lang['strnoinfo'] = 'Nici o informaţie disponibilă.';
	$lang['strreferringtables'] = 'Tabele referite';
	$lang['strparenttables'] = 'Tabele părinte';
	$lang['strchildtables'] = 'Tabele copii';

	// Aggregates
	$lang['straggregate'] = 'Agregare';
	$lang['straggregates'] = 'Agregări';
	$lang['strnoaggregates'] = 'Nici o agregare găsită.';
	$lang['stralltypes'] = '(Toate tipurile)';
	$lang['straggrtransfn'] = 'Funcţie de tranziţie';
	$lang['strcreateaggregate'] = 'Creare agregare';
	$lang['straggrbasetype'] = 'Tip dată de intrare';
	$lang['straggrsfunc'] = 'Funcţie tranziţie de stare';
	$lang['straggrffunc'] = 'Funcţie finală';
	$lang['straggrinitcond'] = 'Condiţie iniţială';
	$lang['straggrsortop'] = 'Operator sortare';
	$lang['strdropaggregate'] = 'Ştergere agregare';
	$lang['strconfdropaggregate'] = 'Sigur ştergeţi agregarea "%s"?';
	$lang['straggregatedropped'] = 'Agregare ştearsă.';
	$lang['straggregatedroppedbad'] = 'Ştergere agregare eşuată.';
	$lang['stralteraggregate'] = 'Modificare agregare';
	$lang['straggraltered'] = 'Agregare modificată.';
	$lang['straggralteredbad'] = 'Modificare agregare eşuată.';
	$lang['straggrneedsname'] = 'Specificaţi un nume pentru agregare';
	$lang['straggrneedsbasetype'] = 'Specificaţi tipul de dată de intrare pentru agregare';
	$lang['straggrneedssfunc'] = 'Specificaţi numele funcţiei tranziţiei de stare pentru agregare';
	$lang['straggrneedsstype'] = 'Specificaţi tipul datei pentru valoarea stării agregării';
	$lang['straggrcreated'] = 'Agregare creată.';
	$lang['straggrcreatedbad'] = 'Creare agregare eşuată.';
	$lang['straggrshowall'] = 'Afişare toate agregările';

	// Operator Classes
	$lang['stropclasses'] = 'Clase de operatori';
	$lang['strnoopclasses'] = 'Nici o clasă de operatori găsită.';
	$lang['straccessmethod'] = 'Metodă de acces';

	// Stats and performance
	$lang['strrowperf'] = 'Performanţă rând';
	$lang['strioperf'] = 'Performanţă I/O';
	$lang['stridxrowperf'] = 'Performanţă index/rând';
	$lang['stridxioperf'] = 'Performanţă index I/O';
	$lang['strpercent'] = '%';
	$lang['strsequential'] = 'Secvenţial';
	$lang['strscan'] = 'Scanare';
	$lang['strread'] = 'Citire';
	$lang['strfetch'] = 'Transfer';
	$lang['strheap'] = 'Stivă';
	$lang['strtoast'] = 'TOAST';
	$lang['strtoastindex'] = 'Index TOAST';
	$lang['strcache'] = 'Cache';
	$lang['strdisk'] = 'Disc';
	$lang['strrows2'] = 'Rânduri';

	// Tablespaces
	$lang['strtablespace'] = 'Spaţiu de tabele';
	$lang['strtablespaces'] = 'Spaţii de tabele';
	$lang['strshowalltablespaces'] = 'Afişare toate spaţiile de tabele';
	$lang['strnotablespaces'] = 'Nici un spaţiu de tabele găsit.';
	$lang['strcreatetablespace'] = 'Creare spaţiu de tabele';
	$lang['strlocation'] = 'Locaţie';
	$lang['strtablespaceneedsname'] = 'Specificaţi un nume pentru spaţiul de tabele.';
	$lang['strtablespaceneedsloc'] = 'Specificaţi directorul în care va fi creat spaţiul de tabele.';
	$lang['strtablespacecreated'] = 'Spaţiu de tabele creat.';
	$lang['strtablespacecreatedbad'] = 'Creare spaţiu de tabele eşuată.';
	$lang['strconfdroptablespace'] = 'Sigur ştergeţi spaţiul de tabele "%s"?';
	$lang['strtablespacedropped'] = 'Spaţiu de tabele şters.';
	$lang['strtablespacedroppedbad'] = 'Ştergere şpaţiu de tabele eşuată.';
	$lang['strtablespacealtered'] = 'Spaţiu de tabele modificat.';
	$lang['strtablespacealteredbad'] = 'Modificare şpaţiu de tabele eşuată.';

	// Miscellaneous
	$lang['strtopbar'] = '%s rulând pe %s:%s -- Sunteţi autentificat ca utilizator "%s"';
	$lang['strtimefmt'] = 'jS M, Y g:iA';
	$lang['strhelp'] = 'Ajutor';
	$lang['strhelpicon'] = '?';
	$lang['strhelppagebrowser'] = 'Pagini de ajutor';
	$lang['strselecthelppage'] = 'Selectaţi o pagină de ajutor';
	$lang['strinvalidhelppage'] = 'Pagină de ajutor incorectă.';
	$lang['strlogintitle'] = 'Autentificare la %s';
	$lang['strlogoutmsg'] = 'Ieşire din %s';
	$lang['strloading'] = 'Încărcare...';
	$lang['strerrorloading'] = 'Eroare la încărcare';
	$lang['strclicktoreload'] = 'Faceţi clic pentru reîncărcare';

	// Autovacuum
	$lang['strautovacuum'] = 'Autovacuum';
	$lang['strturnedon'] = 'Pornit';
	$lang['strturnedoff'] = 'Oprit';
	$lang['strenabled'] = 'Activat';
	$lang['strvacuumbasethreshold'] = 'Vacuum Base Threshold';
	$lang['strvacuumscalefactor'] = 'Vacuum Scale Factor';
	$lang['stranalybasethreshold'] = 'Analyze Base Threshold';
	$lang['stranalyzescalefactor'] = 'Analyze Scale Factor';
	$lang['strvacuumcostdelay'] = 'Vacuum Cost Delay';
	$lang['strvacuumcostlimit'] = 'Vacuum Cost Limit';

	// Table-level Locks
	$lang['strlocks'] = 'Blocări';
	$lang['strtransaction'] = 'ID tranzacţie';
	$lang['strprocessid'] = 'ID proces';
	$lang['strmode'] = 'Mod blocare';
	$lang['strislockheld'] = 'Blocaj reţinut?';

	// Prepared transactions
	$lang['strpreparedxacts'] = 'Tranzacţii preparate';
	$lang['strxactid'] = 'ID tranzacţie';
	$lang['strgid'] = 'ID global';



?>
